@@ -25,20 +25,23 @@
 #' @details
 #'
 #' The `Effects` column indicate if a parameter is a *fixed* or *random* effect.
-#' The `Component` can either be *conditional* or *zero_inflated*. For models
-#' with random effects, the `Group` column indicates the grouping factor of the
-#' random effects. For multivariate response models from **brms** or
-#' **rstanarm**, an additional *Response* column is included, to indicate
-#' which parameters belong to which response formula. Furthermore,
-#' *Cleaned_Parameter* column is returned that contains "human readable"
-#' parameter names (which are mostly identical to `Parameter`, except for for
-#' models from **brms** or **rstanarm**, or for specific terms like smooth-
-#' or spline-terms).
+#' The `Component` column refers to special model components like *conditional*,
+#' *zero_inflated*, or *dispersion*. For models from package **brms**, the
+#' various distributional parameters are also included in this column. For
+#' models with random effects, the `Group` column indicates the grouping factor
+#' of the random effects. For multivariate response models from **brms** or
+#' **rstanarm**, an additional *Response* column is included, to indicate which
+#' parameters belong to which response formula. Furthermore, *Cleaned_Parameter*
+#' column is returned that contains "human readable" parameter names (which are
+#' mostly identical to `Parameter`, except for for models from **brms** or
+#' **rstanarm**, or for specific terms like smooth- or spline-terms).
 #'
 #' @examplesIf require("curl", quietly = TRUE) && curl::has_internet() && require("brms")
 #' \donttest{
 #' model <- download_model("brms_zi_2")
-#' clean_parameters(model)
+#' if (!is.null(model)) {
+#'   clean_parameters(model)
+#' }
 #' }
 #' @export
 clean_parameters <- function(x, ...) {
@@ -48,11 +51,7 @@ clean_parameters <- function(x, ...) {
 
 #' @export
 clean_parameters.default <- function(x, group = "", ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
 
   l <- lapply(names(pars), function(i) {
     eff <- if (grepl("random", i, fixed = TRUE)) {
@@ -61,28 +60,33 @@ clean_parameters.default <- function(x, group = "", ...) {
       "fixed"
     }
 
-    com <- if (grepl("zero_inflated", i, fixed = TRUE)) {
-      "zero_inflated"
-    } else if (grepl("dispersion", i, fixed = TRUE)) {
-      "dispersion"
-    } else if (grepl("nonlinear", i, fixed = TRUE)) {
-      "nonlinear"
-    } else if (grepl("instruments", i, fixed = TRUE)) {
-      "instruments"
-    } else if (grepl("extra", i, fixed = TRUE)) {
-      "extra"
-    } else if (grepl("scale", i, fixed = TRUE)) {
-      "scale"
-    } else if (grepl("marginal", i, fixed = TRUE)) {
-      "marginal"
-    } else if (grepl("intercept", i, fixed = TRUE)) {
-      "intercept"
-    } else if (grepl("correlation", i, fixed = TRUE)) {
-      "correlation"
-    } else {
-      "conditional"
+    # which components do we possibly have for that model? This should match
+    # those possible components returned by `find_parameters()`, see
+    # @section Model components in `find_predictors.R`, or
+    # `.get_elements("fixed", "all")`
+    # fmt: skip
+    components <- c(
+      "zero_inflated", "dispersion", "nonlinear", "instruments", "phi", "mu",
+      "extra", "scale", "marginal", "intercept", "correlation", "ip", "tau",
+      "beta", "precision", "selection", "auxiliary", "outcome", "full",
+      "infrequent_purchase", "delta", "shape", "survival"
+    )
+
+    # iterate all components
+    com <- NULL
+    for (cm in components) {
+      if (grepl(cm, i, fixed = TRUE)) {
+        com <- cm
+        break
+      }
     }
 
+    # finally, if not found, default to "conditional"
+    if (is.null(com)) {
+      com <- "conditional"
+    }
+
+    # check for smooth terms
     fun <- if (grepl("smooth", i, fixed = TRUE)) {
       "smooth"
     } else {
@@ -150,11 +154,7 @@ clean_parameters.emm_list <- clean_parameters.emmGrid
 
 #' @export
 clean_parameters.BFBayesFactor <- function(x, ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
 
   l <- lapply(names(pars), function(i) {
     eff <- if (grepl("random", i, fixed = TRUE)) {
@@ -187,11 +187,7 @@ clean_parameters.BFBayesFactor <- function(x, ...) {
 
 #' @export
 clean_parameters.wbm <- function(x, ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
 
   l <- lapply(names(pars), function(i) {
     com <- if (grepl("random", i, fixed = TRUE)) {
@@ -244,11 +240,7 @@ clean_parameters.model_fit <- function(x, ...) {
 
 #' @export
 clean_parameters.glmm <- function(x, ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
 
   l <- lapply(names(pars), function(i) {
     data.frame(
@@ -306,11 +298,7 @@ clean_parameters.blavaan <- function(x, ...) {
 
 #' @export
 clean_parameters.brmsfit <- function(x, ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "full", component = "all", flatten = FALSE)
 
   is_mv <- is_multivariate(pars)
 
@@ -324,18 +312,14 @@ clean_parameters.brmsfit <- function(x, ...) {
   }
 
   out <- do.call(rbind, l)
-  out <- .remove_empty_columns_from_pars(.clean_brms_params(out, is_mv, ...))
+  out <- .remove_empty_columns_from_pars(.clean_brms_params(x, out, is_mv, ...))
   .fix_random_effect_smooth(x, out)
 }
 
 
 #' @export
 clean_parameters.stanreg <- function(x, ...) {
-  pars <- find_parameters(x,
-    effects = "all",
-    component = "all",
-    flatten = FALSE
-  )
+  pars <- find_parameters(x, effects = "full", component = "all", flatten = FALSE)
 
   l <- .get_stan_params(pars)
 
@@ -359,7 +343,7 @@ clean_parameters.bamlss <- function(x, ...) {
 
 #' @export
 clean_parameters.stanmvreg <- function(x, ...) {
-  pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
+  pars <- find_parameters(x, effects = "full", component = "all", flatten = FALSE)
 
   l <- do.call(
     rbind,
@@ -367,7 +351,7 @@ clean_parameters.stanmvreg <- function(x, ...) {
   )
 
   out <- do.call(rbind, l)
-  out <- .remove_empty_columns_from_pars(.clean_stanreg_params(out))
+  out <- .remove_empty_columns_from_pars(.clean_stanreg_params(out, is_mv = TRUE))
   .fix_random_effect_smooth(x, out)
 }
 
@@ -419,7 +403,6 @@ clean_parameters.mlm <- function(x, ...) {
 
 # helper -------------------------
 
-
 .get_stan_params <- function(pars, response = NA) {
   lapply(names(pars), function(i) {
     eff <- if (grepl("random", i, fixed = TRUE)) {
@@ -428,8 +411,9 @@ clean_parameters.mlm <- function(x, ...) {
       "fixed"
     }
 
-    com <- if (grepl("zero_inflated", i, fixed = TRUE)) {
-      "zero_inflated"
+    # we must start with "conditional one", so it's not confused with "conditional"
+    com <- if (grepl("conditional", i, fixed = TRUE) || i == "random") {
+      "conditional"
     } else if (grepl("sigma", i, fixed = TRUE)) {
       "sigma"
     } else if (grepl("priors", i, fixed = TRUE)) {
@@ -438,22 +422,12 @@ clean_parameters.mlm <- function(x, ...) {
       "car"
     } else if (grepl("smooth_terms", i, fixed = TRUE)) {
       "smooth_terms"
-    } else if (grepl("alpha", i, fixed = TRUE)) {
-      "distributional"
-    } else if (grepl("beta", i, fixed = TRUE)) {
-      "distributional"
-    } else if (grepl("mix", i, fixed = TRUE)) {
-      "distributional"
-    } else if (grepl("shiftprop", i, fixed = TRUE)) {
-      "distributional"
-    } else if (grepl("shape", i, fixed = TRUE)) {
-      "distributional"
-    } else if (grepl("auxiliary", i, fixed = TRUE)) {
-      "distributional"
     } else if (grepl("dispersion", i, fixed = TRUE)) {
       "dispersion"
+    } else if (endsWith(i, "_random")) {
+      gsub("_random$", "", i)
     } else {
-      "conditional"
+      i
     }
 
     fun <- if (grepl("smooth", i, fixed = TRUE)) {
@@ -462,7 +436,6 @@ clean_parameters.mlm <- function(x, ...) {
       ""
     }
 
-
     data.frame(
       Parameter = pars[[i]],
       Effects = eff,
@@ -477,7 +450,7 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-.clean_brms_params <- function(out, is_mv, ...) {
+.clean_brms_params <- function(x, out, is_mv, ...) {
   dots <- list(...)
   out$Cleaned_Parameter <- out$Parameter
 
@@ -507,30 +480,95 @@ clean_parameters.mlm <- function(x, ...) {
     }
   }
 
+  # multimembership / mixture?
+  model_fam <- get_family(x)
+  if (inherits(model_fam, "brmsfamily") && model_fam$family == "mixture") {
+    class_params <- grepl("^b_mu\\d+_(.*)", out$Parameter)
+    if (any(class_params)) {
+      out$Group[class_params] <- paste(
+        "Class",
+        gsub("^b_mu(\\d+)_(.*)", "\\1", out$Parameter[class_params])
+      )
+    }
+  } else {
+    class_params <- NULL
+  }
+
+  # retrieve auxiliary components
+  dpars <- find_auxiliary(x)
+
+  # handle auxiliary components
+  for (i in dpars) {
+    aux_params <- startsWith(out$Cleaned_Parameter, paste0("b_", i, "_"))
+    out$Component[aux_params & out$Component == "conditional"] <- i
+  }
 
   smooth_function <- grepl(pattern = "(bs_|bs_zi_)", out$Cleaned_Parameter)
   if (any(smooth_function)) {
     out$Function[smooth_function] <- "smooth"
   }
 
-
+  # clean auxiliary
+  out$Cleaned_Parameter <- gsub(
+    pattern = paste0("^(", paste0("b_", dpars, "_", collapse = "|"), ")"),
+    "",
+    out$Cleaned_Parameter
+  )
   # clean fixed effects, conditional and zero-inflated
+  out$Cleaned_Parameter <- gsub(
+    pattern = "^b_(?!zi_)(.*)\\.(\\d)\\.$",
+    "\\1[\\2]",
+    out$Cleaned_Parameter,
+    perl = TRUE
+  )
+  out$Cleaned_Parameter <- gsub(
+    pattern = "^b_zi_(.*)\\.(\\d)\\.$",
+    "\\1[\\2]",
+    out$Cleaned_Parameter
+  )
+  out$Cleaned_Parameter <- gsub(
+    pattern = "^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)",
+    "\\2",
+    out$Cleaned_Parameter,
+    perl = TRUE
+  )
+  out$Cleaned_Parameter <- gsub(
+    pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)",
+    "\\2",
+    out$Cleaned_Parameter
+  ) # nolint
 
-  out$Cleaned_Parameter <- gsub(pattern = "^b_(?!zi_)(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^b_zi_(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter)
-  out$Cleaned_Parameter <- gsub(pattern = "^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)", "\\2", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)", "\\2", out$Cleaned_Parameter) # nolint
+  if (!is.null(class_params)) {
+    # remove "mu<number>_" from parameters
+    out$Cleaned_Parameter[class_params] <- gsub(
+      "^mu(\\d+)_(.*)",
+      "\\2",
+      out$Cleaned_Parameter[class_params]
+    )
+  }
 
   # correlation and sd
 
   cor_sd <- grepl("(sd_|cor_)(.*)", out$Cleaned_Parameter)
   if (any(cor_sd)) {
-    out$Cleaned_Parameter[cor_sd] <- gsub("^(sd_|cor_)(.*?)__(.*)", "\\3", out$Parameter[cor_sd])
-    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd]))
+    out$Cleaned_Parameter[cor_sd] <- gsub(
+      "^(sd_|cor_)(.*?)__(.*)",
+      "\\3",
+      out$Parameter[cor_sd]
+    )
+    out$Group[cor_sd] <- paste(
+      "SD/Cor:",
+      gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd])
+    )
     # replace "__" by "~"
     cor_only <- startsWith(out$Parameter[cor_sd], "cor_")
     if (any(cor_only)) {
-      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub("__", " ~ ", out$Cleaned_Parameter[which(cor_sd)[cor_only]], fixed = TRUE) # nolint
+      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub(
+        "__",
+        " ~ ",
+        out$Cleaned_Parameter[which(cor_sd)[cor_only]],
+        fixed = TRUE
+      )
     }
   }
 
@@ -550,6 +588,9 @@ clean_parameters.mlm <- function(x, ...) {
       # we want to have same behaviour as for frequentist models,
       # including levels of grouop factors
       r_levels <- gsub("__zi", "", r_levels, fixed = TRUE)
+      for (i in dpars) {
+        r_levels <- gsub(paste0("__", i), "", r_levels, fixed = TRUE)
+      }
       out$Level[rand_eff] <- r_levels
       # fix labelling of SD and correlation component
       sd_cor <- grepl("SD/Cor:", out$Group, fixed = TRUE)
@@ -557,17 +598,36 @@ clean_parameters.mlm <- function(x, ...) {
         out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
       }
     } else {
-      r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\3: \\1", out$Cleaned_Parameter[rand_eff])
+      r_grps <- gsub(
+        "^r_(.*)\\[(.*),(.*)\\]",
+        "\\3: \\1",
+        out$Cleaned_Parameter[rand_eff]
+      )
     }
+
     r_pars <- gsub("__zi", "", r_pars, fixed = TRUE)
     r_grps <- gsub("__zi", "", r_grps, fixed = TRUE)
 
+    for (i in dpars) {
+      r_pars <- gsub(paste0("__", i), "", r_pars, fixed = TRUE)
+      r_grps <- gsub(paste0("__", i), "", r_grps, fixed = TRUE)
+    }
+
     out$Cleaned_Parameter[rand_eff] <- r_pars
     out$Group[rand_eff] <- r_grps
   }
 
   # clean remaining parameters
 
+  sigma_params <- startsWith(out$Cleaned_Parameter, "sigma_")
+  if (length(sigma_params)) {
+    out$Cleaned_Parameter <- gsub("^sigma_(.*)", "\\1", out$Cleaned_Parameter)
+    # remove double "sigma_" in cleaned parameter names, which we have for
+    # random slope-intercept correlations
+    out$Cleaned_Parameter <- gsub("sigma_", "", out$Cleaned_Parameter, fixed = TRUE)
+    out$Component[sigma_params] <- "sigma"
+  }
+
   priors <- startsWith(out$Cleaned_Parameter, "prior_")
   if (length(priors)) {
     out$Cleaned_Parameter <- gsub("^prior_", "", out$Cleaned_Parameter)
@@ -576,7 +636,11 @@ clean_parameters.mlm <- function(x, ...) {
 
   simplex <- startsWith(out$Cleaned_Parameter, "simo_")
   if (length(simplex)) {
-    out$Cleaned_Parameter[simplex] <- gsub("^(simo_|simo_mo)(.*)\\[(\\d)\\]$", "\\2[\\3]", out$Cleaned_Parameter[simplex]) # nolint
+    out$Cleaned_Parameter[simplex] <- gsub(
+      "^(simo_|simo_mo)(.*)\\[(\\d)\\]$",
+      "\\2[\\3]",
+      out$Cleaned_Parameter[simplex]
+    )
     out$Component[simplex] <- "simplex"
   }
 
@@ -589,13 +653,21 @@ clean_parameters.mlm <- function(x, ...) {
 
   # fix intercept names
 
-  intercepts <- which(out$Cleaned_Parameter %in% c("Intercept", "zi_Intercept"))
+  intercepts <- which(
+    out$Cleaned_Parameter %in%
+      c("Intercept", "zi_Intercept") |
+      endsWith(out$Cleaned_Parameter, "_Intercept")
+  )
 
   if (!is_empty_object(intercepts)) {
     out$Cleaned_Parameter[intercepts] <- "(Intercept)"
   }
 
-  interaction_terms <- grep(".", out$Cleaned_Parameter, fixed = TRUE)
+  interaction_terms <- grep(
+    ".",
+    out$Cleaned_Parameter[out$Effects != "random"],
+    fixed = TRUE
+  )
 
   if (length(interaction_terms)) {
     for (i in interaction_terms) {
@@ -611,16 +683,33 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-.clean_stanreg_params <- function(out, ...) {
-  out$Cleaned_Parameter <- out$Parameter
+.clean_stanreg_params <- function(out, is_mv = FALSE, ...) {
+  out$Cleaned_Parameter <- dummy_parameter <- out$Parameter
   dots <- list(...)
 
+  # clean stanmvreg parameters from response names
+  if (is_mv) {
+    for (i in unique(out$Response)) {
+      out$Cleaned_Parameter <- gsub(
+        paste0(i, "|"),
+        "",
+        out$Cleaned_Parameter,
+        fixed = TRUE
+      )
+    }
+    dummy_parameter <- out$Cleaned_Parameter
+  }
+
   # extract group-names from random effects and clean random effects
 
   rand_intercepts <- startsWith(out$Cleaned_Parameter, "b[(Intercept)")
 
   if (any(rand_intercepts)) {
-    re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_intercepts])
+    re_grp_level <- gsub(
+      "b\\[(.*) (.*):(.*)\\]",
+      "\\2",
+      out$Cleaned_Parameter[rand_intercepts]
+    )
     out$Cleaned_Parameter[rand_intercepts] <- gsub(
       "b\\[\\(Intercept\\) (.*)\\]",
       "\\1",
@@ -629,23 +718,28 @@ clean_parameters.mlm <- function(x, ...) {
     out$Group[rand_intercepts] <- sprintf("Intercept: %s", re_grp_level)
   }
 
-
   # correlation and sd
 
   cor_sd <- startsWith(out$Cleaned_Parameter, "Sigma[")
 
   if (any(cor_sd)) {
-    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", out$Parameter[cor_sd])
-    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", out$Parameter[cor_sd])
+    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", dummy_parameter[cor_sd])
+    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", dummy_parameter[cor_sd])
     out$Cleaned_Parameter[which(cor_sd)] <- parm1
     rand_cor <- parm1 != parm2
     if (any(rand_cor)) {
-      out$Cleaned_Parameter[which(cor_sd)[rand_cor]] <- paste0(parm1[rand_cor], " ~ ", parm2[rand_cor])
+      out$Cleaned_Parameter[which(cor_sd)[rand_cor]] <- paste0(
+        parm1[rand_cor],
+        " ~ ",
+        parm2[rand_cor]
+      )
     }
-    out$Group[cor_sd] <- paste("Var/Cov:", gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", out$Parameter[cor_sd]))
+    out$Group[cor_sd] <- paste(
+      "Var/Cov:",
+      gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", dummy_parameter[cor_sd])
+    )
   }
 
-
   # extract group-names from random effects and clean random effects
 
   rand_effects <- startsWith(out$Cleaned_Parameter, "b[")
@@ -654,7 +748,11 @@ clean_parameters.mlm <- function(x, ...) {
     r_pars <- gsub("b\\[(.*) (.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
     if (identical(dots$version, 2)) {
       out$Level <- ""
-      r_levels <- gsub("b\\[(.*) (.*):(.*)\\]", "\\3", out$Cleaned_Parameter[rand_effects])
+      r_levels <- gsub(
+        "b\\[(.*) (.*):(.*)\\]",
+        "\\3",
+        out$Cleaned_Parameter[rand_effects]
+      )
       r_grps <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
       out$Group[rand_effects] <- r_grps
       out$Level[rand_effects] <- r_levels
@@ -664,7 +762,11 @@ clean_parameters.mlm <- function(x, ...) {
         out$Group[sd_cor] <- gsub("Var/Cov: (.*)", "\\1", out$Group[sd_cor])
       }
     } else {
-      re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
+      re_grp_level <- gsub(
+        "b\\[(.*) (.*):(.*)\\]",
+        "\\2",
+        out$Cleaned_Parameter[rand_effects]
+      )
       r_grps <- gsub("b\\[(.*) (.*)\\]", "\\1", out$Cleaned_Parameter[rand_effects])
       out$Group[rand_effects] <- sprintf("%s: %s", r_grps, re_grp_level)
     }
@@ -722,13 +824,30 @@ clean_parameters.mlm <- function(x, ...) {
 
 .clean_bamlss_params <- function(out) {
   out$Cleaned_Parameter <- out$Parameter
-  out$Cleaned_Parameter <- gsub("^(mu\\.p\\.|pi\\.p\\.)(.*)", "\\2", out$Cleaned_Parameter)
-  out$Cleaned_Parameter <- gsub("^(mu\\.s\\.|pi\\.s\\.)(.*)", "s\\(\\2\\)", out$Cleaned_Parameter)
-  out$Cleaned_Parameter <- gsub("^sigma\\.p\\.(.*)", "sigma \\(\\1\\)", out$Cleaned_Parameter)
+  out$Cleaned_Parameter <- gsub(
+    "^(mu\\.p\\.|pi\\.p\\.)(.*)",
+    "\\2",
+    out$Cleaned_Parameter
+  )
+  out$Cleaned_Parameter <- gsub(
+    "^(mu\\.s\\.|pi\\.s\\.)(.*)",
+    "s\\(\\2\\)",
+    out$Cleaned_Parameter
+  )
+  out$Cleaned_Parameter <- gsub(
+    "^sigma\\.p\\.(.*)",
+    "sigma \\(\\1\\)",
+    out$Cleaned_Parameter
+  )
   out$Cleaned_Parameter <- gsub("..", ".", out$Cleaned_Parameter, fixed = TRUE)
   out$Cleaned_Parameter <- gsub(".)", ")", out$Cleaned_Parameter, fixed = TRUE)
   out$Cleaned_Parameter <- gsub("(.", "(", out$Cleaned_Parameter, fixed = TRUE)
-  out$Cleaned_Parameter <- gsub(".Intercept.", "Intercept", out$Cleaned_Parameter, fixed = TRUE)
+  out$Cleaned_Parameter <- gsub(
+    ".Intercept.",
+    "Intercept",
+    out$Cleaned_Parameter,
+    fixed = TRUE
+  )
   out$Cleaned_Parameter <- gsub("(\\.$)", "", out$Cleaned_Parameter)
   out
 }
@@ -775,6 +894,6 @@ clean_parameters.mlm <- function(x, ...) {
     }
   }
 
-  class(out) <- c("clean_parameters", class(out))
+  class(out) <- unique(c("clean_parameters", class(out)))
   out
 }
