@@ -115,7 +115,9 @@ find_algorithm.glimML <- function(x, ...) {
 #' @export
 find_algorithm.BBmm <- function(x, ...) {
   method <- parse(text = safe_deparse(x$call))[[1]]$method
-  if (is.null(method)) method <- "BB-NR"
+  if (is.null(method)) {
+    method <- "BB-NR"
+  }
   list(algorithm = "extended likelihood", optimizer = method)
 }
 
@@ -170,7 +172,6 @@ find_algorithm.speedlm <- function(x, ...) {
 
 #' @export
 find_algorithm.blavaan <- function(x, ...) {
-  # installed?
   check_if_installed("blavaan")
 
   list(
