@@ -1,12 +1,11 @@
 #' @title Find model formula
 #' @name find_formula
 #'
-#' @description Returns the formula(s) for the different parts of a model
-#'  (like fixed or random effects, zero-inflated component, ...).
-#'  `formula_ok()` checks if a model formula has valid syntax
-#'  regarding writing `TRUE` instead of `T` inside `poly()`
-#'  and that no data names are used (i.e. no `data$variable`, but rather
-#'  `variable`).
+#' @description Returns the formula(s) for the different parts of a model (like
+#' fixed or random effects, zero-inflated component, ...). `formula_ok()` checks
+#' if a model formula has valid syntax regarding writing `TRUE` instead of `T`
+#' inside `poly()` and that no data names are used (i.e. no `data$variable`, but
+#' rather `variable`).
 #'
 #' @param verbose Toggle warnings.
 #' @param dichotomies Logical, if model is a `nestedLogit` objects, returns
@@ -34,53 +33,53 @@
 #' @param ... Currently not used.
 #' @inheritParams find_predictors
 #'
-#' @return A list of formulas that describe the model. For simple models,
-#'  only one list-element, `conditional`, is returned. For more complex
-#'  models, the returned list may have following elements:
+#' @return A list of formulas that describe the model. For simple models, only
+#' one list-element, `conditional`, is returned. For more complex models, the
+#' returned list may have following elements:
 #'
-#'  - `conditional`, the "fixed effects" part from the model (in the
-#'    context of fixed-effects or instrumental variable regression, also
-#'    called *regressors*) . One exception are `DirichletRegModel` models
-#'    from **DirichletReg**, which has two or three components,
-#'    depending on `model`.
+#' - `conditional`, the "fixed effects" part from the model (in the context of
+#'   fixed-effects or instrumental variable regression, also called
+#'   *regressors*) . One exception are `DirichletRegModel` models from
+#'   **DirichletReg**, which has two or three components, depending on `model`.
 #'
-#'  - `random`, the "random effects" part from the model (or the
-#'    `id` for gee-models and similar)
+#' - `random`, the "random effects" part from the model (or the `id` for
+#'   gee-models and similar)
 #'
-#'  - `zero_inflated`, the "fixed effects" part from the
-#'    zero-inflation component of the model
+#' - `zero_inflated`, the "fixed effects" part from the zero-inflation component
+#'   of the model. for models from *brms*, this component is named `zi`.
 #'
-#'  - `zero_inflated_random`, the "random effects" part from the
-#'    zero-inflation component of the model
+#' - `zero_inflated_random`, the "random effects" part from the zero-inflation
+#'   component of the model; for models from *brms*, this component is named
+#'   `zi_random`.
 #'
-#'  - `dispersion`, the dispersion formula
+#' - `dispersion`, the dispersion formula
 #'
-#'  - `instruments`, for fixed-effects or instrumental variable
-#'    regressions like `ivreg::ivreg()`, `lfe::felm()` or `plm::plm()`,
-#'    the instrumental variables
+#' - `instruments`, for fixed-effects or instrumental variable regressions like
+#'   `ivreg::ivreg()`, `lfe::felm()` or `plm::plm()`, the instrumental variables
 #'
-#'  - `cluster`, for fixed-effects regressions like
-#'    `lfe::felm()`, the cluster specification
+#' - `cluster`, for fixed-effects regressions like `lfe::felm()`, the cluster
+#'   specification
 #'
-#'  - `correlation`, for models with correlation-component like
-#'    `nlme::gls()`, the formula that describes the correlation structure
+#' - `correlation`, for models with correlation-component like `nlme::gls()`,
+#'   the formula that describes the correlation structure
 #'
-#'  - `scale`, for distributional models such as `mgcv::gaulss()` family fitted
-#'    with `mgcv::gam()`, the formula that describes the scale parameter
+#' - `scale`, for distributional models such as `mgcv::gaulss()` family fitted
+#'   with `mgcv::gam()`, the formula that describes the scale parameter
 #'
-#'  - `slopes`, for fixed-effects individual-slope models like
-#'    `feisr::feis()`, the formula for the slope parameters
+#' - `slopes`, for fixed-effects individual-slope models like `feisr::feis()`,
+#'   the formula for the slope parameters
 #'
-#'  - `precision`, for `DirichletRegModel` models from
-#'    **DirichletReg**, when parametrization (i.e. `model`) is
-#'    `"alternative"`.
+#' - `precision`, for `DirichletRegModel` models from **DirichletReg**, when
+#'   parametrization (i.e. `model`) is `"alternative"`.
 #'
-#'  - `bidrange`, for models of class `oohbchoice` (from package **DCchoice**),
-#'    which indicates the right-hand side of the bar (the bid-range).
+#' - `bidrange`, for models of class `oohbchoice` (from package **DCchoice**),
+#'   which indicates the right-hand side of the bar (the bid-range).
 #'
-#' @note For models of class `lme` or `gls` the correlation-component
-#'   is only returned, when it is explicitly defined as named argument
-#'   (`form`), e.g. `corAR1(form = ~1 | Mare)`
+#' For models from package **brms**, distributional parameters are also included.
+#'
+#' @note For models of class `lme` or `gls` the correlation-component is only
+#' returned, when it is explicitly defined as named argument (`form`), e.g.
+#' `corAR1(form = ~1 | Mare)`
 #'
 #' @examplesIf require("lme4", quietly = TRUE)
 #' data(mtcars)
@@ -99,12 +98,14 @@ find_formula <- function(x, ...) {
 
 #' @rdname find_formula
 #' @export
-formula_ok <- function(x,
-                       checks = "all",
-                       action = "warning",
-                       prefix_msg = NULL,
-                       verbose = TRUE,
-                       ...) {
+formula_ok <- function(
+  x,
+  checks = "all",
+  action = "warning",
+  prefix_msg = NULL,
+  verbose = TRUE,
+  ...
+) {
   # if a model, retrieve formula. else, treat x as formula
   if (is_model(x)) {
     f <- find_formula(x, verbose = FALSE)
@@ -166,6 +167,10 @@ formula_ok <- function(x,
 #' @export
 find_formula.default <- function(x, verbose = TRUE, ...) {
   f <- .safe(list(conditional = stats::formula(x)))
+  # if evaluation succeeds, we check in a next steps if dots are used
+  if (!is.null(f)) {
+    f$conditional <- .dot_formula(f$conditional, x, ...)
+  }
   .find_formula_return(f, verbose = verbose)
 }
 
@@ -257,7 +262,8 @@ find_formula.gam <- function(x, verbose = TRUE, ...) {
     if (is.list(f)) {
       mi <- .gam_family(x)
       if (!is.null(mi)) {
-        f <- switch(mi$family,
+        f <- switch(
+          mi$family,
           ziplss = list(conditional = f[[1]], zero_inflated = f[[2]]),
           # handle formula for location-scale models
           gaulss = list(conditional = f[[1]], scale = f[[2]]),
@@ -425,7 +431,6 @@ find_formula.deltaMethod <- find_formula.meta_random
 
 # Other models ----------------------------------------------
 
-
 #' @export
 find_formula.censReg <- find_formula.default
 
@@ -435,6 +440,17 @@ find_formula.maxLik <- find_formula.default
 #' @export
 find_formula.maxim <- find_formula.default
 
+#' @export
+find_formula.estimate_means <- function(x, verbose = TRUE, ...) {
+  find_formula(get_model(x), verbose = verbose, ...)
+}
+
+#' @export
+find_formula.estimate_slopes <- find_formula.estimate_means
+
+#' @export
+find_formula.estimate_contrasts <- find_formula.estimate_means
+
 
 #' @rdname find_formula
 #' @export
@@ -470,7 +486,9 @@ find_formula.systemfit <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.marginaleffects <- function(x, verbose = TRUE, ...) {
-  find_formula(attributes(x)$model, verbose = verbose, ...)
+  check_if_installed("marginaleffects", minimum_version = "0.29.0")
+  m <- marginaleffects::components(x, "model")
+  find_formula(m, verbose = verbose, ...)
 }
 
 
@@ -487,10 +505,12 @@ find_formula.selection <- function(x, verbose = TRUE, ...) {
     stats::as.formula(model_call$outcome),
     error = function(e) stats::as.formula(eval(model_call$outcome))
   )
-  f <- list(conditional = list(
-    selection = f_selection,
-    outcome = f_outcome
-  ))
+  f <- list(
+    conditional = list(
+      selection = f_selection,
+      outcome = f_outcome
+    )
+  )
   attr(f, "two_stage") <- TRUE
   .find_formula_return(f, verbose = verbose)
 }
@@ -654,6 +674,26 @@ find_formula.afex_aov <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+find_formula.lcmm <- function(x, verbose = TRUE, ...) {
+  model_call <- get_call(x)
+  f <- compact_list(list(
+    conditional = model_call$fixed,
+    random = model_call$random,
+    mixture = model_call$mixture,
+    classmb = model_call$classmb,
+    survival = model_call$survival
+  ))
+  .find_formula_return(f, verbose)
+}
+
+#' @export
+find_formula.externVar <- find_formula.lcmm
+
+#' @export
+find_formula.externX <- find_formula.lcmm
+
+
 #' @export
 find_formula.mira <- function(x, verbose = TRUE, ...) {
   .find_formula_return(find_formula(x$analyses[[1]]), verbose = verbose)
@@ -878,7 +918,10 @@ find_formula.pgmm <- find_formula.plm
 #' @export
 find_formula.felm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE))
+  f_parts <- trim_ws(unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  ))
 
   f.cond <- f_parts[1]
 
@@ -913,7 +956,10 @@ find_formula.felm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.mhurdle <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x)[[3]])
-  f_parts <- trim_ws(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE))
+  f_parts <- trim_ws(unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  ))
 
   f.zi <- paste0("~", f_parts[1])
 
@@ -930,10 +976,10 @@ find_formula.mhurdle <- function(x, verbose = TRUE, ...) {
   }
 
   # remove "empty" parts
-  if (f.zi == "~0") {
+  if (identical(f.zi, "~0")) {
     f.zi <- NULL
   }
-  if (f.ip == "~0") {
+  if (identical(f.ip, "~0")) {
     f.ip <- NULL
   }
 
@@ -949,7 +995,10 @@ find_formula.mhurdle <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.feglm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
+  f_parts <- unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  )
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -977,7 +1026,10 @@ find_formula.feglm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.fixest <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
+  f_parts <- unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  )
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -1017,7 +1069,10 @@ find_formula.oohbchoice <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.feis <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
+  f_parts <- unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  )
 
   f.cond <- trim_ws(f_parts[1])
   id <- parse(text = safe_deparse(x$call))[[1]]$id
@@ -1071,7 +1126,10 @@ find_formula.ivprobit <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.wbm <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
+  f_parts <- unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  )
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -1142,7 +1200,7 @@ find_formula.tobit <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.hurdle <- function(x, verbose = TRUE, ...) {
-  .zeroinf_formula(x, verbose = verbose)
+  .zeroinf_formula(x, verbose = verbose, ...)
 }
 
 #' @export
@@ -1154,7 +1212,7 @@ find_formula.zerotrunc <- find_formula.hurdle
 
 #' @export
 find_formula.zcpglm <- function(x, verbose = TRUE, ...) {
-  .zeroinf_formula(x, separator = "\\|\\|", verbose = verbose)
+  .zeroinf_formula(x, separator = "\\|\\|", verbose = verbose, ...)
 }
 
 
@@ -1163,9 +1221,16 @@ find_formula.zcpglm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.clmm2 <- function(x, verbose = TRUE, ...) {
   f <- compact_list(list(
-    conditional = stats::as.formula(safe_deparse(attr(x$location, "terms", exact = TRUE))),
+    conditional = stats::as.formula(safe_deparse(attr(
+      x$location,
+      "terms",
+      exact = TRUE
+    ))),
     scale = stats::as.formula(safe_deparse(attr(x$scale, "terms", exact = TRUE))),
-    random = stats::as.formula(paste0("~", parse(text = safe_deparse(x$call))[[1]]$random))
+    random = stats::as.formula(paste0(
+      "~",
+      parse(text = safe_deparse(x$call))[[1]]$random
+    ))
   ))
   .find_formula_return(f, verbose = verbose)
 }
@@ -1195,7 +1260,10 @@ find_formula.clm <- function(x, verbose = TRUE, ...) {
 #' @export
 find_formula.DirichletRegModel <- function(x, verbose = TRUE, ...) {
   f <- safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE), use.names = FALSE)
+  f_parts <- unlist(
+    strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE),
+    use.names = FALSE
+  )
 
   f.cond <- trim_ws(f_parts[1])
 
@@ -1278,8 +1346,12 @@ find_formula.glmmTMB <- function(x, verbose = TRUE, ...) {
 
   # extract fixed effects parts
   f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-  if (!is.null(f.zi)) f.zi <- stats::as.formula(.get_fixed_effects(f.zi))
-  if (!is.null(f.disp)) f.disp <- stats::as.formula(.get_fixed_effects(f.disp))
+  if (!is.null(f.zi)) {
+    f.zi <- stats::as.formula(.get_fixed_effects(f.zi))
+  }
+  if (!is.null(f.disp)) {
+    f.disp <- stats::as.formula(.get_fixed_effects(f.disp))
+  }
 
   f <- compact_list(list(
     conditional = f.cond,
@@ -1293,6 +1365,36 @@ find_formula.glmmTMB <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+find_formula.sdmTMB <- function(x, verbose = TRUE, ...) {
+  f.cond <- stats::formula(x)
+
+  # sanity check, we might have a list of formulas, only need first element
+  if (is.list(f.cond)) {
+    f.cond <- f.cond[[1]]
+  }
+
+  # extract random parts of formula
+  f.random <- lapply(.findbars(f.cond), function(.x) {
+    f <- safe_deparse(.x)
+    stats::as.formula(paste0("~", f))
+  })
+
+  if (length(f.random) == 1L) {
+    f.random <- f.random[[1]]
+  }
+
+  # extract fixed effects parts
+  f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
+
+  f <- compact_list(list(
+    conditional = f.cond,
+    random = f.random
+  ))
+  .find_formula_return(f, verbose = verbose)
+}
+
+
 #' @export
 find_formula.nlmerMod <- function(x, verbose = TRUE, ...) {
   f.random <- lapply(.findbars(stats::formula(x)), function(.x) {
@@ -1304,8 +1406,15 @@ find_formula.nlmerMod <- function(x, verbose = TRUE, ...) {
     f.random <- f.random[[1]]
   }
 
-  f.cond <- .nobars(stats::as.formula(gsub("(.*)(~)(.*)~(.*)", "\\1\\2\\4", safe_deparse(stats::formula(x)))))
-  f.nonlin <- stats::as.formula(paste0("~", trim_ws(gsub("(.*)~(.*)~(.*)", "\\2", safe_deparse(stats::formula(x))))))
+  f.cond <- .nobars(stats::as.formula(gsub(
+    "(.*)(~)(.*)~(.*)",
+    "\\1\\2\\4",
+    safe_deparse(stats::formula(x))
+  )))
+  f.nonlin <- stats::as.formula(paste0(
+    "~",
+    trim_ws(gsub("(.*)~(.*)~(.*)", "\\2", safe_deparse(stats::formula(x))))
+  ))
 
   f <- compact_list(list(
     conditional = f.cond,
@@ -1470,7 +1579,10 @@ find_formula.mixor <- function(x, verbose = TRUE, ...) {
   if (is.null(f_rs)) {
     fmr <- f_id
   } else {
-    f_rs <- trim_ws(unlist(strsplit(safe_deparse(x$call$formula[[3]]), "+", fixed = TRUE), use.names = FALSE))[f_rs]
+    f_rs <- trim_ws(unlist(
+      strsplit(safe_deparse(x$call$formula[[3]]), "+", fixed = TRUE),
+      use.names = FALSE
+    ))[f_rs]
     fmr <- paste(f_rs, "|", f_id)
   }
 
@@ -1694,126 +1806,30 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
   f_cond <- stats::as.formula(.get_fixed_effects(f_cond))
 
-  f_zi <- f$pforms$zi
-  f_zirandom <- NULL
+  dpar_formulas <- list()
+  dpar_random_formulas <- list()
 
-  # auxiliary
-  f_sigma <- f$pforms$sigma
-  f_mu <- f$pforms$mu
-  f_nu <- f$pforms$nu
-  f_shape <- f$pforms$shape
-  f_alpha <- f$pforms$alpha
-  f_beta <- f$pforms$beta
-  f_phi <- f$pforms$phi
-  f_xi <- f$pforms$xi
-  f_hu <- f$pforms$hu
-  f_ndt <- f$pforms$ndt
-  f_zoi <- f$pforms$zoi
-  f_coi <- f$pforms$coi
-  f_kappa <- f$pforms$kappa
-  f_bias <- f$pforms$bias
-  f_bs <- f$pforms$bs
-
-  # brms formulas can also have custom names, based on variable names, e.g.:
-  # brm(
-  #   bf(carb ~ gear * vs) + lf(disc ~ 0 + mo(cyl)),
-  #   data = mtcars,
-  #   family = cumulative("probit"),
-  # )
-  # the lf() part is in "f$pforms" with name "disc".
-  #
-  # we therefore need to check whether we have additional names not yet covered
-  # by the above exceptions.
-
-  # auxiliary names
-  auxiliary_names <- .brms_aux_elements()
-
-  # check if any further pforms exist
-  if (all(names(f$pforms) %in% auxiliary_names)) {
-    f_custom <- NULL
-  } else {
-    custom_names <- setdiff(names(f$pforms), auxiliary_names)
-    if (length(custom_names)) {
-      f_custom <- f$pforms[custom_names]
-    }
-  }
-
-  f_sigmarandom <- NULL
-  f_betarandom <- NULL
-
-
-  # split zero-inflated fixed from zero-inflated random
-
-  if (!is_empty_object(f_zi)) {
-    f_zirandom <- lapply(.findbars(f_zi), function(.x) {
-      f <- safe_deparse(.x)
-      stats::as.formula(paste0("~", f))
+  for (aux in names(f$pforms)) {
+    f_aux <- f$pforms[[aux]]
+    f_aux_random <- lapply(.findbars(f_aux), function(.x) {
+      fx <- safe_deparse(.x)
+      stats::as.formula(paste0("~", fx))
     })
-
-    if (length(f_zirandom) == 1L) {
-      f_zirandom <- f_zirandom[[1]]
+    if (length(f_aux_random) == 1L) {
+      f_aux_random <- f_aux_random[[1]]
     }
-
-    f_zi <- stats::as.formula(paste0("~", safe_deparse(f_zi[[3L]])))
-    f_zi <- stats::as.formula(.get_fixed_effects(f_zi))
+    f_aux <- stats::as.formula(paste0("~", safe_deparse(f_aux[[3L]])))
+    f_aux <- stats::as.formula(.get_fixed_effects(f_aux))
+    # add formula to list of custom formulas
+    dpar_formulas[[aux]] <- f_aux
+    dpar_random_formulas[[paste0(aux, "_random")]] <- f_aux_random
   }
 
-
-  # split sigma fixed from sigma random
-
-  if (!is_empty_object(f_sigma)) {
-    f_sigmarandom <- lapply(.findbars(f_sigma), function(.x) {
-      f <- safe_deparse(.x)
-      stats::as.formula(paste0("~", f))
-    })
-
-    if (length(f_sigmarandom) == 1L) {
-      f_sigmarandom <- f_sigmarandom[[1]]
-    }
-
-    f_sigma <- stats::as.formula(paste0("~", safe_deparse(f_sigma[[3L]])))
-    f_sigma <- stats::as.formula(.get_fixed_effects(f_sigma))
-  }
-
-
-  # split beta fixed from beta random
-
-  if (!is_empty_object(f_beta)) {
-    f_betarandom <- lapply(.findbars(f_beta), function(.x) {
-      f <- safe_deparse(.x)
-      stats::as.formula(paste0("~", f))
-    })
-
-    if (length(f_betarandom) == 1L) {
-      f_betarandom <- f_betarandom[[1]]
-    }
-
-    f_beta <- stats::as.formula(paste0("~", safe_deparse(f_beta[[3L]])))
-    f_beta <- stats::as.formula(.get_fixed_effects(f_beta))
-  }
-
-
-  compact_list(c(list(
-    conditional = f_cond,
-    random = f_random,
-    zero_inflated = f_zi,
-    zero_inflated_random = f_zirandom,
-    sigma = f_sigma,
-    sigma_random = f_sigmarandom,
-    beta = f_beta,
-    beta_random = f_betarandom,
-    shape = f_shape,
-    phi = f_phi,
-    hurdle = f_hu,
-    mu = f_mu,
-    nu = f_nu,
-    ndt = f_ndt,
-    bs = f_bs,
-    bias = f_bias,
-    zero_one_inflated = f_zoi,
-    conditional_one_inflated = f_coi,
-    kappa = f_kappa
-  ), f_custom))
+  compact_list(c(
+    list(conditional = f_cond, random = f_random),
+    dpar_formulas,
+    dpar_random_formulas
+  ))
 }
 
 
@@ -1839,7 +1855,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
 # Find formula for zero-inflated regressions, where
 # zero-inflated part is separated by | from count part
-.zeroinf_formula <- function(x, separator = "\\|", verbose = TRUE) {
+.zeroinf_formula <- function(x, separator = "\\|", verbose = TRUE, ...) {
   f <- tryCatch(stats::formula(x), error = function(x) NULL)
 
   if (is.null(f)) {
@@ -1858,7 +1874,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
   ## TODO could be extended to all find_formula()
 
   # fix dot-formulas
-  c.form <- .dot_formula(f = c.form, model = x)
+  c.form <- .dot_formula(f = c.form, model = x, ...)
 
   # fix dot-formulas
   zi.form <- tryCatch(
@@ -1875,7 +1891,6 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     }
   )
 
-
   f <- compact_list(list(conditional = c.form, zero_inflated = zi.form))
   .find_formula_return(f, verbose = verbose)
 }
@@ -1883,7 +1898,13 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
 # try to guess "full" formula for dot-abbreviation, e.g.
 # lm(mpg ~., data = mtcars)
-.dot_formula <- function(f, model) {
+.dot_formula <- function(f, model, ...) {
+  # skip_dot_formula = TRUE is only internally used, to avoid infinite loops
+  # when `find_formula()` is called from `get_data()`
+  if (isTRUE(list(...)$skip_dot_formula)) {
+    return(f)
+  }
+
   # fix dot-formulas
   tryCatch(
     {
@@ -1921,10 +1942,14 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     f <- list(f)
   }
   len <- length(f)
-  keep <- vapply(f, function(i) {
-    i <- gsub("(~1| | \\|)", "", deparse(i))
-    !any(grepl("(Xr\\.\\d|g\\.\\d)", i) | i %in% c("Xr", "g"))
-  }, TRUE)
+  keep <- vapply(
+    f,
+    function(i) {
+      i <- gsub("(~1| | \\|)", "", deparse(i))
+      !any(grepl("(Xr\\.\\d|g\\.\\d)", i) | i %in% c("Xr", "g"))
+    },
+    TRUE
+  )
   f <- compact_list(f[keep])
   # exceptions, if random effect is named Xr
   if (!length(f) && len > 1L) {
@@ -1947,7 +1972,12 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 }
 
 
-.check_formula_for_T <- function(f, action = "warning", prefix_msg = NULL, verbose = TRUE) {
+.check_formula_for_T <- function(
+  f,
+  action = "warning",
+  prefix_msg = NULL,
+  verbose = TRUE
+) {
   f <- safe_deparse(f[[1]])
 
   if (is_empty_object(f)) {
@@ -1973,7 +2003,12 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 # in various functions throughout the easystats packages. We warn the user
 # here...
 
-.check_formula_for_dollar <- function(f, action = "warning", prefix_msg = NULL, verbose = TRUE) {
+.check_formula_for_dollar <- function(
+  f,
+  action = "warning",
+  prefix_msg = NULL,
+  verbose = TRUE
+) {
   if (is_empty_object(f)) {
     return(TRUE)
   }
@@ -1988,7 +2023,10 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
         prefix_msg,
         paste0(
           "Using `$` in model formulas can produce unexpected results. Specify your model using the `data` argument instead.", # nolint
-          "\n  Try: ", fc$formula, ", data = ", fc$data
+          "\n  Try: ",
+          fc$formula,
+          ", data = ",
+          fc$data
         )
       )
       format_alert(msg, type = action)
@@ -2003,7 +2041,13 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 # cause problems in various functions throughout the easystats packages. We
 # warn the user here...
 
-.check_formula_index_df <- function(f, x, action = "warning", prefix_msg = NULL, verbose = TRUE) {
+.check_formula_index_df <- function(
+  f,
+  x,
+  action = "warning",
+  prefix_msg = NULL,
+  verbose = TRUE
+) {
   if (is_empty_object(f)) {
     return(TRUE)
   }
@@ -2025,7 +2069,12 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 # formulas with non-syntactic names, where backticks are used, may cause
 # problems. warn user here
 
-.check_formula_backticks <- function(f, action = "warning", prefix_msg = NULL, verbose = TRUE) {
+.check_formula_backticks <- function(
+  f,
+  action = "warning",
+  prefix_msg = NULL,
+  verbose = TRUE
+) {
   if (is_empty_object(f)) {
     return(TRUE)
   }
@@ -2060,14 +2109,22 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
   pattern <- "[\\s*+:()|^,\\-\\/]" # was: "[\\s\\*\\+:\\-\\|/\\(\\)\\^,]"
 
-  parts <- trim_ws(unlist(strsplit(split = pattern, x = LHS, perl = TRUE), use.names = FALSE))
+  parts <- trim_ws(unlist(
+    strsplit(split = pattern, x = LHS, perl = TRUE),
+    use.names = FALSE
+  ))
   d_LHS <- unique(gsub("(.*)\\$(.*)", "\\1", grep("(.*)\\$(.*)", parts, value = TRUE)))
 
-  parts <- trim_ws(unlist(strsplit(split = pattern, x = RHS, perl = TRUE), use.names = FALSE))
+  parts <- trim_ws(unlist(
+    strsplit(split = pattern, x = RHS, perl = TRUE),
+    use.names = FALSE
+  ))
   d_RHS <- unique(gsub("(.*)\\$(.*)", "\\1", grep("(.*)\\$(.*)", parts, value = TRUE)))
 
   if (n_unique(c(d_LHS, d_RHS)) > 1L) {
-    format_error("Multiple data objects present in formula. Specify your model using the `data` argument instead.")
+    format_error(
+      "Multiple data objects present in formula. Specify your model using the `data` argument instead."
+    )
   } else {
     d <- unique(d_RHS)
   }
