@@ -49,6 +49,24 @@ find_response.default <- function(x, combine = TRUE, ...) {
 }
 
 
+#' @export
+find_response.insight_formula <- function(x, combine = TRUE, ...) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  # this is for multivariate response models,
+  # where we have a list of formulas
+  if (is_multivariate(x)) {
+    resp <- unlist(lapply(x, function(i) safe_deparse(i$conditional[[2L]])))
+  } else {
+    resp <- safe_deparse(x$conditional[[2L]])
+  }
+
+  check_cbind(resp, combine, model = NULL)
+}
+
+
 #' @export
 find_response.brmsfit <- function(x, combine = TRUE, ...) {
   f <- find_formula(x, verbose = FALSE)
@@ -62,8 +80,19 @@ find_response.brmsfit <- function(x, combine = TRUE, ...) {
   if (is_multivariate(f)) {
     resp <- unlist(lapply(f, function(i) {
       resp_formula <- safe_deparse(i$conditional[[2L]])
+      # passing "find_random = TRUE" to the function will return only the
+      # left part of the response, if it contains "|". This is required when
+      # called from `find_random()`.
       if (grepl("|", resp_formula, fixed = TRUE)) {
-        resp_formula <- all.vars(i$conditional[[2L]])
+        if (isTRUE(list(...)$find_random)) {
+          # if we have a response with "|", we want to return only the left part
+          resp_formula <- trim_ws(gsub("(.*)\\|(.*)", "\\1", resp_formula))
+          # just for the records, an alternative way to do this:
+          # resp_formula <- trim_ws(sub("^([^|]+)\\|.*", "\\1", resp_formula))
+        } else {
+          # if we do not want to look for random effects, we return the full response
+          resp_formula <- all.vars(i$conditional[[2L]])
+        }
       }
       resp_formula
     }))
@@ -103,10 +132,18 @@ find_response.bfsl <- function(x, combine = TRUE, ...) {
 #' @export
 find_response.selection <- function(x, combine = TRUE, ...) {
   f <- find_formula(x, verbose = FALSE)
-  resp <- c(
-    safe_deparse(f$conditional$selection[[2L]]),
-    safe_deparse(f$conditional$outcome[[2L]])
-  )
+  resp <- safe_deparse(f$conditional$selection[[2L]])
+  # "outcome" can be a list, so we need to check for that
+  if (is.list(f$conditional$outcome)) {
+    additional_resp <- unlist(
+      lapply(f$conditional$outcome, function(i) safe_deparse(i[[2L]])),
+      use.names = FALSE
+    )
+  } else {
+    additional_resp <- safe_deparse(f$conditional$outcome[[2L]])
+  }
+  resp <- c(resp, additional_resp)
+
   check_cbind(resp, combine, model = x)
 }
 
@@ -119,7 +156,10 @@ find_response.mediate <- function(x, combine = TRUE, ...) {
     return(NULL)
   }
 
-  resp <- c(safe_deparse(f$mediator$conditional[[2L]]), safe_deparse(f$outcome$conditional[[2L]]))
+  resp <- c(
+    safe_deparse(f$mediator$conditional[[2L]]),
+    safe_deparse(f$outcome$conditional[[2L]])
+  )
   check_cbind(resp, combine, model = x)
 }
 
@@ -144,20 +184,22 @@ find_response.workflow <- function(x, combine = TRUE, ...) {
 }
 
 
-#' @rdname find_response
 #' @export
-find_response.mjoint <- function(x, combine = TRUE, component = c("conditional", "survival", "all"), ...) {
-  component <- match.arg(component)
+find_response.mjoint <- function(x, combine = TRUE, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "survival", "all"))
   f <- find_formula(x, verbose = FALSE)
 
   if (is.null(f)) {
     return(NULL)
   }
 
-  conditional <- unlist(lapply(f[startsWith(names(f), "conditional")], function(i) safe_deparse(i[[2L]])))
+  conditional <- unlist(lapply(f[startsWith(names(f), "conditional")], function(i) {
+    safe_deparse(i[[2L]])
+  }))
   survial <- safe_deparse(f$survival[[2L]])
 
-  resp <- switch(component,
+  resp <- switch(
+    component,
     conditional = conditional,
     survial = survial,
     all = c(conditional, survial)
@@ -169,11 +211,8 @@ find_response.mjoint <- function(x, combine = TRUE, component = c("conditional",
 
 #' @rdname find_response
 #' @export
-find_response.joint <- function(x,
-                                combine = TRUE,
-                                component = c("conditional", "survival", "all"),
-                                ...) {
-  component <- match.arg(component)
+find_response.joint <- function(x, combine = TRUE, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "survival", "all"))
   f <- find_formula(x, verbose = FALSE)
 
   if (is.null(f)) {
@@ -183,7 +222,8 @@ find_response.joint <- function(x,
   conditional <- safe_deparse(f$conditional[[2L]])
   survial <- safe_deparse(f$survival[[2L]])
 
-  resp <- switch(component,
+  resp <- switch(
+    component,
     conditional = conditional,
     survial = survial,
     all = c(conditional, survial)
@@ -195,7 +235,6 @@ find_response.joint <- function(x,
 
 # utils ---------------------
 
-
 # should not be called for brms-models!
 check_cbind <- function(resp, combine, model) {
   if (any(.string_contains("|", resp))) {
@@ -204,6 +243,7 @@ check_cbind <- function(resp, combine, model) {
     r2 <- trim_ws(sub("(.*)\\|(.*)\\(([^,)]*).*", "\\3", resp))
     # check for "resp_thres" and similar patterns
     r_resp <- trim_ws(unlist(strsplit(resp, "|", fixed = TRUE))[2])
+    # fmt: skip
     if (grepl("^(resp_thres|thres|resp_weights|weights|resp_se|se|resp_cens|cens)", r_resp)) {
       r3 <- trim_ws(sub("=", "", sub("(.*)\\(([^=)]*)(.*)\\)", "\\3", r_resp), fixed = TRUE))
       numeric_values <- suppressWarnings(as.numeric(r2))
@@ -238,7 +278,8 @@ check_cbind <- function(resp, combine, model) {
     # "all.vars()" will take care of extracting the correct variables.
     resp_combined_string <- paste(resp, collapse = "+")
     # create an expression, so all.vars() works similar like for formulas
-    resp_combined <- tryCatch(all.vars(str2lang(resp_combined_string)),
+    resp_combined <- tryCatch(
+      all.vars(str2lang(resp_combined_string)),
       error = function(e) resp_combined_string
     )
     # if we do not want to combine, or if we just have one variable as
