@@ -125,24 +125,26 @@
 #' @return A data frame. Note that `format_table()` converts all columns
 #' into character vectors!
 #' @export
-format_table <- function(x,
-                         pretty_names = TRUE,
-                         stars = FALSE,
-                         stars_only = FALSE,
-                         digits = 2,
-                         ci_width = "auto",
-                         ci_brackets = TRUE,
-                         ci_digits = digits,
-                         p_digits = 3,
-                         rope_digits = digits,
-                         ic_digits = 1,
-                         zap_small = FALSE,
-                         preserve_attributes = FALSE,
-                         exact = TRUE,
-                         use_symbols = getOption("insight_use_symbols", FALSE),
-                         select = NULL,
-                         verbose = TRUE,
-                         ...) {
+format_table <- function(
+  x,
+  pretty_names = TRUE,
+  stars = FALSE,
+  stars_only = FALSE,
+  digits = 2,
+  ci_width = "auto",
+  ci_brackets = TRUE,
+  ci_digits = digits,
+  p_digits = 3,
+  rope_digits = digits,
+  ic_digits = 1,
+  zap_small = FALSE,
+  preserve_attributes = FALSE,
+  exact = TRUE,
+  use_symbols = getOption("insight_use_symbols", FALSE),
+  select = NULL,
+  verbose = TRUE,
+  ...
+) {
   # validation check
   if (is.null(x) || (is.data.frame(x) && nrow(x) == 0)) {
     if (isTRUE(verbose)) {
@@ -152,11 +154,21 @@ format_table <- function(x,
   }
 
   # check if user supplied digits attributes
-  if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
-  if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", digits)
-  if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
-  if (missing(rope_digits)) rope_digits <- .additional_arguments(x, "rope_digits", digits)
-  if (missing(ic_digits)) ic_digits <- .additional_arguments(x, "ic_digits", 1)
+  if (missing(digits)) {
+    digits <- .additional_arguments(x, "digits", 2)
+  }
+  if (missing(ci_digits)) {
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
+  }
+  if (missing(p_digits)) {
+    p_digits <- .additional_arguments(x, "p_digits", 3)
+  }
+  if (missing(rope_digits)) {
+    rope_digits <- .additional_arguments(x, "rope_digits", digits)
+  }
+  if (missing(ic_digits)) {
+    ic_digits <- .additional_arguments(x, "ic_digits", 1)
+  }
 
   # find name of coefficient, if present
   coef_column_name <- attributes(x)$coef_name
@@ -171,7 +183,6 @@ format_table <- function(x,
   att <- attributes(x)
   x <- as.data.frame(x, stringsAsFactors = FALSE)
 
-
   # Format parameters names ----
   if (pretty_names && !is.null(att$pretty_names)) {
     shared <- intersect(x$Parameter, names(att$pretty_names))
@@ -180,32 +191,38 @@ format_table <- function(x,
   }
 
   # Format specific columns ----
-  if ("n_Obs" %in% names(x)) x$n_Obs <- format_value(x$n_Obs, protect_integers = TRUE)
-  if ("n_Missing" %in% names(x)) x$n_Missing <- format_value(x$n_Missing, protect_integers = TRUE)
-
+  if ("n_Obs" %in% names(x)) {
+    x$n_Obs <- format_value(x$n_Obs, protect_integers = TRUE)
+  }
+  if ("n_Missing" %in% names(x)) {
+    x$n_Missing <- format_value(x$n_Missing, protect_integers = TRUE)
+  }
 
   # Format df columns ----
   x <- .format_df_columns(x)
 
-
   # Format special anova columns ----
   x <- .format_aov_columns(x)
 
-
   # Format frequentist stats ----
   x <- .format_freq_stats(x)
 
-
   # P values ----
   x <- .format_p_values(x, stars = stars, p_digits = p_digits, stars_only = stars_only)
 
-
   # Main CI and Prediction Intervals ----
   x <- .format_main_ci_columns(x, att, ci_digits, zap_small, ci_width, ci_brackets)
-  x <- .format_main_ci_columns(x, att, ci_digits, zap_small, ci_width, ci_brackets, ci_name = "PI")
+  x <- .format_main_ci_columns(
+    x,
+    att,
+    ci_digits,
+    zap_small,
+    ci_width,
+    ci_brackets,
+    ci_name = "PI"
+  )
   x <- .format_broom_ci_columns(x, ci_digits, zap_small, ci_width, ci_brackets)
 
-
   # Misc / Effect Sizes
   x <- .format_effectsize_columns(x, use_symbols)
 
@@ -214,11 +231,9 @@ format_table <- function(x,
   x <- out$x
   other_ci_colname <- out$other_ci_colname
 
-
   # Standardized ----
   x <- .format_std_columns(x, other_ci_colname, digits, zap_small)
 
-
   # Partial ----
   x[names(x)[endsWith(names(x), "_partial")]] <- format_value(
     x[names(x)[endsWith(names(x), "_partial")]],
@@ -229,10 +244,10 @@ format_table <- function(x,
     " (partial)"
   )
 
-
   # metafor ----
-  if ("Weight" %in% names(x)) x$Weight <- format_value(x$Weight, protect_integers = TRUE)
-
+  if ("Weight" %in% names(x)) {
+    x$Weight <- format_value(x$Weight, protect_integers = TRUE)
+  }
 
   # Bayesian ---
   x <- .format_bayes_columns(
@@ -245,21 +260,19 @@ format_table <- function(x,
     exact = exact
   )
 
-
   # rename performance columns
   x <- .format_performance_columns(x, digits, ic_digits, zap_small, use_symbols)
 
-
   # format symbols in column names, if any left
   x <- .format_symbols(x, use_symbols)
 
-
   # Format remaining columns
   other_cols <- names(x)[vapply(x, is.numeric, logical(1))]
   x[other_cols[other_cols %in% names(x)]] <- format_value(
     x[other_cols[other_cols %in% names(x)]],
     digits = digits,
-    zap_small = zap_small
+    zap_small = zap_small,
+    protect_integers = TRUE
   )
 
   # SEM links
@@ -268,7 +281,11 @@ format_table <- function(x,
 
     col_position <- which(names(x) == "To")
     # Replace at initial position
-    x <- x[c(names(x)[0:(col_position - 1)], "Link", names(x)[col_position:(length(names(x)) - 1)])]
+    x <- x[c(
+      names(x)[0:(col_position - 1)],
+      "Link",
+      names(x)[col_position:(length(names(x)) - 1)]
+    )]
     x$To <- x$Operator <- x$From <- NULL
   }
 
@@ -295,7 +312,6 @@ format_table <- function(x,
 
 # sub-routines ---------------
 
-
 # Format various p-values, coming from different easystats-packages
 # like bayestestR (p_ROPE, p_MAP) or performance (p_Chi2)
 
@@ -322,11 +338,15 @@ format_table <- function(x,
     }
   }
 
-  for (stats in c(
+  # fmt: skip
+  statistic_names <- c(
     "p_CochransQ", "p_Omnibus", "p_Chi2", "p_Baseline", "p_RMSEA", "p_ROPE",
     "p_MAP", "Wu_Hausman_p", "Sargan_p", "p_Omega2", "p_LR", "p_calibrated",
-    "weak_instruments_p"
-  )) {
+    "weak_instruments_p", "p_Superiority", "p_Inferiority", "p_Equivalence",
+    "p_Nonsuperiority", "p_Noninferiority"
+  )
+
+  for (stats in statistic_names) {
     if (stats %in% names(x)) {
       x[[stats]] <- format_p(
         x[[stats]],
@@ -352,9 +372,13 @@ format_table <- function(x,
 
 .format_df_columns <- function(x) {
   # generic df
-  if ("df" %in% names(x)) x$df <- format_value(x$df, protect_integers = TRUE)
+  if ("df" %in% names(x)) {
+    x$df <- format_value(x$df, protect_integers = TRUE)
+  }
   # residual df
-  if ("df_residual" %in% names(x)) x$df_residual <- format_value(x$df_residual, protect_integers = TRUE)
+  if ("df_residual" %in% names(x)) {
+    x$df_residual <- format_value(x$df_residual, protect_integers = TRUE)
+  }
   names(x)[names(x) == "df_residual"] <- "df"
   # df for errors
   if ("df_error" %in% names(x)) {
@@ -391,10 +415,17 @@ format_table <- function(x,
   names(x)[names(x) == "Cohens_g"] <- "Cohen's g"
   names(x)[names(x) == "Cohens_f"] <- "Cohen's f"
   names(x)[names(x) == "Cohens_f_partial"] <- "Cohen's f (partial)"
+  names(x)[names(x) == "Cohens_d_robust"] <- "Robust Cohen's d"
+  names(x)[names(x) == "Cohens_d_robust_CI_low"] <- "Robust Cohen's d_CI_low"
+  names(x)[names(x) == "Cohens_d__robust_CI_high"] <- "Robust Cohen's d_CI_high"
+  names(x)[names(x) == "d_partial"] <- "d (partial)"
+  names(x)[names(x) == "d_marginal"] <- "d (marginal)"
   names(x)[names(x) == "Cramers_v"] <- "Cramer's V"
   names(x)[names(x) == "Cramers_v_adjusted"] <- "Cramer's V (adj.)"
   names(x)[names(x) == "r_rank_biserial"] <- "r (rank biserial)"
   names(x)[names(x) == "Hedges_g"] <- "Hedges' g"
+  names(x)[names(x) == "Hedges_g_CI_low"] <- "Hedges' g_CI_low"
+  names(x)[names(x) == "Hedges_g_CI_high"] <- "Hedges' g_CI_high"
   names(x)[names(x) == "Mahalanobis_D"] <- "Mahalanobis' D"
   names(x)[names(x) == "Pearsons_c"] <- "Pearson's C"
   names(x)[names(x) == "Kendalls_W"] <- "Kendall's W"
@@ -490,20 +521,26 @@ format_table <- function(x,
     }
   }
 
-  if ("Success" %in% names(x)) x$Success <- format_value(x$Success, protect_integers = TRUE)
-  if ("Trials" %in% names(x)) x$Trials <- format_value(x$Trials, protect_integers = TRUE)
+  if ("Success" %in% names(x)) {
+    x$Success <- format_value(x$Success, protect_integers = TRUE)
+  }
+  if ("Trials" %in% names(x)) {
+    x$Trials <- format_value(x$Trials, protect_integers = TRUE)
+  }
 
   x
 }
 
 
-.format_main_ci_columns <- function(x,
-                                    att,
-                                    ci_digits,
-                                    zap_small,
-                                    ci_width = "auto",
-                                    ci_brackets = TRUE,
-                                    ci_name = "CI") {
+.format_main_ci_columns <- function(
+  x,
+  att,
+  ci_digits,
+  zap_small,
+  ci_width = "auto",
+  ci_brackets = TRUE,
+  ci_name = "CI"
+) {
   # Main CI
   ci_low <- names(x)[grep(paste0("^", ci_name, "_low"), names(x))]
   ci_high <- names(x)[grep(paste0("^", ci_name, "_high"), names(x))]
@@ -525,7 +562,9 @@ format_table <- function(x,
       # when we have multiple ci-levels, column names can be "CI_low_0.8" or
       # "CI_low_0.95" etc. - this is handled here, if we have no ci-attribute
       ptrn <- paste0("((?<=", ci_name, "_low_)|(?<=", ci_name, "_high_))\\d*\\.?\\d*")
-      if (all(grepl(ptrn, ci_low, perl = TRUE)) && all(grepl(ptrn, ci_high, perl = TRUE))) {
+      if (
+        all(grepl(ptrn, ci_low, perl = TRUE)) && all(grepl(ptrn, ci_high, perl = TRUE))
+      ) {
         m <- regexpr(ptrn, ci_low, perl = TRUE)
         ci_value <- as.numeric(regmatches(ci_low, m))
       } else {
@@ -544,7 +583,6 @@ format_table <- function(x,
       ci_colname <- sprintf("%g%% %s", ci_value * 100, ci_name)
     }
 
-
     # Get characters to align the CI
     for (i in seq_along(ci_colname)) {
       x[[ci_low[i]]] <- format_ci(
@@ -565,12 +603,18 @@ format_table <- function(x,
     }
   }
 
-
   x
 }
 
 
-.format_other_ci_columns <- function(x, att, ci_digits, zap_small, ci_width = "auto", ci_brackets = TRUE) {
+.format_other_ci_columns <- function(
+  x,
+  att,
+  ci_digits,
+  zap_small,
+  ci_width = "auto",
+  ci_brackets = TRUE
+) {
   other_ci_low <- names(x)[endsWith(names(x), "_CI_low")]
   other_ci_high <- names(x)[endsWith(names(x), "_CI_high")]
   if (length(other_ci_low) >= 1 && length(other_ci_low) == length(other_ci_high)) {
@@ -578,11 +622,23 @@ format_table <- function(x,
 
     # CI percentage
     if (length(other) == 1 && !is.null(att[[paste0("ci_", other)]])) {
-      other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(att[[paste0("ci_", other)]])) * 100)
+      other_ci_colname <- sprintf(
+        "%s %g%% CI",
+        other,
+        unique(stats::na.omit(att[[paste0("ci_", other)]])) * 100
+      )
     } else if (!is.null(att[["ci"]])) {
-      other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(att[["ci"]])) * 100)
+      other_ci_colname <- sprintf(
+        "%s %g%% CI",
+        other,
+        unique(stats::na.omit(att[["ci"]])) * 100
+      )
     } else if (length(other) == 1 && paste0(other, "_CI") %in% colnames(x)) {
-      other_ci_colname <- sprintf("%s %g%% CI", other, unique(stats::na.omit(x[[paste0(other, "_CI")]])) * 100)
+      other_ci_colname <- sprintf(
+        "%s %g%% CI",
+        other,
+        unique(stats::na.omit(x[[paste0(other, "_CI")]])) * 100
+      )
     } else {
       other_ci_colname <- paste(other, " CI")
     }
@@ -617,11 +673,13 @@ format_table <- function(x,
 }
 
 
-.format_broom_ci_columns <- function(x,
-                                     ci_digits,
-                                     zap_small,
-                                     ci_width = "auto",
-                                     ci_brackets = TRUE) {
+.format_broom_ci_columns <- function(
+  x,
+  ci_digits,
+  zap_small,
+  ci_width = "auto",
+  ci_brackets = TRUE
+) {
   if (!any(grepl("conf.low", names(x), fixed = TRUE))) {
     return(x)
   }
@@ -666,6 +724,7 @@ format_table <- function(x,
     names(x)[names(x) == "ROPE_low"] <- "ROPE"
     x$ROPE_CI <- NULL
   }
+
   x
 }
 
@@ -684,7 +743,11 @@ format_table <- function(x,
   }
 
   x[std_cols] <- format_value(x[std_cols], digits = digits, zap_small = zap_small)
-  names(x)[names(x) == std_cols] <- .replace_words(std_cols, "Std_Coefficient", "Std. Coef.")
+  names(x)[names(x) == std_cols] <- .replace_words(
+    std_cols,
+    "Std_Coefficient",
+    "Std. Coef."
+  )
   names(x)[names(x) == std_cols] <- .replace_words(std_cols, "Std_Median", "Std. Median")
   names(x)[names(x) == std_cols] <- .replace_words(std_cols, "Std_Mean", "Std. Mean")
   names(x)[names(x) == std_cols] <- .replace_words(std_cols, "Std_MAP", "Std. MAP")
@@ -699,13 +762,15 @@ format_table <- function(x,
 }
 
 
-.format_bayes_columns <- function(x,
-                                  zap_small,
-                                  stars = FALSE,
-                                  rope_digits = 2,
-                                  ci_width = "auto",
-                                  ci_brackets = TRUE,
-                                  exact = TRUE) {
+.format_bayes_columns <- function(
+  x,
+  zap_small,
+  stars = FALSE,
+  rope_digits = 2,
+  ci_width = "auto",
+  ci_brackets = TRUE,
+  exact = TRUE
+) {
   # Specify stars for which column
   if (is.character(stars)) {
     starlist <- list(BF = FALSE, pd = FALSE)
@@ -719,19 +784,49 @@ format_table <- function(x,
     x$BF <- format_bf(x$BF, name = NULL, stars = starlist[["BF"]], exact = exact)
   }
   if ("log_BF" %in% names(x)) {
-    x$log_BF <- format_bf(exp(x$log_BF), name = NULL, stars = starlist[["BF"]], exact = exact)
+    x$log_BF <- format_bf(
+      exp(x$log_BF),
+      name = NULL,
+      stars = starlist[["BF"]],
+      exact = exact
+    )
     x$BF <- NULL
     colnames(x)[colnames(x) == "log_BF"] <- "BF"
   }
-  if ("pd" %in% names(x)) x$pd <- format_pd(x$pd, name = NULL, stars = starlist[["pd"]])
-  if ("Rhat" %in% names(x)) x$Rhat <- format_value(x$Rhat, digits = 3)
-  if ("ESS" %in% names(x)) x$ESS <- round(x$ESS)
+  if ("pd" %in% names(x)) {
+    x$pd <- format_pd(x$pd, name = NULL, stars = starlist[["pd"]])
+  }
+  if ("Rhat" %in% names(x)) {
+    x$Rhat <- format_value(x$Rhat, digits = 3)
+  }
+  if ("ESS" %in% names(x)) {
+    x$ESS <- round(x$ESS)
+  }
 
-  if ("ROPE_Equivalence" %in% names(x)) names(x)[names(x) == "ROPE_Equivalence"] <- "Equivalence (ROPE)"
+  if ("ROPE_Equivalence" %in% names(x)) {
+    names(x)[names(x) == "ROPE_Equivalence"] <- "Equivalence (ROPE)"
+  }
   if ("ROPE_Percentage" %in% names(x)) {
     x$ROPE_Percentage <- format_rope(x$ROPE_Percentage, name = NULL, digits = rope_digits)
     names(x)[names(x) == "ROPE_Percentage"] <- "% in ROPE"
   }
+  if ("Superiority_Percentage" %in% names(x)) {
+    x$Superiority_Percentage <- format_rope(
+      x$Superiority_Percentage,
+      name = NULL,
+      digits = rope_digits
+    )
+    names(x)[names(x) == "Superiority_Percentage"] <- "Above ROPE"
+  }
+  if ("Inferiority_Percentage" %in% names(x)) {
+    x$Inferiority_Percentage <- format_rope(
+      x$Inferiority_Percentage,
+      name = NULL,
+      digits = rope_digits
+    )
+    names(x)[names(x) == "Inferiority_Percentage"] <- "Below ROPE"
+  }
+
   x <- .format_rope_columns(
     x,
     zap_small = zap_small,
@@ -739,20 +834,30 @@ format_table <- function(x,
     ci_brackets = ci_brackets
   )
 
-
   # Priors
-  if ("Prior_Location" %in% names(x)) x$Prior_Location <- format_value(x$Prior_Location, protect_integers = TRUE)
-  if ("Prior_Scale" %in% names(x)) x$Prior_Scale <- format_value(x$Prior_Scale, protect_integers = TRUE)
+  if ("Prior_Location" %in% names(x)) {
+    x$Prior_Location <- format_value(x$Prior_Location, protect_integers = TRUE)
+  }
+  if ("Prior_Scale" %in% names(x)) {
+    x$Prior_Scale <- format_value(x$Prior_Scale, protect_integers = TRUE)
+  }
   if ("Prior_Distribution" %in% names(x)) {
     x$Prior_Distribution <- ifelse(
-      is.na(x$Prior_Distribution), "", x$Prior_Distribution
+      is.na(x$Prior_Distribution),
+      "",
+      x$Prior_Distribution
     )
   }
-  if ("Prior_df" %in% names(x)) x$Prior_df <- format_value(x$Prior_df, protect_integers = TRUE)
+  if ("Prior_df" %in% names(x)) {
+    x$Prior_df <- format_value(x$Prior_df, protect_integers = TRUE)
+  }
   if (all(c("Prior_Distribution", "Prior_df") %in% names(x))) {
     missing_df <- is.na(x$Prior_df) | x$Prior_df == ""
     x$Prior_Distribution[!missing_df] <- paste0(
-      x$Prior_Distribution[!missing_df], " (df=", x$Prior_df[!missing_df], ")"
+      x$Prior_Distribution[!missing_df],
+      " (df=",
+      x$Prior_df[!missing_df],
+      ")"
     )
   }
   if (all(c("Prior_Distribution", "Prior_Location", "Prior_Scale") %in% names(x))) {
@@ -769,7 +874,11 @@ format_table <- function(x,
 
     col_position <- which(names(x) == "Prior_Distribution")
     # Replace at initial position
-    x <- x[c(names(x)[0:(col_position - 1)], "Prior", names(x)[col_position:(length(names(x)) - 1)])]
+    x <- x[c(
+      names(x)[0:(col_position - 1)],
+      "Prior",
+      names(x)[col_position:(length(names(x)) - 1)]
+    )]
     x$Prior_Distribution <- x$Prior_Location <- x$Prior_Scale <- x$Prior_df <- NULL
   }
 
@@ -779,39 +888,78 @@ format_table <- function(x,
 
 .format_performance_columns <- function(x, digits, ic_digits, zap_small, use_symbols) {
   if (isTRUE(use_symbols) && .unicode_symbols()) {
-    if ("R2" %in% names(x)) names(x)[names(x) == "R2"] <- "R\u00b2"
-    if ("R2_adjusted" %in% names(x)) names(x)[names(x) == "R2_adjusted"] <- "R\u00b2 (adj.)"
-    if ("R2_conditional" %in% names(x)) names(x)[names(x) == "R2_conditional"] <- "R\u00b2 (cond.)"
-    if ("R2_marginal" %in% names(x)) names(x)[names(x) == "R2_marginal"] <- "R\u00b2 (marg.)"
-    if ("R2_Tjur" %in% names(x)) names(x)[names(x) == "R2_Tjur"] <- "Tjur's R\u00b2"
-    if ("R2_Nagelkerke" %in% names(x)) names(x)[names(x) == "R2_Nagelkerke"] <- "Nagelkerke's R\u00b2"
+    if ("R2" %in% names(x)) {
+      names(x)[names(x) == "R2"] <- "R\u00b2"
+    }
+    if ("R2_adjusted" %in% names(x)) {
+      names(x)[names(x) == "R2_adjusted"] <- "R\u00b2 (adj.)"
+    }
+    if ("R2_conditional" %in% names(x)) {
+      names(x)[names(x) == "R2_conditional"] <- "R\u00b2 (cond.)"
+    }
+    if ("R2_marginal" %in% names(x)) {
+      names(x)[names(x) == "R2_marginal"] <- "R\u00b2 (marg.)"
+    }
+    if ("R2_Tjur" %in% names(x)) {
+      names(x)[names(x) == "R2_Tjur"] <- "Tjur's R\u00b2"
+    }
+    if ("R2_Nagelkerke" %in% names(x)) {
+      names(x)[names(x) == "R2_Nagelkerke"] <- "Nagelkerke's R\u00b2"
+    }
   } else {
-    if ("R2_adjusted" %in% names(x)) names(x)[names(x) == "R2_adjusted"] <- "R2 (adj.)"
-    if ("R2_conditional" %in% names(x)) names(x)[names(x) == "R2_conditional"] <- "R2 (cond.)"
-    if ("R2_marginal" %in% names(x)) names(x)[names(x) == "R2_marginal"] <- "R2 (marg.)"
-    if ("R2_Tjur" %in% names(x)) names(x)[names(x) == "R2_Tjur"] <- "Tjur's R2"
-    if ("R2_Nagelkerke" %in% names(x)) names(x)[names(x) == "R2_Nagelkerke"] <- "Nagelkerke's R2"
+    if ("R2_adjusted" %in% names(x)) {
+      names(x)[names(x) == "R2_adjusted"] <- "R2 (adj.)"
+    }
+    if ("R2_conditional" %in% names(x)) {
+      names(x)[names(x) == "R2_conditional"] <- "R2 (cond.)"
+    }
+    if ("R2_marginal" %in% names(x)) {
+      names(x)[names(x) == "R2_marginal"] <- "R2 (marg.)"
+    }
+    if ("R2_Tjur" %in% names(x)) {
+      names(x)[names(x) == "R2_Tjur"] <- "Tjur's R2"
+    }
+    if ("R2_Nagelkerke" %in% names(x)) {
+      names(x)[names(x) == "R2_Nagelkerke"] <- "Nagelkerke's R2"
+    }
+  }
+  if ("Performance_Score" %in% names(x)) {
+    names(x)[names(x) == "Performance_Score"] <- "Performance-Score"
+  }
+  if ("Wu_Hausman" %in% names(x)) {
+    names(x)[names(x) == "Wu_Hausman"] <- "Wu & Hausman"
+  }
+  if ("p(Wu_Hausman)" %in% names(x)) {
+    names(x)[names(x) == "p(Wu_Hausman)"] <- "p(Wu & Hausman)"
+  }
+  if ("weak_instruments" %in% names(x)) {
+    names(x)[names(x) == "weak_instruments"] <- "Weak instruments"
+  }
+  if ("weak_instruments_p" %in% names(x)) {
+    names(x)[names(x) == "weak_instruments_p"] <- "p(Weak instruments)"
   }
-  if ("Performance_Score" %in% names(x)) names(x)[names(x) == "Performance_Score"] <- "Performance-Score"
-  if ("Wu_Hausman" %in% names(x)) names(x)[names(x) == "Wu_Hausman"] <- "Wu & Hausman"
-  if ("p(Wu_Hausman)" %in% names(x)) names(x)[names(x) == "p(Wu_Hausman)"] <- "p(Wu & Hausman)"
-  if ("weak_instruments" %in% names(x)) names(x)[names(x) == "weak_instruments"] <- "Weak instruments"
-  if ("weak_instruments_p" %in% names(x)) names(x)[names(x) == "weak_instruments_p"] <- "p(Weak instruments)"
 
   # Formatting if we have IC and IC weight columns ----
 
   # add IC weights to IC columns. The next code lines only apply if we have
   # both the IC and IC weights in the data frame
   all_ics <- list(
-    AIC = c("AIC", "AIC_wt"), BIC = c("BIC", "BIC_wt"),
-    AICc = c("AICc", "AICc_wt"), WAIC = c("WAIC", "WAIC_wt"),
+    AIC = c("AIC", "AIC_wt"),
+    BIC = c("BIC", "BIC_wt"),
+    AICc = c("AICc", "AICc_wt"),
+    WAIC = c("WAIC", "WAIC_wt"),
     LOOIC = c("LOOIC", "LOOIC_wt")
   )
   for (ic in names(all_ics)) {
     ics <- all_ics[[ic]]
     if (all(ics %in% colnames(x))) {
       x[[ics[1]]] <- format_value(x[[ics[1]]], digits = ic_digits, zap_small = zap_small)
-      x[[ics[2]]] <- format_p(x[[ics[2]]], digits = digits, name = NULL, whitespace = FALSE)
+      x[[ics[2]]] <- format_p(
+        x[[ics[2]]],
+        digits = digits,
+        name = NULL,
+        whitespace = FALSE
+      )
       x[[ics[1]]] <- sprintf("%s (%s)", x[[ics[1]]], x[[ics[2]]])
       x[ics[2]] <- NULL
       names(x)[names(x) == ics[1]] <- sprintf("%s (weights)", ics[1])
@@ -821,11 +969,21 @@ format_table <- function(x,
   # Formatting if we only have IC columns ----
 
   # if we don't have IC weights, format regular IC columns
-  if ("AIC" %in% names(x)) format_value(x[["AIC"]], digits = ic_digits, zap_small = zap_small)
-  if ("BIC" %in% names(x)) format_value(x[["BIC"]], digits = ic_digits, zap_small = zap_small)
-  if ("AICc" %in% names(x)) format_value(x[["AICc"]], digits = ic_digits, zap_small = zap_small)
-  if ("WAIC" %in% names(x)) format_value(x[["WAIC"]], digits = ic_digits, zap_small = zap_small)
-  if ("LOOIC" %in% names(x)) format_value(x[["LOOIC"]], digits = ic_digits, zap_small = zap_small)
+  if ("AIC" %in% names(x)) {
+    x[["AIC"]] <- format_value(x[["AIC"]], digits = ic_digits, zap_small = zap_small)
+  }
+  if ("BIC" %in% names(x)) {
+    x[["BIC"]] <- format_value(x[["BIC"]], digits = ic_digits, zap_small = zap_small)
+  }
+  if ("AICc" %in% names(x)) {
+    x[["AICc"]] <- format_value(x[["AICc"]], digits = ic_digits, zap_small = zap_small)
+  }
+  if ("WAIC" %in% names(x)) {
+    x[["WAIC"]] <- format_value(x[["WAIC"]], digits = ic_digits, zap_small = zap_small)
+  }
+  if ("LOOIC" %in% names(x)) {
+    x[["LOOIC"]] <- format_value(x[["LOOIC"]], digits = ic_digits, zap_small = zap_small)
+  }
 
   # Formatting if we only have IC weights ----
 
@@ -878,7 +1036,6 @@ format_table <- function(x,
 
 # helper ---------------------
 
-
 .replace_words <- function(x, target, replacement) {
   for (i in seq_along(x)) {
     if (grepl(target, x[i], fixed = TRUE)) {
@@ -922,5 +1079,6 @@ format_table <- function(x,
     }
   )
 
-  l10n_info()[["UTF-8"]] && ((win_os && getRversion() >= "4.2") || (!win_os && getRversion() >= "4.0"))
+  l10n_info()[["UTF-8"]] &&
+    ((win_os && getRversion() >= "4.2") || (!win_os && getRversion() >= "4.0"))
 }
