@@ -23,3 +23,18 @@
   s <- lavaSearch2::summary2(x)
   stats::setNames(as.vector(s$tTable[, "df"]), parameters)
 }
+
+#' @keywords internal
+.degrees_of_freedom_satterthwaite.glmmTMB <- function(x, ...) {
+  check_if_installed("glmmTMB", minimum_version = "1.1.3")
+
+  out <- glmmTMB::dof_satt(x)
+  parameters <- find_parameters(
+    x,
+    effects = "fixed",
+    component = "conditional",
+    flatten = TRUE
+  )
+
+  stats::setNames(out, parameters)
+}
