@@ -16,7 +16,9 @@
 #'   `centrality = "median"` would use the more robust median value as
 #'   measure of central tendency.
 #' @param verbose Toggle messages and warnings.
-#' @param ... Currently not used.
+#' @param ... Currently only used for models of class `brmsfit`, where a `variable`
+#'   argument can be used, which is directly passed to the `as.data.frame()`
+#'   method (i.e., `as.data.frame(x, variable = variable)`).
 #'
 #' @inheritParams find_parameters.BGGM
 #' @inheritParams find_parameters
@@ -45,11 +47,13 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' get_parameters(m)
 #' @export
-get_parameters.BGGM <- function(x,
-                                component = "correlation",
-                                summary = FALSE,
-                                centrality = "mean",
-                                ...) {
+get_parameters.BGGM <- function(
+  x,
+  component = "correlation",
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   # check_if_installed("BGGM")
   #
   # out <- as.data.frame(BGGM::posterior_samples(x))
@@ -62,7 +66,8 @@ get_parameters.BGGM <- function(x,
     component,
     c("correlation", "conditional", "intercept", "all")
   )
-  out <- switch(component,
+  out <- switch(
+    component,
     conditional = out[, conditional, drop = FALSE],
     correlation = out[, correlations, drop = FALSE],
     intercept = out[, intercepts, drop = FALSE],
@@ -76,16 +81,21 @@ get_parameters.BGGM <- function(x,
 
 
 #' @export
-get_parameters.MCMCglmm <- function(x,
-                                    effects = "fixed",
-                                    summary = FALSE,
-                                    centrality = "mean",
-                                    ...) {
+get_parameters.MCMCglmm <- function(
+  x,
+  effects = "fixed",
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   effects <- validate_argument(effects, c("fixed", "random", "all"))
 
   nF <- x$Fixed$nfl
   fixed <- as.data.frame(x$Sol[, 1:nF, drop = FALSE])
-  random <- as.data.frame(x$VCV[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE])
+  random <- as.data.frame(x$VCV[,
+    find_random(x, split_nested = TRUE, flatten = TRUE),
+    drop = FALSE
+  ])
   all_params <- cbind(fixed, random)
 
   out <- if (effects == "fixed") {
@@ -105,15 +115,17 @@ get_parameters.MCMCglmm <- function(x,
 
 #' @rdname get_parameters.BGGM
 #' @export
-get_parameters.BFBayesFactor <- function(x,
-                                         effects = "all",
-                                         component = "all",
-                                         iterations = 4000,
-                                         progress = FALSE,
-                                         verbose = TRUE,
-                                         summary = FALSE,
-                                         centrality = "mean",
-                                         ...) {
+get_parameters.BFBayesFactor <- function(
+  x,
+  effects = "all",
+  component = "all",
+  iterations = 4000,
+  progress = FALSE,
+  verbose = TRUE,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   check_if_installed("BayesFactor")
 
   effects <- validate_argument(effects, c("all", "fixed", "random"))
@@ -122,30 +134,49 @@ get_parameters.BFBayesFactor <- function(x,
 
   # check if valid model was indexed...
 
-  if ((length(x@numerator) > 1 ||
-    !xor(
-      x@denominator@shortName == "Intercept only",
-      grepl("^(Null|Indep)", x@denominator@shortName)
-    )) && verbose) {
+  if (
+    (length(x@numerator) > 1 ||
+      !xor(
+        x@denominator@shortName == "Intercept only",
+        grepl("^(Null|Indep)", x@denominator@shortName)
+      )) &&
+      verbose
+  ) {
     format_alert(
       "Multiple `BFBayesFactor` models detected - posteriors are extracted from the first numerator model.",
       'See help("get_parameters", package = "insight").'
     )
   }
 
-
-  params <- find_parameters(x, effects = effects, component = component, flatten = TRUE, ...)
+  params <- find_parameters(
+    x,
+    effects = effects,
+    component = component,
+    flatten = TRUE,
+    ...
+  )
 
   if (bf_type %in% c("correlation", "ttest1", "ttest2", "meta", "linear")) {
     posteriors <-
       as.data.frame(suppressMessages(
-        BayesFactor::posterior(x, iterations = iterations, progress = progress, index = 1, ...)
+        BayesFactor::posterior(
+          x,
+          iterations = iterations,
+          progress = progress,
+          index = 1,
+          ...
+        )
       ))
 
-    out <- switch(bf_type,
+    out <- switch(
+      bf_type,
       correlation = data.frame(rho = as.numeric(posteriors$rho)),
-      ttest1 = data.frame(Difference = as.numeric(posteriors[, 1]) - x@numerator[[1]]@prior$mu),
-      ttest2 = data.frame(Difference = as.numeric(posteriors[, 2]) - x@numerator[[1]]@prior$mu),
+      ttest1 = data.frame(
+        Difference = as.numeric(posteriors[, 1]) - x@numerator[[1]]@prior$mu
+      ),
+      ttest2 = data.frame(
+        Difference = as.numeric(posteriors[, 2]) - x@numerator[[1]]@prior$mu
+      ),
       meta = data.frame(Effect = as.numeric(posteriors$delta)),
       linear = .get_bf_posteriors(posteriors, params),
       NULL
@@ -181,81 +212,73 @@ get_parameters.BFBayesFactor <- function(x,
 }
 
 
-#' @export
-get_parameters.stanmvreg <- function(x,
-                                     effects = "fixed",
-                                     parameters = NULL,
-                                     summary = FALSE,
-                                     centrality = "mean",
-                                     ...) {
-  effects <- validate_argument(effects, c("fixed", "random", "all"))
-  elements <- .get_elements(effects, "all")
-  parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
-
-  for (i in names(parms)) {
-    parms[[i]]$conditional <- sprintf("%s|%s", i, parms[[i]]$conditional)
-    find_bracket <- regexpr(pattern = "[", parms[[i]]$random, fixed = TRUE)
-    parms[[i]]$random <- paste0(
-      substr(parms[[i]]$random, start = 1, stop = find_bracket),
-      i, "|",
-      substr(parms[[i]]$random, start = find_bracket + 1, stop = 1000000L)
-    )
-    parms[[i]]$sigma <- NULL
-  }
-
-  out <- as.data.frame(x)[unlist(lapply(compact_list(parms), function(i) i[elements]), use.names = FALSE)]
-
-  if (isTRUE(summary)) {
-    out <- .summary_of_posteriors(out, centrality = centrality)
-  }
-  out
-}
-
-
 #' @rdname get_parameters.BGGM
 #' @export
-get_parameters.brmsfit <- function(x,
-                                   effects = "fixed",
-                                   component = "all",
-                                   parameters = NULL,
-                                   summary = FALSE,
-                                   centrality = "mean",
-                                   ...) {
-  effects <- validate_argument(effects, c("all", "fixed", "random"))
-  component <- validate_argument(
-    component,
-    c("all", .all_elements(), "location", "distributional")
-  )
+get_parameters.brmsfit <- function(
+  x,
+  effects = "fixed",
+  component = "all",
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
+  # we require namespace, to ensure that `as.data.frame()` works correctly
+  check_if_installed("brms")
 
-  if (is_multivariate(x)) {
-    parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
-    elements <- .get_elements(effects, component)
-    out <- as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]), use.names = FALSE)]
+  dots <- list(...)
+  # allow hidden argument "variable" to be passed directly to as.data.frame
+  if (is.null(dots$variable)) {
+    parms <- find_parameters(
+      x,
+      effects = effects,
+      component = component,
+      flatten = FALSE,
+      parameters = parameters
+    )
+    variables <- unique(unlist(parms, use.names = FALSE))
   } else {
-    out <- as.data.frame(x)[.get_parms_data(x, effects, component, parameters)]
+    variables <- dots$variable
   }
 
+  out <- as.data.frame(x, variable = variables)
+
   if (isTRUE(summary)) {
-    out <- .summary_of_posteriors(out, centrality = centrality)
+    out <- .summary_of_posteriors(out, centrality = centrality, parms)
   }
   out
 }
 
 
 #' @export
-get_parameters.stanreg <- function(x,
-                                   effects = "fixed",
-                                   component = "location",
-                                   parameters = NULL,
-                                   summary = FALSE,
-                                   centrality = "mean",
-                                   ...) {
-  effects <- validate_argument(effects, c("fixed", "random", "all"))
-  component <- validate_argument(
-    component,
-    c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary")
-  )
-  out <- as.data.frame(x)[.get_parms_data(x, effects, component, parameters)]
+get_parameters.stanreg <- function(
+  x,
+  effects = "fixed",
+  component = "location",
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
+  # we require namespace, to ensure that `as.data.frame()` works correctly
+  check_if_installed("rstanarm")
+
+  dots <- list(...)
+  # allow hidden argument "variable" to be passed directly to as.data.frame
+  if (is.null(dots$variable)) {
+    parms <- find_parameters(
+      x,
+      effects = effects,
+      component = component,
+      flatten = FALSE,
+      parameters = parameters
+    )
+    variables <- unique(unlist(parms, use.names = FALSE))
+  } else {
+    variables <- dots$variable
+  }
+
+  out <- as.data.frame(x, pars = variables)
 
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
@@ -263,17 +286,21 @@ get_parameters.stanreg <- function(x,
   out
 }
 
-
 #' @export
 get_parameters.stanfit <- get_parameters.stanreg
 
+#' @export
+get_parameters.stanmvreg <- get_parameters.stanreg
+
 
 #' @export
-get_parameters.bcplm <- function(x,
-                                 parameters = NULL,
-                                 summary = FALSE,
-                                 centrality = "mean",
-                                 ...) {
+get_parameters.bcplm <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   out <- as.data.frame(do.call(rbind, x$sims.list))
   if (!is.null(parameters)) {
     out <- out[grepl(pattern = parameters, x = colnames(out), perl = TRUE)]
@@ -286,11 +313,13 @@ get_parameters.bcplm <- function(x,
 
 
 #' @export
-get_parameters.bayesx <- function(x,
-                                  component = "conditional",
-                                  summary = FALSE,
-                                  centrality = "mean",
-                                  ...) {
+get_parameters.bayesx <- function(
+  x,
+  component = "conditional",
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   component <- validate_argument(component, c("conditional", "smooth_terms", "all"))
 
   smooth_dat <- data.frame(
@@ -307,7 +336,8 @@ get_parameters.bayesx <- function(x,
     stringsAsFactors = FALSE
   )
 
-  params <- switch(component,
+  params <- switch(
+    component,
     all = rbind(fixed_dat, smooth_dat),
     conditional = fixed_dat,
     smooth_terms = smooth_dat
@@ -323,11 +353,13 @@ get_parameters.bayesx <- function(x,
 
 
 #' @export
-get_parameters.mcmc.list <- function(x,
-                                     parameters = NULL,
-                                     summary = FALSE,
-                                     centrality = "mean",
-                                     ...) {
+get_parameters.mcmc.list <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   out <- as.data.frame(do.call(rbind, x))
   if (!is.null(parameters)) {
     out <- out[grepl(pattern = parameters, x = colnames(out), perl = TRUE)]
@@ -340,12 +372,14 @@ get_parameters.mcmc.list <- function(x,
 
 
 #' @export
-get_parameters.bamlss <- function(x,
-                                  component = "all",
-                                  parameters = NULL,
-                                  summary = FALSE,
-                                  centrality = "mean",
-                                  ...) {
+get_parameters.bamlss <- function(
+  x,
+  component = "all",
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   component <- validate_argument(
     component,
     c("all", "conditional", "smooth_terms", "location", "distributional", "auxiliary")
@@ -362,11 +396,13 @@ get_parameters.bamlss <- function(x,
 
 
 #' @export
-get_parameters.mcmc <- function(x,
-                                parameters = NULL,
-                                summary = FALSE,
-                                centrality = "mean",
-                                ...) {
+get_parameters.mcmc <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   out <- as.data.frame(x)[.get_parms_data(x, "all", "all", parameters)]
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
@@ -376,11 +412,13 @@ get_parameters.mcmc <- function(x,
 
 
 #' @export
-get_parameters.bayesQR <- function(x,
-                                   parameters = NULL,
-                                   summary = FALSE,
-                                   centrality = "mean",
-                                   ...) {
+get_parameters.bayesQR <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   out <- as.data.frame(x[[1]]$betadraw)
   names(out) <- x[[1]]$names
   out <- out[.get_parms_data(x, "all", "all", parameters)]
@@ -392,11 +430,13 @@ get_parameters.bayesQR <- function(x,
 
 
 #' @export
-get_parameters.blrm <- function(x,
-                                parameters = NULL,
-                                summary = FALSE,
-                                centrality = "mean",
-                                ...) {
+get_parameters.blrm <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   out <- as.data.frame(x$draws)
   out <- out[.get_parms_data(x, "all", "all", parameters)]
   if (isTRUE(summary)) {
@@ -407,16 +447,22 @@ get_parameters.blrm <- function(x,
 
 
 #' @export
-get_parameters.sim.merMod <- function(x,
-                                      effects = "fixed",
-                                      parameters = NULL,
-                                      summary = FALSE,
-                                      centrality = "mean",
-                                      ...) {
+get_parameters.sim.merMod <- function(
+  x,
+  effects = "fixed",
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   effects <- validate_argument(effects, c("fixed", "random", "all"))
   fe <- re <- NULL
-  if (effects %in% c("fixed", "all")) fe <- .get_armsim_fixef_parms(x)
-  if (effects %in% c("random", "all")) re <- .get_armsim_ranef_parms(x)
+  if (effects %in% c("fixed", "all")) {
+    fe <- .get_armsim_fixef_parms(x)
+  }
+  if (effects %in% c("random", "all")) {
+    re <- .get_armsim_ranef_parms(x)
+  }
 
   dat <- do.call(cbind, compact_list(list(fe, re)))
 
@@ -430,11 +476,13 @@ get_parameters.sim.merMod <- function(x,
 
 
 #' @export
-get_parameters.sim <- function(x,
-                               parameters = NULL,
-                               summary = FALSE,
-                               centrality = "mean",
-                               ...) {
+get_parameters.sim <- function(
+  x,
+  parameters = NULL,
+  summary = FALSE,
+  centrality = "mean",
+  ...
+) {
   dat <- .get_armsim_fixef_parms(x)
   out <- as.data.frame(dat)[.get_parms_data(x, "all", "all", parameters)]
 
@@ -447,18 +495,27 @@ get_parameters.sim <- function(x,
 
 # helper -----------------------
 
-
-.summary_of_posteriors <- function(out, centrality = "mean", ...) {
-  s <- switch(centrality,
+.summary_of_posteriors <- function(out, centrality = "mean", params = NULL, ...) {
+  s <- switch(
+    centrality,
     mean = vapply(out, mean, numeric(1), na.rm = TRUE),
     median = vapply(out, stats::median, numeric(1), na.rm = TRUE),
     vapply(out, mean, numeric(1), na.rm = TRUE)
   )
-  data.frame(
+  out <- data.frame(
     Parameter = names(s),
     Estimate = unname(s),
     stringsAsFactors = FALSE
   )
+  if (!is.null(params)) {
+    components <- rep(names(params), lengths(params))
+    out$Effects <- "fixed"
+    out$Effects[endsWith(components, "random")] <- "random"
+    components <- gsub("(_random|random)$", "", components)
+    components[components == ""] <- "conditional"
+    out$Components <- components
+  }
+  out
 }
 
 
@@ -470,7 +527,13 @@ get_parameters.sim <- function(x,
 
 .get_parms_data <- function(x, effects, component, parameters = NULL) {
   elements <- .get_elements(effects, component)
-  unlist(find_parameters(x, effects = "all", component = "all", flatten = FALSE, parameters = parameters)[elements])
+  unlist(find_parameters(
+    x,
+    effects = "all",
+    component = "all",
+    flatten = FALSE,
+    parameters = parameters
+  )[elements])
 }
 
 
@@ -485,7 +548,8 @@ get_parameters.sim <- function(x,
     pcors_total <- p * (p - 1) * 0.5
     I_p <- diag(p)
     iter <- object$iter
-    pcor_samples <- matrix(object$post_samp$pcors[, , 51:(iter + 50)][upper.tri(I_p)],
+    pcor_samples <- matrix(
+      object$post_samp$pcors[,, 51:(iter + 50)][upper.tri(I_p)],
       nrow = iter,
       ncol = pcors_total,
       byrow = TRUE
@@ -511,17 +575,20 @@ get_parameters.sim <- function(x,
       } else {
         col_names <- cn
       }
-      beta_start <- matrix(beta_samples[1:n_beta_terms, 1, 51:(iter + 50)],
+      beta_start <- matrix(
+        beta_samples[1:n_beta_terms, 1, 51:(iter + 50)],
         nrow = iter,
         n_beta_terms,
         byrow = TRUE
       )
       colnames(beta_start) <- paste0(
-        col_names[1], "_",
+        col_names[1],
+        "_",
         beta_terms
       )
       for (i in 2:p) {
-        beta_i <- matrix(beta_samples[1:n_beta_terms, i, 51:(iter + 50)],
+        beta_i <- matrix(
+          beta_samples[1:n_beta_terms, i, 51:(iter + 50)],
           nrow = iter,
           n_beta_terms,
           byrow = TRUE
@@ -539,7 +606,8 @@ get_parameters.sim <- function(x,
     pcors_total <- p * (p - 1) * 0.5
     I_p <- diag(p)
     iter <- object$iter
-    pcor_samples <- matrix(object$fit$pcors[, , 51:(iter + 50)][upper.tri(I_p)],
+    pcor_samples <- matrix(
+      object$fit$pcors[,, 51:(iter + 50)][upper.tri(I_p)],
       nrow = iter,
       ncol = pcors_total,
       byrow = TRUE
@@ -556,14 +624,16 @@ get_parameters.sim <- function(x,
     beta_samples <- object$fit$beta
     col_names <- colnames(object$Y)
     beta_terms <- colnames(object$X)
-    beta_start <- matrix(beta_samples[1:n_beta_terms, 1, 51:(iter + 50)],
+    beta_start <- matrix(
+      beta_samples[1:n_beta_terms, 1, 51:(iter + 50)],
       nrow = iter,
       n_beta_terms,
       byrow = TRUE
     )
     colnames(beta_start) <- paste0(col_names[1], "_", beta_terms)
     for (i in 2:p) {
-      beta_i <- matrix(beta_samples[1:n_beta_terms, i, 51:(iter + 50)],
+      beta_i <- matrix(
+        beta_samples[1:n_beta_terms, i, 51:(iter + 50)],
         nrow = iter,
         n_beta_terms,
         byrow = TRUE
