@@ -2,12 +2,14 @@
 # =======================================================================
 
 #' @export
-get_predicted.clm <- function(x,
-                              data = NULL,
-                              predict = "expectation",
-                              ci = NULL,
-                              verbose = TRUE,
-                              ...) {
+get_predicted.clm <- function(
+  x,
+  data = NULL,
+  predict = "expectation",
+  ci = NULL,
+  verbose = TRUE,
+  ...
+) {
   # When (a) `newdata` is not null and (b) the response variable does *not*
   # appear in `newdata`, predict.clm() returns matrices with predictions for
   # each levels of the response.  When either of those conditions fail,
@@ -21,12 +23,10 @@ get_predicted.clm <- function(x,
     valid <- c("expectation", "classification")
     predict <- match.arg(predict, choices = valid)
     type_arg <- c("prob", "class")[match(predict, valid)]
+  } else if ("type" %in% names(dots)) {
+    type_arg <- match.arg(dots$type, choices = c("prob", "class"))
   } else {
-    if (!"type" %in% names(dots)) {
-      format_error("Please specify the `predict` argument.")
-    } else {
-      type_arg <- match.arg(dots$type, choices = c("prob", "class"))
-    }
+    format_error("Please specify the `predict` argument.")
   }
 
   # hack to get predictions for all response levels
@@ -55,7 +55,7 @@ get_predicted.clm <- function(x,
   }
 
   # compute predictions
-  args <- list(
+  my_args <- list(
     object = x,
     newdata = data,
     type = type_arg,
@@ -63,17 +63,18 @@ get_predicted.clm <- function(x,
     interval = !is.null(ci),
     level = ifelse(is.null(ci), 0.95, ci)
   )
-  pred <- do.call("predict", args)
+  pred <- do.call("predict", my_args)
 
-  args$data <- args$newdata
-  out <- .get_predicted_out(pred$fit, args = args)
+  my_args$data <- my_args$newdata
+  out <- .get_predicted_out(pred$fit, my_args = my_args)
 
   # standard error and confidence intervals matrix to long format
   if (type_arg == "prob") {
     se <- pred$se.fit
     se <- as.data.frame(se)
     se$Row <- seq_len(nrow(se))
-    se <- stats::reshape(se,
+    se <- stats::reshape(
+      se,
       direction = "long",
       varying = setdiff(colnames(se), "Row"),
       times = setdiff(colnames(se), "Row"),
@@ -94,7 +95,8 @@ get_predicted.clm <- function(x,
         }
         vary <- setdiff(colnames(conf), "Row")
         conf$Row <- seq_len(nrow(conf))
-        conf <- stats::reshape(conf,
+        conf <- stats::reshape(
+          conf,
           direction = "long",
           varying = vary,
           times = vary,
@@ -124,13 +126,18 @@ get_predicted.clm <- function(x,
 }
 
 
-
-
 # nnet::multinom --------------------------------------------------------
 # =======================================================================
 
 #' @export
-get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci = NULL, verbose = TRUE, ...) {
+get_predicted.multinom <- function(
+  x,
+  predict = "expectation",
+  data = NULL,
+  ci = NULL,
+  verbose = TRUE,
+  ...
+) {
   dots <- list(...)
 
   # `type` argument can be: probs | class
@@ -140,10 +147,12 @@ get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci =
   } else if ("type" %in% names(dots)) {
     type_arg <- match.arg(dots$type, choices = c("class", "probs"))
   } else {
-    format_error("The `predict` argument must be either \"expectation\" or \"classification\".")
+    format_error(
+      "The `predict` argument must be either \"expectation\" or \"classification\"."
+    )
   }
 
-  args <- c(list(x, data = data, ci = ci, predict = type_arg), list(...))
+  my_args <- c(list(x, data = data, ci = ci, predict = type_arg), list(...))
 
   # predict.multinom doesn't work when `newdata` is explicitly set to NULL (weird)
   if (is.null(data)) {
@@ -153,7 +162,7 @@ get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci =
   }
 
   # reshape
-  out <- .get_predicted_out(out, args = args)
+  out <- .get_predicted_out(out, my_args = my_args)
 
   # add CI
   if (!is.null(ci)) {
@@ -171,8 +180,6 @@ get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci =
 }
 
 
-
-
 # MASS ------------------------------------------------------------------
 # =======================================================================
 
