@@ -11,30 +11,6 @@
 #'   where the index of the column that is being pulled is `column_index`.
 #'   Defaults to 3, which is the default statistic column for most models'
 #'   summary-output.
-#' @param component String, indicating the model component for which parameters
-#'   should be returned. The default for all models is `"all"`, which returns
-#'   the requested information for all available model components. Furthermore,
-#'   there are specific options depending on the model class. `component` then
-#'   may be one of:
-#'
-#'   - For zero-inflated models (`gmmTMB`, `hurdle`, `zeroinfl`, ...) can also
-#'     be `"conditional"` or `"zero-inflated"`. Note that the *conditional*
-#'     component is also called *count* or *mean* component, depending on the
-#'     model. `glmmTMB` also has a `"dispersion"` component.
-#'   - For models with smooth terms, `component = "smooth_terms"` returns the
-#'     test statistic for the smooth terms.
-#'   - For models of class `mhurdle`, may also be one of  `"conditional"`,
-#'     `"zero_inflated"`, `"infrequent_purchase"` or `"auxiliary"`.
-#'   - For models of class `clm2` or `clmm2`, may also be `"scale"`.
-#'   - For models of class `betareg`, `betaor` or `betamfx`, may also be
-#'     `"precision"`. For other `*mfx` models (`logitmfx`, `betamfx`, ...),
-#'     may also be `"marginal"`.
-#'   - For models of class `mvord`, may also be `"thresholds"` or
-#'     `"correlation"`.
-#'   - For models of class `selection`, may also be `"selection"`, `"outcome"`
-#'     or `"auxiliary"`.
-#'   - For models of class `glmx`, may also be `"extra"`.
-#'   - For models of class `averaging`, may also be `"full"`.
 #' @param robust Logical, if `TRUE`, test statistic based on robust
 #'   standard errors is returned.
 #' @param adjust Character value naming the method used to adjust p-values or
@@ -42,9 +18,12 @@
 #' @param ci Confidence Interval (CI) level. Default to `0.95` (`95%`).
 #'   Currently only applies to objects of class `emmGrid`.
 #' @param ... Currently not used.
+#' @inheritParams find_predictors
 #' @inheritParams get_parameters
 #' @inheritParams get_parameters.emmGrid
 #'
+#' @inheritSection find_predictors Model components
+#'
 #' @return A data frame with the model's parameter names and the related test
 #'   statistic.
 #'
@@ -60,7 +39,6 @@ get_statistic <- function(x, ...) {
 
 # Default models ----------------------------------------------------------
 
-
 #' @rdname get_statistic
 #' @export
 get_statistic.default <- function(x, column_index = 3, verbose = TRUE, ...) {
@@ -92,6 +70,24 @@ get_statistic.default <- function(x, column_index = 3, verbose = TRUE, ...) {
 }
 
 
+#' @export
+get_statistic.aov <- function(x, ...) {
+  s <- summary(x)[[1]]
+  params <- s[!is.na(s$`F value`), ]
+
+  out <- data.frame(
+    Parameter = trim_ws(row.names(params)),
+    Statistic = params$`F value`,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.htest <- function(x, ...) {
   if (x$method == "Fisher's Exact Test for Count Data") {
@@ -209,6 +205,98 @@ get_statistic.asym <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.lcmm <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "membership", "longitudinal", "beta", "splines", "linear")
+  )
+
+  id <- seq_along(x$best)
+  indice <- rep(id * (id + 1) / 2)
+  se <- sqrt(x$V[indice])
+  statistic <- x$best / se
+
+  statistic <- statistic[
+    !startsWith(names(statistic), "cholesky ") & !startsWith(names(statistic), "varcov ")
+  ]
+  comp <- rep("longitudinal", times = length(statistic))
+
+  if (x$linktype == 1) {
+    comp[startsWith(names(statistic), "Beta")] <- "beta"
+  } else if (x$linktype == 2) {
+    comp[startsWith(names(statistic), "I-splines")] <- "splines"
+  } else if (x$linktype == 3) {
+    ## TODO: thresholds
+  } else {
+    comp[startsWith(names(statistic), "Linear")] <- "linear"
+  }
+
+  # check whether we have membership and longitudinal submodel
+  n_membership <- x$N[1]
+  n_longitudinal <- x$N[2]
+
+  if (n_membership > 0) {
+    comp[seq_len(n_membership)] <- "membership"
+  }
+
+  # check if we have mutilple classes
+  has_classes <- grepl("(.*) (class\\d+)$", names(statistic))
+  if (any(has_classes)) {
+    grp <- gsub("(.*) (class\\d+)$", "\\2", names(statistic))
+    grp[!has_classes] <- "link"
+  } else {
+    grp <- NULL
+  }
+
+  out <- data.frame(
+    Parameter = names(statistic),
+    Statistic = as.vector(statistic),
+    Component = comp,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+  # separate, because can be NULL
+  out$Group <- grp
+
+  if (component != "all") {
+    out <- out[out$Component == component, , drop = FALSE]
+  }
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.externX <- function(x, ...) {
+  id <- seq_along(x$best)
+  indice <- rep(id * (id + 1) / 2)
+  se <- sqrt(x$V[indice])
+  statistic <- x$best / se
+
+  statistic <- statistic[
+    !startsWith(names(statistic), "cholesky ") & !startsWith(names(statistic), "varcov ")
+  ]
+
+  out <- data.frame(
+    Parameter = names(statistic),
+    Statistic = as.vector(statistic),
+    Group = gsub("(.*) (class\\d+)$", "\\2", names(statistic)),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+#' @export
+get_statistic.externVar <- get_statistic.externX
+
+
 #' @export
 get_statistic.oohbchoice <- function(x, ...) {
   cftable <- summary(x)$coef
@@ -287,14 +375,18 @@ get_statistic.feis <- get_statistic.default
 
 # Models with zero-inflation component --------------------------------------
 
-
 #' @export
 get_statistic.mhurdle <- function(x, component = "all", ...) {
   component <- match.arg(
     component,
     choices = c(
-      "all", "conditional", "zi", "zero_inflated", "infrequent_purchase",
-      "ip", "auxiliary"
+      "all",
+      "conditional",
+      "zi",
+      "zero_inflated",
+      "infrequent_purchase",
+      "ip",
+      "auxiliary"
     )
   )
 
@@ -319,7 +411,10 @@ get_statistic.mhurdle <- function(x, component = "all", ...) {
   stats$Component[aux_pars] <- "auxiliary"
 
   params <- merge(params, stats, sort = FALSE)
-  params <- .filter_component(params, component)[intersect(c("Parameter", "Statistic", "Component"), colnames(params))]
+  params <- .filter_component(params, component)[intersect(
+    c("Parameter", "Statistic", "Component"),
+    colnames(params)
+  )]
   params <- text_remove_backticks(params)
   attr(params, "statistic") <- find_statistic(x)
 
@@ -378,11 +473,7 @@ get_statistic.zeroinfl <- function(x, component = "all", ...) {
     }
 
     data.frame(
-      Parameter = find_parameters(x,
-        effects = "fixed",
-        component = comp,
-        flatten = TRUE
-      ),
+      Parameter = find_parameters(x, effects = "fixed", component = comp, flatten = TRUE),
       Statistic = as.vector(stats[, 3]),
       Component = comp,
       stringsAsFactors = FALSE,
@@ -422,11 +513,7 @@ get_statistic.MixMod <- function(x, component = "all", ...) {
 
   out <- lapply(names(cs), function(i) {
     data.frame(
-      Parameter = find_parameters(x,
-        effects = "fixed",
-        component = i,
-        flatten = TRUE
-      ),
+      Parameter = find_parameters(x, effects = "fixed", component = i, flatten = TRUE),
       Statistic = as.vector(cs[[i]][, 3]),
       Component = i,
       stringsAsFactors = FALSE,
@@ -444,7 +531,6 @@ get_statistic.MixMod <- function(x, component = "all", ...) {
 
 # gam models --------------------------------------------------------------
 
-
 #' @export
 get_statistic.Gam <- function(x, ...) {
   p.aov <- stats::na.omit(summary(x)$parametric.anova)
@@ -503,12 +589,15 @@ get_statistic.SemiParBIV <- function(x, ...) {
   s <- summary(x)
   s <- compact_list(s[startsWith(names(s), "tableP")])
 
-  params <- do.call(rbind, lapply(seq_along(s), function(i) {
-    out <- as.data.frame(s[[i]])
-    out$Parameter <- rownames(out)
-    out$Component <- paste0("Equation", i)
-    out
-  }))
+  params <- do.call(
+    rbind,
+    lapply(seq_along(s), function(i) {
+      out <- as.data.frame(s[[i]])
+      out$Parameter <- rownames(out)
+      out$Component <- paste0("Equation", i)
+      out
+    })
+  )
 
   colnames(params)[3] <- "Statistic"
   rownames(params) <- NULL
@@ -603,7 +692,9 @@ get_statistic.cgam <- function(x, component = "all", ...) {
 
   sc <- summary(x)
   stat <- as.vector(sc$coefficients[, 3])
-  if (!is.null(sc$coefficients2)) stat <- c(stat, rep(NA, nrow(sc$coefficients2)))
+  if (!is.null(sc$coefficients2)) {
+    stat <- c(stat, rep(NA, nrow(sc$coefficients2)))
+  }
 
   params <- get_parameters(x, component = "all")
 
@@ -626,7 +717,6 @@ get_statistic.cgam <- function(x, component = "all", ...) {
 
 # Survival models ------------------------------------------
 
-
 #' @export
 get_statistic.coxph <- function(x, ...) {
   # z is not always in the same column
@@ -792,6 +882,27 @@ get_statistic.aareg <- function(x, ...) {
 
 # Ordinal models --------------------------------------------------
 
+#' @export
+get_statistic.polr <- function(x, verbose = TRUE, ...) {
+  cs <- suppressWarnings(stats::coef(summary(x)))
+  params <- c(sprintf("Intercept: %s", names(x$zeta)), names(x$coefficients))
+  param_order <- match(c(names(x$zeta), names(x$coefficients)), rownames(cs))
+
+  out <- data.frame(
+    Parameter = params,
+    Statistic = as.vector(cs[, 3])[param_order],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+#' @export
+get_statistic.svyolr <- get_statistic.polr
+
 
 #' @export
 get_statistic.clm2 <- function(x, component = "all", ...) {
@@ -805,7 +916,10 @@ get_statistic.clm2 <- function(x, component = "all", ...) {
   out <- data.frame(
     Parameter = rownames(stats),
     Statistic = unname(stats[, "z value"]),
-    Component = c(rep("conditional", times = n_intercepts + n_location), rep("scale", times = n_scale)),
+    Component = c(
+      rep("conditional", times = n_intercepts + n_location),
+      rep("scale", times = n_scale)
+    ),
     stringsAsFactors = FALSE,
     row.names = NULL
   )
@@ -859,7 +973,10 @@ get_statistic.mvord <- function(x, component = "all", ...) {
   params <- data.frame(
     Parameter = c(thresholds$Parameter, model_coef$Parameter),
     Statistic = c(unname(thresholds[, "z value"]), unname(model_coef[, "z value"])),
-    Component = c(rep("thresholds", nrow(thresholds)), rep("conditional", nrow(model_coef))),
+    Component = c(
+      rep("thresholds", nrow(thresholds)),
+      rep("conditional", nrow(model_coef))
+    ),
     Response = c(thresholds$Response, model_coef$Response),
     stringsAsFactors = FALSE,
     row.names = NULL
@@ -876,7 +993,7 @@ get_statistic.mvord <- function(x, component = "all", ...) {
 
   params <- rbind(params, params_error)
 
-  if (n_unique(params$Response) == 1) {
+  if (has_single_value(params$Response, remove_na = TRUE)) {
     params$Response <- NULL
   }
 
@@ -1182,7 +1299,6 @@ get_statistic.negbinirr <- get_statistic.logitor
 
 # Other models -------------------------------------------------------
 
-
 #' @export
 get_statistic.glmgee <- function(x, ...) {
   junk <- utils::capture.output({
@@ -1203,10 +1319,42 @@ get_statistic.glmgee <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.estimate_means <- function(x, ...) {
+  if ("t" %in% colnames(x)) {
+    stat <- x[["t"]]
+  } else {
+    stat <- x[["z"]]
+  }
+
+  params <- get_parameters(x)
+
+  out <- data.frame(
+    Parameter = params$Parameter,
+    Statistic = as.vector(stat),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+#' @export
+get_statistic.estimate_slopes <- get_statistic.estimate_means
+
+#' @export
+get_statistic.estimate_contrasts <- get_statistic.estimate_means
+
+
 #' @export
 get_statistic.nestedLogit <- function(x, component = "all", verbose = TRUE, ...) {
   cf <- as.data.frame(stats::coef(x))
-  out <- as.data.frame(do.call(rbind, lapply(x$models, function(i) stats::coef(summary(i)))))
+  out <- as.data.frame(do.call(
+    rbind,
+    lapply(x$models, function(i) stats::coef(summary(i)))
+  ))
   colnames(out)[3] <- "Statistic"
   response_levels <- unlist(lapply(x$dichotomies, function(i) {
     paste0("{", toString(i[[1]]), "} vs. {", toString(i[[2]]), "}")
@@ -1275,12 +1423,12 @@ get_statistic.selection <- function(x, component = "all", ...) {
   params <- data.frame(
     Parameter = rn,
     Statistic = estimates[[3]],
-    Component = "auxiliary",
+    Component = "selection",
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  params$Component[s$param$index$betaS] <- "selection"
-  params$Component[s$param$index$betaO] <- "outcome"
+  params$Component[s$param$index$errTerms] <- "auxiliary"
+  params$Component[s$param$index$outcome] <- "outcome"
 
   if (component != "all") {
     params <- params[params$Component == component, , drop = FALSE]
@@ -1415,16 +1563,78 @@ get_statistic.ergm <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+get_statistic.sdmTMB <- function(x, component = "all", verbose = TRUE, ...) {
+  delta_comp <- isTRUE(x$family$delta)
+  valid_comp <- compact_character(c(
+    "all",
+    "conditional",
+    ifelse(delta_comp, "delta", "")
+  ))
+  component <- validate_argument(component, valid_comp)
+
+  # get standard errors
+  se <- sqrt(diag(get_varcov(x)))
+
+  # for model with delta component, we have two intercepts
+  intercepts <- which(names(se) == "(Intercept)")
+
+  # get standard errors for each component - we have to remove one intercept
+  if (length(intercepts) > 1) {
+    se_cond <- se[-intercepts[2]]
+    se_delta <- se[-intercepts[1]]
+  } else {
+    se_cond <- se
+    se_delta <- NULL
+  }
+
+  est <- suppressMessages(stats::coef(x, model = 1))
+  conditional <- data.frame(
+    Parameter = names(est),
+    Statistic = est / se_cond,
+    Component = "conditional",
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  if (delta_comp) {
+    est <- suppressMessages(stats::coef(x, model = 2))
+    delta <- data.frame(
+      Parameter = names(est),
+      Statistic = est / se_delta,
+      Component = "delta",
+      stringsAsFactors = FALSE,
+      row.names = NULL
+    )
+  }
+
+  if (delta_comp) {
+    out <- rbind(conditional, delta)
+  } else {
+    out <- conditional
+  }
+
+  out <- switch(component, all = out, conditional = conditional, delta = delta)
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.btergm <- function(x, verbose = TRUE, ...) {
   params <- x@coef
   bootstraps <- x@boot$t
 
   # standard error
-  sdev <- vapply(seq_len(ncol(bootstraps)), function(i) {
-    cur <- (bootstraps[, i] - params[i])^2
-    sqrt(sum(cur) / length(cur))
-  }, numeric(1))
+  sdev <- vapply(
+    seq_len(ncol(bootstraps)),
+    function(i) {
+      cur <- (bootstraps[, i] - params[i])^2
+      sqrt(sum(cur) / length(cur))
+    },
+    numeric(1)
+  )
   stat <- (0 - colMeans(bootstraps)) / sdev
 
   out <- data.frame(
@@ -1599,11 +1809,7 @@ get_statistic.mle <- get_statistic.mle2
 #' @export
 get_statistic.glht <- function(x, ...) {
   s <- summary(x)
-  alt <- switch(x$alternative,
-    two.sided = "==",
-    less = ">=",
-    greater = "<="
-  )
+  alt <- switch(x$alternative, two.sided = "==", less = ">=", greater = "<=")
   out <- data.frame(
     Parameter = paste(names(s$test$coefficients), alt, x$rhs),
     Statistic = unname(s$test$tstat),
@@ -1617,7 +1823,13 @@ get_statistic.glht <- function(x, ...) {
 
 #' @rdname get_statistic
 #' @export
-get_statistic.emmGrid <- function(x, ci = 0.95, adjust = "none", merge_parameters = FALSE, ...) {
+get_statistic.emmGrid <- function(
+  x,
+  ci = 0.95,
+  adjust = "none",
+  merge_parameters = FALSE,
+  ...
+) {
   s <- summary(x, level = ci, adjust = adjust, infer = TRUE)
 
   stat <- s[["t.ratio"]]
@@ -1805,11 +2017,14 @@ get_statistic.Arima <- function(x, ...) {
 get_statistic.wbm <- function(x, ...) {
   s <- summary(x)
 
-  statistic_column <- if ("t val." %in% c(
-    colnames(s$within_table),
-    colnames(s$between_table),
-    colnames(s$ints_table)
-  )) {
+  statistic_column <- if (
+    "t val." %in%
+      c(
+        colnames(s$within_table),
+        colnames(s$between_table),
+        colnames(s$ints_table)
+      )
+  ) {
     "t val."
   } else {
     "z val."
@@ -1867,7 +2082,9 @@ get_statistic.sem <- function(x, ...) {
   params <- get_parameters(x, effects = "fixed")
 
   if (is.null(x$se)) {
-    format_warning("Model has no standard errors. Please fit model again with bootstrapped standard errors.")
+    format_warning(
+      "Model has no standard errors. Please fit model again with bootstrapped standard errors."
+    )
     return(NULL)
   }
 
@@ -1906,7 +2123,10 @@ get_statistic.cpglm <- function(x, ...) {
 get_statistic.zcpglm <- function(x, component = "all", ...) {
   check_if_installed("cplm")
 
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated"))
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "zi", "zero_inflated")
+  )
   junk <- utils::capture.output(stats <- cplm::summary(x)$coefficients) # nolint
   params <- get_parameters(x)
 
@@ -1953,17 +2173,20 @@ get_statistic.manova <- function(x, ...) {
 #' @export
 get_statistic.maov <- function(x, ...) {
   s <- summary(x)
-  out <- do.call(rbind, lapply(names(s), function(i) {
-    stats <- s[[i]]
-    missing_values <- is.na(stats[["F value"]])
-    data.frame(
-      Parameter = rownames(stats)[!missing_values],
-      Statistic = as.vector(stats[["F value"]][!missing_values]),
-      Response = gsub("\\s*Response ", "", i),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
-  }))
+  out <- do.call(
+    rbind,
+    lapply(names(s), function(i) {
+      stats <- s[[i]]
+      missing_values <- is.na(stats[["F value"]])
+      data.frame(
+        Parameter = rownames(stats)[!missing_values],
+        Statistic = as.vector(stats[["F value"]][!missing_values]),
+        Response = gsub("\\s*Response ", "", i),
+        stringsAsFactors = FALSE,
+        row.names = NULL
+      )
+    })
+  )
 
   attr(out, "statistic") <- find_statistic(x)
   out
@@ -2079,10 +2302,8 @@ get_statistic.nlrq <- get_statistic.rq
 
 
 #' @export
-get_statistic.rqss <- function(x,
-                               component = c("all", "conditional", "smooth_terms"),
-                               ...) {
-  component <- match.arg(component)
+get_statistic.rqss <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "smooth_terms"))
 
   cs <- summary(x)
   stat <- c(as.vector(cs$coef[, "t value"]), as.vector(cs$qsstab[, "F value"]))
