@@ -14,10 +14,12 @@
 #' of `"conditional"`, `"zi"`, `"zero-inflated"`, `"dispersion"`, `"precision"`,
 #' or `"all"`. May be abbreviated. Note that the *conditional* component also
 #' refers to the *count* or *mean* component - names may differ, depending on
-#' the modeling package.
+#' the modeling package. See section _Model components_ for details. For models
+#' of class `glmmTMB`, the `component` argument can also be `"full"`, to return
+#' the full variance-covariance matrix (including random effects, called `theta`).
 #' @param effects Should the complete variance-covariance matrix of the model
 #' be returned, or only for specific model parameters only? Currently only
-#' applies to models of class `mixor`.
+#' applies to models of class `mixor` and `MixMod`.
 #' @param complete Logical, if `TRUE`, for `aov`, returns the full
 #' variance-covariance matrix.
 #' @param vcov Variance-covariance matrix used to compute uncertainty estimates
@@ -37,6 +39,13 @@
 #'    - Other `sandwich` package functions: `"HAC"`, `"PC"`, `"CL"`, `"OPG"`,
 #'      `"PL"`.
 #'    - Kenward-Roger approximation: `kenward-roger`. See `?pbkrtest::vcovAdj`.
+#'
+#' Exceptions are following models:
+#' - Model of class `glmgee`, which have pre-defined options for the
+#'   variance-covariance matrix calculation. These are `"robust"`,
+#'   `"df-adjusted"`, `"model"`, `"bias-corrected"`, and `"jackknife"`. See
+#'   `?glmtoolbox::vcov.glmgee` for details.
+#' - Model of class `glmmTMB` currently only support the `"HC0"` option.
 #' @param vcov_args List of arguments to be passed to the function identified by
 #'   the `vcov` argument. This function is typically supplied by the
 #'   **sandwich** or **clubSandwich** packages. Please refer to their
@@ -53,6 +62,8 @@
 #'   errors of model parameters. A message is shown when the matrix is negative
 #'   definite and a corrected matrix is returned.
 #'
+#' @inheritSection find_predictors Model components
+#'
 #' @return The variance-covariance matrix, as `matrix`-object.
 #'
 #' @examplesIf require("pscl") && require("sandwich")
@@ -82,14 +93,9 @@ get_varcov <- function(x, ...) {
 
 # Default models ----------------------------------------------------
 
-
 #' @rdname get_varcov
 #' @export
-get_varcov.default <- function(x,
-                               verbose = TRUE,
-                               vcov = NULL,
-                               vcov_args = NULL,
-                               ...) {
+get_varcov.default <- function(x, verbose = TRUE, vcov = NULL, vcov_args = NULL, ...) {
   .check_get_varcov_dots(x, ...)
   # process vcov-argument
   vcov <- .check_vcov_args(x, vcov = vcov, verbose = verbose, ...)
@@ -97,7 +103,8 @@ get_varcov.default <- function(x,
   if (is.null(vcov)) {
     vc <- .safe_vcov(x)
   } else {
-    vc <- .get_varcov_sandwich(x,
+    vc <- .get_varcov_sandwich(
+      x,
       vcov_fun = vcov,
       vcov_args = vcov_args,
       verbose = FALSE,
@@ -120,10 +127,7 @@ get_varcov.geeglm <- get_varcov.default
 # fixest ---------------------------------------------
 
 #' @export
-get_varcov.fixest <- function(x,
-                              vcov = NULL,
-                              vcov_args = NULL,
-                              ...) {
+get_varcov.fixest <- function(x, vcov = NULL, vcov_args = NULL, ...) {
   # fixest supplies its own mechanism. Vincent thinks it might not be wise to
   # try `sandwich`, because there may be inconsistencies.
   check_if_installed("fixest")
@@ -147,10 +151,7 @@ get_varcov.asym <- function(x, ...) {
 # mlm ---------------------------------------------
 
 #' @export
-get_varcov.mlm <- function(x,
-                           vcov = NULL,
-                           vcov_args = NULL,
-                           ...) {
+get_varcov.mlm <- function(x, vcov = NULL, vcov_args = NULL, ...) {
   .check_get_varcov_dots(x, ...)
   if (is.null(x$weights)) {
     get_varcov.default(x, vcov = vcov, vcov_args = vcov_args, ...)
@@ -166,27 +167,27 @@ get_varcov.mlm <- function(x,
 
 # models with special components ---------------------------------------------
 
-
 #' @rdname get_varcov
 #' @export
-get_varcov.glmgee <- function(x,
-                              verbose = TRUE,
-                              vcov = c("robust", "df-adjusted", "model", "bias-corrected", "jackknife"),
-                              ...) {
-  vcov <- match.arg(vcov)
+get_varcov.glmgee <- function(x, verbose = TRUE, vcov = "robust", ...) {
+  vcov <- validate_argument(
+    vcov,
+    c("robust", "df-adjusted", "model", "bias-corrected", "jackknife")
+  )
   vc <- suppressWarnings(stats::vcov(x, type = vcov))
   .process_vcov(vc, verbose, ...)
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.nestedLogit <- function(x,
-                                   component = "all",
-                                   verbose = TRUE,
-                                   vcov = NULL,
-                                   vcov_args = NULL,
-                                   ...) {
+get_varcov.nestedLogit <- function(
+  x,
+  component = "all",
+  vcov = NULL,
+  vcov_args = NULL,
+  verbose = TRUE,
+  ...
+) {
   vcovs <- lapply(
     x$models,
     get_varcov,
@@ -218,16 +219,48 @@ get_varcov.nestedLogit <- function(x,
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.betareg <- function(x,
-                               component = c("conditional", "precision", "all"),
-                               verbose = TRUE,
-                               ...) {
-  .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+get_varcov.sdmTMB <- function(x, verbose = TRUE, ...) {
+  delta_comp <- isTRUE(x$family$delta)
+  vc <- suppressWarnings(stats::vcov(x, complete = TRUE, ...))
 
-  vc <- switch(component,
+  # make sure we find all parameters
+  params <- suppressMessages(names(stats::coef(x)))
+
+  # extract relevant vcov-values
+  if (delta_comp) {
+    dups <- duplicated(colnames(vc))
+    vc <- vc[!dups, !dups, drop = FALSE]
+    index <- grepl("^(b_j|bs|\\(Intercept\\)|b\\d+)", colnames(vc)) |
+      colnames(vc) %in% params
+  } else {
+    index <- grepl("^(b_j$|bs|\\(Intercept\\)|b\\d+)", colnames(vc)) |
+      colnames(vc) %in% params
+  }
+  vc <- vc[index, index, drop = FALSE]
+
+  # fix parameter names
+  if (length(params) < nrow(vc)) {
+    vc_names <- colnames(vc)
+    params1 <- params[match(gsub("^b_j(.*)", "(Intercept)", vc_names), params)]
+    params1[is.na(params1)] <- setdiff(params, params1)
+    params <- params1
+  }
+
+  # update names, so that they match with parameter names
+  dimnames(vc) <- list(params, params)
+
+  .process_vcov(vc, verbose, ...)
+}
+
+
+#' @export
+get_varcov.betareg <- function(x, component = "conditional", verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  component <- validate_argument(component, c("conditional", "precision", "all"))
+
+  vc <- switch(
+    component,
     conditional = stats::vcov(object = x, model = "mean"),
     precision = stats::vcov(object = x, model = "precision"),
     stats::vcov(object = x)
@@ -237,12 +270,14 @@ get_varcov.betareg <- function(x,
 
 
 #' @export
-get_varcov.DirichletRegModel <- function(x,
-                                         component = c("conditional", "precision", "all"),
-                                         verbose = TRUE,
-                                         ...) {
+get_varcov.DirichletRegModel <- function(
+  x,
+  component = "conditional",
+  verbose = TRUE,
+  ...
+) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("conditional", "precision", "all"))
   if (x$parametrization == "common") {
     vc <- .safe_vcov(x)
   } else if (component == "conditional") {
@@ -260,13 +295,10 @@ get_varcov.DirichletRegModel <- function(x,
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.clm2 <- function(x,
-                            component = c("all", "conditional", "scale"),
-                            ...) {
+get_varcov.clm2 <- function(x, component = "all", ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("all", "conditional", "scale"))
 
   n_intercepts <- length(x$xi)
   n_location <- length(x$beta)
@@ -278,7 +310,8 @@ get_varcov.clm2 <- function(x,
     vc <- .fix_negative_matrix(vc)
   }
 
-  col_range <- switch(component,
+  col_range <- switch(
+    component,
     all = 1:(n_scale + n_intercepts + n_location),
     conditional = 1:(n_intercepts + n_location),
     scale = (1 + n_intercepts + n_location):(n_scale + n_intercepts + n_location)
@@ -297,12 +330,9 @@ get_varcov.clmm2 <- get_varcov.clm2
 
 
 #' @export
-get_varcov.glmx <- function(x,
-                            component = c("all", "conditional", "extra"),
-                            verbose = TRUE,
-                            ...) {
+get_varcov.glmx <- function(x, component = "all", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("all", "conditional", "extra"))
   vc <- stats::vcov(object = x)
 
   if (component != "all") {
@@ -314,21 +344,24 @@ get_varcov.glmx <- function(x,
 
 
 #' @export
-get_varcov.pgmm <- function(x,
-                            component = c("conditional", "all"),
-                            vcov = NULL,
-                            vcov_args = NULL,
-                            verbose = TRUE,
-                            ...) {
+get_varcov.pgmm <- function(
+  x,
+  component = "conditional",
+  vcov = NULL,
+  vcov_args = NULL,
+  verbose = TRUE,
+  ...
+) {
   .check_get_varcov_dots(x, ...)
   # process vcov-argument
   vcov <- .check_vcov_args(x, vcov = vcov, verbose = verbose, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("conditional", "all"))
 
   if (is.null(vcov)) {
     vc <- .safe_vcov(x)
   } else {
-    vc <- .get_varcov_sandwich(x,
+    vc <- .get_varcov_sandwich(
+      x,
       vcov_fun = vcov,
       vcov_args = vcov_args,
       verbose = FALSE,
@@ -345,11 +378,9 @@ get_varcov.pgmm <- function(x,
 
 
 #' @export
-get_varcov.selection <- function(x,
-                                 component = c("all", "selection", "outcome", "auxiliary"),
-                                 ...) {
+get_varcov.selection <- function(x, component = "all", ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("all", "selection", "outcome", "auxiliary"))
   vc <- stats::vcov(object = x)
 
   if (component != "all") {
@@ -366,12 +397,12 @@ get_varcov.selection <- function(x,
 
 
 #' @export
-get_varcov.mvord <- function(x,
-                             component = c("all", "conditional", "thresholds", "correlation"),
-                             verbose = TRUE,
-                             ...) {
+get_varcov.mvord <- function(x, component = "all", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "thresholds", "correlation")
+  )
   vc <- .safe_vcov(x)
 
   if (component != "all") {
@@ -387,12 +418,9 @@ get_varcov.mvord <- function(x,
 
 
 #' @export
-get_varcov.mjoint <- function(x,
-                              component = c("all", "conditional", "survival"),
-                              verbose = TRUE,
-                              ...) {
+get_varcov.mjoint <- function(x, component = "all", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("all", "conditional", "survival"))
   vc <- .safe_vcov(x)
 
   keep <- match(find_parameters(x, flatten = TRUE, component = component), rownames(vc))
@@ -402,12 +430,16 @@ get_varcov.mjoint <- function(x,
 
 
 #' @export
-get_varcov.mhurdle <- function(x,
-                               component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"), # nolint
-                               verbose = TRUE,
-                               ...) {
+get_varcov.mhurdle <- function(x, component = "all", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  # fmt: skip
+  component <- validate_argument(
+    component,
+    c(
+      "all", "conditional", "zi", "zero_inflated", "infrequent_purchase",
+      "ip", "auxiliary"
+    )
+  )
   vc <- .safe_vcov(x)
 
   # rownames(vc) <- gsub("^(h1|h2|h3)\\.(.*)", "\\2", rownames(vc))
@@ -419,11 +451,10 @@ get_varcov.mhurdle <- function(x,
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.truncreg <- function(x, component = c("conditional", "all"), verbose = TRUE, ...) {
+get_varcov.truncreg <- function(x, component = "conditional", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("conditional", "all"))
   vc <- .safe_vcov(x)
 
   if (component == "conditional") {
@@ -434,9 +465,9 @@ get_varcov.truncreg <- function(x, component = c("conditional", "all"), verbose
 
 
 #' @export
-get_varcov.gamlss <- function(x, component = c("conditional", "all"), verbose = TRUE, ...) {
+get_varcov.gamlss <- function(x, component = "conditional", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("conditional", "all"))
   vc <- .safe_vcov(x)
 
   if (component == "conditional") {
@@ -449,36 +480,43 @@ get_varcov.gamlss <- function(x, component = c("conditional", "all"), verbose =
 
 # Zero-Inflated models ----------------------------------------------------
 
-
 #' @rdname get_varcov
 #' @export
-get_varcov.hurdle <- function(x,
-                              component = c("conditional", "zero_inflated", "zi", "all"),
-                              vcov = NULL,
-                              vcov_args = NULL,
-                              verbose = TRUE,
-                              ...) {
+get_varcov.hurdle <- function(
+  x,
+  component = "conditional",
+  vcov = NULL,
+  vcov_args = NULL,
+  verbose = TRUE,
+  ...
+) {
   .check_get_varcov_dots(x, ...)
   # process vcov-argument
   vcov <- .check_vcov_args(x, vcov = vcov, verbose = verbose, ...)
 
-  component <- match.arg(component)
+  component <- validate_argument(
+    component,
+    c("conditional", "zero_inflated", "zi", "all")
+  )
 
   if (is.null(vcov)) {
-    vc <- switch(component,
+    vc <- switch(
+      component,
       conditional = stats::vcov(object = x, model = "count"),
       zi = ,
       zero_inflated = stats::vcov(object = x, model = "zero"),
       stats::vcov(object = x)
     )
   } else {
-    vc <- .get_varcov_sandwich(x,
+    vc <- .get_varcov_sandwich(
+      x,
       vcov_fun = vcov,
       vcov_args = vcov_args,
       verbose = verbose,
       ...
     )
-    keep <- switch(component,
+    keep <- switch(
+      component,
       conditional = startsWith(colnames(vc), "count_"),
       zi = ,
       zero_inflated = startsWith(colnames(vc), "zero_"),
@@ -497,13 +535,12 @@ get_varcov.zeroinfl <- get_varcov.hurdle
 get_varcov.zerocount <- get_varcov.hurdle
 
 #' @export
-get_varcov.zcpglm <- function(x,
-                              component = c("conditional", "zero_inflated", "zi", "all"),
-                              verbose = TRUE,
-                              ...) {
+get_varcov.zcpglm <- function(x, component = "conditional", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
-
+  component <- validate_argument(
+    component,
+    c("conditional", "zero_inflated", "zi", "all")
+  )
 
   check_if_installed("cplm")
 
@@ -511,7 +548,8 @@ get_varcov.zcpglm <- function(x,
   tweedie <- which(startsWith(rownames(vc), "tw_"))
   zero <- which(startsWith(rownames(vc), "zero_"))
 
-  vc <- switch(component,
+  vc <- switch(
+    component,
     conditional = vc[tweedie, tweedie, drop = FALSE],
     zi = ,
     zero_inflated = vc[zero, zero, drop = FALSE],
@@ -523,34 +561,75 @@ get_varcov.zcpglm <- function(x,
 
 # Zero-Inflated mixed models ------------------------------------------------
 
-
-#' @rdname get_varcov
 #' @export
-get_varcov.glmmTMB <- function(x,
-                               component = c("conditional", "zero_inflated", "zi", "dispersion", "all"),
-                               verbose = TRUE,
-                               ...) {
+get_varcov.glmmTMB <- function(
+  x,
+  component = "conditional",
+  vcov = NULL,
+  vcov_args = NULL,
+  verbose = TRUE,
+  ...
+) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
-
-  vc <- switch(component,
-    conditional = .safe_vcov(x)[["cond"]],
-    zi = ,
-    zero_inflated = .safe_vcov(x)[["zi"]],
-    dispersion = .safe_vcov(x)[["disp"]],
-    stats::vcov(x, full = TRUE)
+  component <- validate_argument(
+    component,
+    c("conditional", "zero_inflated", "zi", "dispersion", "all", "full")
   )
+
+  if (is.null(vcov)) {
+    vc <- switch(
+      component,
+      conditional = .safe_vcov(x)[["cond"]],
+      zi = ,
+      zero_inflated = .safe_vcov(x)[["zi"]],
+      dispersion = .safe_vcov(x)[["disp"]],
+      stats::vcov(x, full = TRUE)
+    )
+  } else {
+    vc <- .get_varcov_sandwich(
+      x,
+      vcov_fun = vcov,
+      vcov_args = vcov_args,
+      full = TRUE,
+      verbose = FALSE,
+      ...
+    )
+
+    # find parameters for each component
+    theta_parms <- startsWith(colnames(vc), "theta_")
+    zi_parms <- startsWith(colnames(vc), "zi~")
+    disp_parms <- startsWith(colnames(vc), "disp~")
+    cond_parms <- !zi_parms & !disp_parms & !theta_parms
+
+    # filter vcov
+    vc <- switch(
+      component,
+      conditional = vc[cond_parms, cond_parms, drop = FALSE],
+      zi = ,
+      zero_inflated = vc[zi_parms, zi_parms, drop = FALSE],
+      dispersion = vc[disp_parms, disp_parms, drop = FALSE],
+      vc
+    )
+  }
+
+  # drop theta parameters
+  theta_parms <- startsWith(colnames(vc), "theta_")
+  if (any(theta_parms) && component != "full") {
+    vc <- vc[!theta_parms, !theta_parms, drop = FALSE]
+  }
+
   .process_vcov(vc, verbose, ...)
 }
 
 
-#' @rdname get_varcov
 #' @export
-get_varcov.MixMod <- function(x,
-                              effects = c("fixed", "random"),
-                              component = c("conditional", "zero_inflated", "zi", "dispersion", "auxiliary", "all"),
-                              verbose = TRUE,
-                              ...) {
+get_varcov.MixMod <- function(
+  x,
+  effects = "fixed",
+  component = "conditional",
+  verbose = TRUE,
+  ...
+) {
   .check_get_varcov_dots(x, ...)
 
   # backward compatibility. there used to be a `robust` argument in this
@@ -558,15 +637,19 @@ get_varcov.MixMod <- function(x,
   # does not seem to be a documented argument for the `MixMod` class.
   robust <- isTRUE(list(...)[["robust"]])
 
-  component <- match.arg(component)
-  effects <- match.arg(effects)
+  component <- validate_argument(
+    component,
+    c("conditional", "zero_inflated", "zi", "dispersion", "auxiliary", "all")
+  )
+  effects <- validate_argument(effects, c("fixed", "random"))
 
   random_vc <- stats::vcov(x, parm = "var-cov", sandwich = robust)
 
   if (effects == "random") {
     vc <- random_vc
   } else {
-    vc <- switch(component,
+    vc <- switch(
+      component,
       conditional = stats::vcov(x, parm = "fixed-effects", sandwich = robust),
       zero_inflated = ,
       zi = stats::vcov(x, parm = "all", sandwich = robust),
@@ -595,12 +678,10 @@ get_varcov.MixMod <- function(x,
 
 # Bayesian models ------------------------------------------------
 
-
-#' @rdname get_varcov
 #' @export
 get_varcov.brmsfit <- function(x, component = "conditional", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component, choices = c("all", .all_elements()))
+  component <- validate_argument(component, c("all", .all_elements()))
   params <- find_parameters(x, effects = "fixed", component = component, flatten = TRUE)
   params <- gsub("^b_", "", params)
 
@@ -619,15 +700,10 @@ get_varcov.brmsfit <- function(x, component = "conditional", verbose = TRUE, ...
 
 # mfx models -------------------------------------------------------
 
-
-#' @rdname get_varcov
 #' @export
-get_varcov.betamfx <- function(x,
-                               component = c("conditional", "precision", "all"),
-                               verbose = TRUE,
-                               ...) {
+get_varcov.betamfx <- function(x, component = "conditional", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  component <- match.arg(component)
+  component <- validate_argument(component, c("conditional", "precision", "all"))
   get_varcov.betareg(x$fit, component = component, verbose = verbose, ...)
 }
 
@@ -664,7 +740,6 @@ get_varcov.model_fit <- get_varcov.logitmfx
 
 # Other models with special handling -----------------------------------------
 
-
 #' @export
 get_varcov.flic <- function(x, verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
@@ -675,6 +750,23 @@ get_varcov.flic <- function(x, verbose = TRUE, ...) {
 get_varcov.flac <- get_varcov.flic
 
 
+#' @export
+get_varcov.estimate_means <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+  v <- attributes(x)$vcov
+  if (is.null(v)) {
+    return(get_varcov(get_model(x), verbose = verbose, ...))
+  }
+  .process_vcov(v, verbose, ...)
+}
+
+#' @export
+get_varcov.estimate_slopes <- get_varcov.estimate_means
+
+#' @export
+get_varcov.estimate_contrasts <- get_varcov.estimate_means
+
+
 #' @export
 get_varcov.merModList <- function(x, ...) {
   .check_get_varcov_dots(x, ...)
@@ -683,6 +775,34 @@ get_varcov.merModList <- function(x, ...) {
 }
 
 
+#' @export
+get_varcov.lcmm <- function(x, verbose = TRUE, ...) {
+  .check_get_varcov_dots(x, ...)
+
+  # extract vcov, which, however, is stored as a vector
+  V <- x$V
+  # get number of parameters
+  p <- length(x$best)
+
+  # create empty matrix
+  vcov_matrix <- matrix(0, nrow = p, ncol = p)
+  # fill upper triangle
+  vcov_matrix[upper.tri(vcov_matrix, diag = TRUE)] <- V
+  # fill lower triangle
+  vcov_matrix[lower.tri(vcov_matrix)] <- t(vcov_matrix)[lower.tri(vcov_matrix)]
+  # set names
+  dimnames(vcov_matrix) <- list(names(x$best), names(x$best))
+
+  .process_vcov(vcov_matrix, verbose = verbose, ...)
+}
+
+#' @export
+get_varcov.externX <- get_varcov.lcmm
+
+#' @export
+get_varcov.externVar <- get_varcov.lcmm
+
+
 #' @export
 get_varcov.mediate <- function(x, ...) {
   .check_get_varcov_dots(x, ...)
@@ -711,7 +831,9 @@ get_varcov.ivFixed <- function(x, verbose = TRUE, ...) {
 get_varcov.averaging <- function(x, verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
   if (is.null(attributes(x)$modelList)) {
-    format_warning("Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'.")
+    format_warning(
+      "Can't calculate covariance matrix. Please use 'fit = TRUE' in 'model.avg()'."
+    )
   } else {
     get_varcov.default(x, verbose = verbose, ...)
   }
@@ -876,9 +998,9 @@ get_varcov.mle <- get_varcov.mle2
 
 #' @rdname get_varcov
 #' @export
-get_varcov.mixor <- function(x, effects = c("all", "fixed", "random"), verbose = TRUE, ...) {
+get_varcov.mixor <- function(x, effects = "all", verbose = TRUE, ...) {
   .check_get_varcov_dots(x, ...)
-  effects <- match.arg(effects)
+  effects <- validate_argument(effects, c("all", "fixed", "random"))
   params <- find_parameters(x, effects = effects, flatten = TRUE)
   vc <- as.matrix(.safe_vcov(x))[params, params, drop = FALSE]
   .process_vcov(vc, verbose, ...)
@@ -905,7 +1027,7 @@ get_varcov.lqmm <- function(x, ...) {
 
   if (length(dim(sc$Cov)) == 3) {
     vc <- lapply(seq_along(x$tau), function(i) {
-      .x <- sc$Cov[, , i][1:np, 1:np]
+      .x <- sc$Cov[,, i][1:np, 1:np]
       if (.is_negativ_matrix(.x, ...)) {
         .x <- .fix_negative_matrix(.x)
       }
@@ -1045,7 +1167,6 @@ get_varcov.LORgee <- get_varcov.gee
 
 # helper-functions -----------------------------------------------------
 
-
 .safe_vcov <- function(x) {
   vc <- tryCatch(
     suppressWarnings(stats::vcov(x)),
@@ -1054,19 +1175,32 @@ get_varcov.LORgee <- get_varcov.gee
   if (inherits(vc, "error")) {
     # check for dates or times, which can cause the error
     my_data <- get_data(x, verbose = FALSE)
-    if (!is.null(my_data) && any(vapply(my_data, inherits, FUN.VALUE = logical(1), what = c("Date", "POSIXt", "difftime")))) { # nolint
+    if (
+      !is.null(my_data) &&
+        any(vapply(
+          my_data,
+          inherits,
+          FUN.VALUE = logical(1),
+          what = c("Date", "POSIXt", "difftime")
+        ))
+    ) {
+      # nolint
       msg <- "A reason might be that your model includes dates or times. Please convert them to numeric values before fitting the model." # nolint
     } else {
       msg <- NULL
     }
-    format_error(paste(
-      "Can't extract variance-covariance matrix. `get_varcov()` returned following error:",
-      vc$message
-    ), msg)
+    format_error(
+      paste(
+        "Can't extract variance-covariance matrix. `get_varcov()` returned following error:",
+        vc$message
+      ),
+      msg
+    )
   }
   vc
 }
 
+
 .process_vcov <- function(vc, verbose = TRUE, ...) {
   if (.is_negativ_matrix(vc, ...)) {
     vc <- .fix_negative_matrix(vc)
@@ -1115,7 +1249,9 @@ get_varcov.LORgee <- get_varcov.gee
 .fix_rank_deficiency <- function(m, verbose = TRUE) {
   if (anyNA(m)) {
     if (isTRUE(verbose)) {
-      format_warning("Model matrix is rank deficient. Some variance-covariance parameters are missing.")
+      format_warning(
+        "Model matrix is rank deficient. Some variance-covariance parameters are missing."
+      )
     }
     mm <- m[!is.na(m)]
     if (!is.matrix(mm)) {
@@ -1173,11 +1309,16 @@ get_varcov.LORgee <- get_varcov.gee
   # warning here.
   if ("vcov" %in% names(dots) && !is.null(dots[["vcov"]])) {
     format_warning(
-      sprintf("The `vcov` argument of the `insight::get_varcov()` function is not yet supported for models of class `%s`.", paste(class(x), collapse = "/")) # nolint
+      sprintf(
+        "The `vcov` argument of the `insight::get_varcov()` function is not yet supported for models of class `%s`.",
+        paste(class(x), collapse = "/")
+      ) # nolint
     )
   }
   if ("robust" %in% names(dots) && !is.null(dots[["robust"]])) {
-    format_warning("The `robust` argument is no longer supported. Please use the `vcov` and `vcov_args` instead.") # nolint
+    format_warning(
+      "The `robust` argument is no longer supported. Please use the `vcov` and `vcov_args` instead."
+    ) # nolint
   }
 }
 
