@@ -1,10 +1,12 @@
 # Get Variance-covariance Matrix ---------------------------------------------------
 
-.get_varcov_sandwich <- function(x,
-                                 vcov_fun = NULL,
-                                 vcov_args = NULL,
-                                 verbose = TRUE,
-                                 ...) {
+.get_varcov_sandwich <- function(
+  x,
+  vcov_fun = NULL,
+  vcov_args = NULL,
+  verbose = TRUE,
+  ...
+) {
   dots <- list(...)
 
   if (is.null(vcov_args)) {
@@ -27,6 +29,7 @@
     return(.vcov)
   }
 
+  # fmt: skip
   vcov_type_shortcuts <- c(
     "HC0", "HC1", "HC2", "HC3", "HC4", "HC4m", "HC5", "CR0", "CR1",
     "CR1p", "CR1S", "CR2", "CR3", "xy", "residual", "wild", "mammen",
@@ -39,10 +42,7 @@
       vcov_args[["type"]] <- vcov_fun
     } else if (is.null(vcov_fun)) {
       # set defaults
-      vcov_args[["type"]] <- switch(vcov_fun,
-        CR = "CR3",
-        NULL
-      )
+      vcov_args[["type"]] <- switch(vcov_fun, CR = "CR3", NULL)
     }
   }
 
@@ -57,7 +57,8 @@
   if (grepl("^(vcov|kernHAC|NeweyWest)", vcov_fun)) {
     vcov_fun_clean <- vcov_fun
   } else {
-    vcov_fun_clean <- switch(vcov_fun,
+    vcov_fun_clean <- switch(
+      vcov_fun,
       HC0 = ,
       HC1 = ,
       HC2 = ,
@@ -93,10 +94,21 @@
 
   # check if required package is available
   if (is.character(vcov_fun) && is.null(vcov_fun_clean)) {
-    format_error(sprintf("`%s` is not a recognized value for the `vcov` argument.", vcov_fun[1]))
+    format_error(sprintf(
+      "`%s` is not a recognized value for the `vcov` argument.",
+      vcov_fun[1]
+    ))
   } else if (isTRUE(vcov_fun_clean == "vcovAdj")) {
-    check_if_installed("pbkrtest")
-    fun <- try(get(vcov_fun_clean, asNamespace("pbkrtest")), silent = TRUE)
+    if (inherits(x, "glmmTMB")) {
+      # for glmmTMB, we have the KR-adjusted vcov as attributed saved
+      # in the degrees of freedom
+      dof <- .degrees_of_freedom_kr(x, verbose = verbose)
+      return(attributes(dof)$vcov)
+    } else {
+      # for other packages, we need pbkrtest
+      check_if_installed("pbkrtest")
+      fun <- try(get(vcov_fun_clean, asNamespace("pbkrtest")), silent = TRUE)
+    }
   } else if (isTRUE(vcov_fun_clean == "vcovCR")) {
     check_if_installed("clubSandwich", reason = "to get cluster-robust standard errors")
     fun <- try(get(vcov_fun_clean, asNamespace("clubSandwich")), silent = TRUE)
@@ -104,12 +116,20 @@
     check_if_installed("sandwich", reason = "to get robust standard errors")
     fun <- try(get(vcov_fun_clean, asNamespace("sandwich")), silent = TRUE)
     if (!is.function(fun) && is.character(vcov_fun)) {
-      format_error(sprintf("`%s` is not a function exported by the `sandwich` package.", vcov_fun[1]))
+      format_error(sprintf(
+        "`%s` is not a function exported by the `sandwich` package.",
+        vcov_fun[1]
+      ))
     }
   }
 
   vcov_fun <- vcov_fun_clean
 
+  # for glmmTMB models, we allow "full = TRUE" to get the full vcov matrix
+  if (isTRUE(dots$full) && inherits(x, "glmmTMB")) {
+    vcov_args[["full"]] <- TRUE
+  }
+
   # try with arguments
   .vcov <- try(do.call(fun, c(list(x), vcov_args)), silent = TRUE)
   if (!inherits(.vcov, "try-error")) {
@@ -118,7 +138,10 @@
 
   # extract variance-covariance matrix
   if (!inherits(.vcov, "matrix")) {
-    msg <- sprintf("Unable to extract a variance-covariance matrix for model object of class `%s`. Different values of the `vcov` argument trigger calls to the `sandwich` or `clubSandwich` packages in order to extract the matrix (see `?insight::get_varcov`). Your model or the requested estimation type may not be supported by one or both of those packages, or you were missing one or more required arguments in `vcov_args` (like `cluster`).", class(x)[1]) # nolint
+    msg <- sprintf(
+      "Unable to extract a variance-covariance matrix for model object of class `%s`. Different values of the `vcov` argument trigger calls to the `sandwich` or `clubSandwich` packages in order to extract the matrix (see `?insight::get_varcov`). Your model or the requested estimation type may not be supported by one or both of those packages, or you were missing one or more required arguments in `vcov_args` (like `cluster`).",
+      class(x)[1]
+    ) # nolint
     if (inherits(.vcov, "try-error")) {
       msg <- c(msg, "", "This error was raised:", attr(.vcov, "condition")$message)
     }
