@@ -80,7 +80,9 @@
   reihenfolge <- c(which(!doubles), which(doubles))
 
   # remove duplicate column names, if requested
-  if (replace && any(doubles)) tmp <- tmp[, !doubles, drop = FALSE]
+  if (replace && any(doubles)) {
+    tmp <- tmp[, !doubles, drop = FALSE]
+  }
 
   # bind all data
   x <- cbind(tmp, data)
@@ -91,7 +93,7 @@
     # but not all variable are duplicates, add indices of regular values
     if (ncol(x) > length(reihenfolge)) {
       # get remaining indices
-      xl <- seq_len(ncol(x))[-seq_len(length(reihenfolge))]
+      xl <- seq_len(ncol(x))[-seq_along(reihenfolge)]
       # add to "reihefolge"
       reihenfolge <- c(reihenfolge, xl)
     }
@@ -118,20 +120,30 @@
 # if there are any chars left, these come from further terms that come after
 # random effects...
 .formula_empty_after_random_effect <- function(f) {
-  nchar(gsub("(~|\\+|\\*|-|/|:)", "", gsub(" ", "", gsub("\\((.*)\\)", "", f), fixed = TRUE))) == 0 # nolint
+  nchar(gsub(
+    "(~|\\+|\\*|-|/|:)",
+    "",
+    gsub(" ", "", gsub("\\((.*)\\)", "", f), fixed = TRUE)
+  )) ==
+    0 # nolint
 }
 
 
 # extract random effects from formula
 .get_model_random <- function(f, model, split_nested = FALSE) {
-  is_special <- inherits(
-    model,
-    c(
-      "MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife",
-      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm",
-      "glmgee"
+  if (is.null(model)) {
+    is_special <- FALSE
+  } else {
+    # fmt: skip
+    is_special <- inherits(
+      model,
+      c(
+        "MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife",
+        "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm",
+        "glmgee"
+      )
     )
-  )
+  }
 
   if (identical(safe_deparse(f), "~0") || identical(safe_deparse(f), "~1")) {
     return(NULL)
@@ -145,6 +157,10 @@
       re <- as.list(re)
       split_nested <- FALSE
     }
+  } else if (is_empty_object(re)) {
+    # need this for the many brms-custom formulas, this exception might not
+    # be yet captured - so make sure, "re" is not empty here.
+    return(NULL)
   } else {
     re <- trim_ws(substring(re, max(gregexpr(pattern = "|", re, fixed = TRUE)[[1]]) + 1))
   }
@@ -184,7 +200,11 @@
     )
 
     if (any(has_parantheses)) {
-      re[has_parantheses] <- gsub(pattern = "[\\(\\)]", replacement = "", x = re[has_parantheses])
+      re[has_parantheses] <- gsub(
+        pattern = "[\\(\\)]",
+        replacement = "",
+        x = re[has_parantheses]
+      )
     }
 
     re
@@ -220,33 +240,55 @@
 
 # helper to access model components ----------------
 
+# fmt: skip
 .all_elements <- function() {
   c(
-    "conditional", "conditional1", "conditional2", "conditional3", "precision",
-    "nonlinear", "random", "zi", "zero_inflated", "zero_inflated_random", "shape",
-    "dispersion", "dispersion_random", "instruments", "interactions", "simplex",
-    "smooth_terms", "sigma", "nu", "tau", "correlation", "slopes", "cluster",
-    "extra", "scale", "marginal", "alpha", "beta", "survival", "infrequent_purchase",
-    "auxiliary", "mix", "shiftprop", "phi", "ndt", "hu", "xi", "coi", "zoi",
-    "aux", "dist", "selection", "outcome", "time_dummies", "sigma_random",
-    "beta_random", "car", "nominal", "bidrange", "mu", "kappa", "bias"
+    # these come first
+    "conditional", "conditional1", "conditional2", "conditional3",
+    "precision", "nonlinear",
+    # regular random
+    "random",
+    # zero-inflated and random
+    "zero_inflated", "zero_inflated_random",
+    "zi", "zi_random",
+    # dispersion and random
+    "dispersion", "dispersion_random",
+    # then instruments and smooth terms
+    "instruments", "interactions", "smooth_terms",
+    # then auxiliary
+    "alpha", "aux", "auxiliary", "beta", "beta_random", "bias",
+    "bs", "bidrange", "car", "cluster", "coi", "correlation", "delta",
+    "dist", "extra", "hu", "infrequent_purchase", "k", "kappa", "marginal",
+    "mix", "mu", "ndt", "nominal", "nu", "outcome", "phi", "scale", "selection",
+    "shape", "shiftprop", "sigma", "simplex", "slopes", "survival", "tau",
+    "time_dummies", "xi", "zoi",
+    # special elements, from lcmm
+    "linear", "splines", "membership", "longitudinal", "mixture", "classmb",
+    # special elements, from survey
+    "design",
+    # other random parameters
+    "sigma_random"
   )
 }
 
+# fmt: skip
 .aux_elements <- function() {
   c(
-    "sigma", "alpha", "beta", "dispersion", "precision", "nu", "tau", "shape",
-    "phi", "(phi)", "ndt", "hu", "xi", "coi", "zoi", "mix", "shiftprop", "auxiliary",
-    "aux", "dist", "mu", "kappa", "bias",
+    "(phi)", "alpha", "aux", "auxiliary", "beta", "bias", "coi", "dispersion",
+    "dist", "hu", "kappa", "mix", "mu", "ndt", "nu", "phi", "precision",
+    "shape", "shiftprop", "sigma", "tau", "xi", "zoi",
+    # special elements, from lcmm
+    "linear", "splines", "membership", "longitudinal", "mixture", "classmb",
     # random parameters
     "dispersion_random", "sigma_random", "beta_random"
   )
 }
 
+# fmt: skip
 .brms_aux_elements <- function() {
   c(
-    "sigma", "mu", "nu", "shape", "beta", "phi", "hu", "ndt", "zoi", "coi",
-    "kappa", "bias", "bs", "zi", "alpha", "xi"
+    "alpha", "beta", "bias", "bs", "coi", "delta", "hu", "k", "kappa",
+    "mu", "ndt", "nu", "phi", "shape", "sigma", "xi", "zi", "zoi"
   )
 }
 
@@ -255,23 +297,40 @@
   elements <- .all_elements()
 
   # zero-inflation component
-  zero_inflated_component <- c("zi", "zero_inflated", "zero_inflated_random")
+  zero_inflated_component <- c("zi", "zi_random", "zero_inflated", "zero_inflated_random")
 
   # auxiliary parameters
   auxiliary_parameters <- .aux_elements()
 
   # random parameters
-  random_parameters <- c("random", "zero_inflated_random", "dispersion_random", "sigma_random", "beta_random", "car")
+  random_parameters <- c(
+    "random",
+    "zero_inflated_random",
+    "zi_random",
+    "dispersion_random",
+    "sigma_random",
+    "beta_random",
+    "car"
+  )
 
   # conditional component
   conditional_component <- setdiff(
     elements,
-    c(auxiliary_parameters, zero_inflated_component, "smooth_terms", "nonlinear")
+    c(
+      auxiliary_parameters,
+      zero_inflated_component,
+      "smooth_terms",
+      "nonlinear",
+      "design"
+    )
   )
 
   # location parameters
-  location_parameters <- switch(effects,
+  location_parameters <- switch(
+    effects,
     fixed = setdiff(elements, c(auxiliary_parameters, random_parameters)),
+    grouplevel = ,
+    random_variance = ,
     random = intersect(setdiff(elements, auxiliary_parameters), random_parameters),
     setdiff(elements, auxiliary_parameters)
   )
@@ -290,17 +349,21 @@
   # that are not covered by the standard elements. We then just do not
   # filter elements.
   if (inherits(model, "brmsfit") && component == "all") {
-    f <- insight::find_formula(model, verbose = FALSE)
-    elements <- unique(c(elements, names(f)))
+    elements <- unique(c(elements, find_auxiliary(model, verbose = FALSE)))
   }
 
-  elements <- switch(effects,
-    all = elements,
-    fixed = elements[!elements %in% random_parameters],
-    random = elements[elements %in% random_parameters]
+  elements <- switch(
+    effects,
+    all = ,
+    full = elements,
+    fixed = elements[!elements %in% random_parameters & !endsWith(elements, "random")],
+    grouplevel = ,
+    random_variance = ,
+    random = elements[elements %in% random_parameters | endsWith(elements, "random")]
   )
 
-  elements <- switch(component,
+  elements <- switch(
+    component,
     all = elements,
     cond = ,
     conditional = elements[elements %in% conditional_component],
@@ -335,13 +398,16 @@
 
 .filter_pars_univariate <- function(l, parameters) {
   lapply(l, function(component) {
-    unlist(sapply(
-      parameters,
-      function(pattern) {
-        grep(pattern = pattern, x = component, perl = TRUE, value = TRUE)
-      },
-      simplify = FALSE
-    ), use.names = FALSE)
+    unlist(
+      sapply(
+        parameters,
+        function(pattern) {
+          grep(pattern = pattern, x = component, perl = TRUE, value = TRUE)
+        },
+        simplify = FALSE
+      ),
+      use.names = FALSE
+    )
   })
 }
 
@@ -371,7 +437,9 @@
 
 .grep_zi_smoothers <- function(x) {
   # this one captures smoothers in zi- or mv-models from gam
-  grepl("^(s\\.\\d\\()", x) | grepl("^(gam::s\\.\\d\\()", x) | grepl("^(mgcv::s\\.\\d\\()", x)
+  grepl("^(s\\.\\d\\()", x) |
+    grepl("^(gam::s\\.\\d\\()", x) |
+    grepl("^(mgcv::s\\.\\d\\()", x)
 }
 
 
@@ -403,7 +471,6 @@
 #   c(x, rval)
 # }
 
-
 .gam_family <- function(x) {
   faminfo <- .safe(stats::family(x))
 
@@ -419,7 +486,8 @@
 # for models with zero-inflation component, return
 # required component of model-summary
 .filter_component <- function(dat, component) {
-  switch(component,
+  switch(
+    component,
     cond = ,
     conditional = dat[dat$Component == "conditional", , drop = FALSE],
     zi = ,
@@ -437,11 +505,10 @@
 
 
 #' @keywords internal
-.gather <- function(x,
-                    names_to = "key",
-                    values_to = "value",
-                    columns = colnames(x)) {
-  if (is.numeric(columns)) columns <- colnames(x)[columns]
+.gather <- function(x, names_to = "key", values_to = "value", columns = colnames(x)) {
+  if (is.numeric(columns)) {
+    columns <- colnames(x)[columns]
+  }
 
   dat <- stats::reshape(
     x,
@@ -462,7 +529,13 @@
 }
 
 
-.is_baysian_emmeans <- function(x) {
+.is_bayesian_marginaleffects <- function(x) {
+  check_if_installed("marginaleffects", minimum_version = "0.29.0")
+  !is.null(suppressWarnings(marginaleffects::get_draws(x, "PxD")))
+}
+
+
+.is_bayesian_emmeans <- function(x) {
   if (inherits(x, "emm_list")) {
     x <- x[[1]]
   }
@@ -471,21 +544,6 @@
 }
 
 
-.is_bayesian_model <- function(x, exclude = NULL) {
-  bayes_classes <- c(
-    "brmsfit", "stanfit", "MCMCglmm", "stanreg", "stanmvreg", "bmerMod",
-    "BFBayesFactor", "bamlss", "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
-    "meta_random", "meta_fixed", "meta_bma", "blavaan", "blrm", "blmerMod",
-    "bglmerMod"
-  )
-  # if exclude is not NULL, remove elements in exclude from bayes_class
-  if (!is.null(exclude)) {
-    bayes_classes <- bayes_classes[!bayes_classes %in% exclude]
-  }
-  inherits(x, bayes_classes)
-}
-
-
 # safe conversion from factor to numeric
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.data.frame(x)) {
@@ -534,16 +592,27 @@
 
 ## copied from lme4::findbars() -----------------------
 
-
 .expandDoubleVert <- function(term) {
   frml <- stats::formula(substitute(~x, list(x = term[[2]])))
   newtrms <- paste0("0+", attr(stats::terms(frml), "term.labels"))
   if (attr(stats::terms(frml), "intercept") != 0) {
     newtrms <- c("1", newtrms)
   }
-  stats::as.formula(paste("~(", paste(vapply(newtrms, function(trm) { # nolint
-    paste0(trm, "|", deparse(term[[3]]))
-  }, ""), collapse = ")+("), ")"))[[2]]
+  stats::as.formula(paste(
+    "~(",
+    paste(
+      vapply(
+        newtrms,
+        function(trm) {
+          # nolint
+          paste0(trm, "|", deparse(term[[3]]))
+        },
+        ""
+      ),
+      collapse = ")+("
+    ),
+    ")"
+  ))[[2]]
 }
 
 
@@ -620,18 +689,19 @@
       expandSlash(list(bb))
     }
   }
-  modterm <- .expandDoubleVerts(if (methods::is(term, "formula")) {
-    term[[length(term)]]
-  } else {
-    term
-  })
+  modterm <- .expandDoubleVerts(
+    if (methods::is(term, "formula")) {
+      term[[length(term)]]
+    } else {
+      term
+    }
+  )
   expandSlash(fb(modterm))
 }
 
 
 ## copied from lme4::nobars() -----------------------
 
-
 .nobars <- function(term) {
   nb <- .nobars_(term)
   if (methods::is(term, "formula") && length(term) == 3 && is.symbol(nb)) {
@@ -709,7 +779,6 @@
 
 # classify emmeans objects -------------
 
-
 is.emmeans.contrast <- function(x) {
   if (inherits(x, "list")) {
     out <- vector("list", length = length(x))
