@@ -50,8 +50,9 @@ is_regression_model <- function(x) {
   x
 }
 
-
+# fmt: skip
 .get_model_classes <- function(regression_only = FALSE) {
+  # fmt: skip
   out <- c(
     "_ranger",
 
@@ -79,6 +80,8 @@ is_regression_model <- function(x) {
 
     # e --------------------
     "eglm", "elm", "emmGrid", "emm_list", "epi.2by2", "ergm",
+    "externVar", "externX", "estimate_means", "estimate_slopes",
+    "estimate_contrasts",
 
     # f --------------------
     "fdm", "feglm", "feis", "felm", "fitdistr", "fixest", "flexmix",
@@ -110,6 +113,7 @@ is_regression_model <- function(x) {
     "loggammacenslmrob", "logistf", "LogitBoost", "loo",
     "LORgee", "lmodel2", "lmerMod", "lmerModLmerTest",
     "logitmfx", "logitor", "logitr", "lqm", "lqmm", "lrm",
+    "lcmm",
 
     # m --------------------
     "maov", "manova", "MANOVA", "margins", "maxLik", "mboostLSS",
@@ -120,7 +124,7 @@ is_regression_model <- function(x) {
     "mle", "mle2", "mlergm", "mlm", "mlma", "mlogit", "model_fit",
     "multinom", "mvmeta", "mvord", "mvr", "marginaleffects",
     "marginaleffects.summary", "mblogit", "mclogit", "mmrm", "mmrm_fit",
-    "mmrm_tmb", "multinom_weightit",
+    "mmrm_tmb", "multinom_weightit", "mmlogit", "med1way", "mcp12",
 
     # n --------------------
     "negbin", "negbinmfx", "negbinirr", "nlreg", "nlrq", "nls",
@@ -128,6 +132,7 @@ is_regression_model <- function(x) {
 
     # o --------------------
     "objectiveML", "ols", "osrt", "orcutt", "ordinal_weightit", "oohbchoice",
+    "onesampb", "orm",
 
     # p --------------------
     "pairwise.htest", "pb1", "pb2", "pgmm", "plm", "plmm", "PMCMR",
@@ -146,7 +151,8 @@ is_regression_model <- function(x) {
     "Sarlm", "scam", "selection", "sem", "SemiParBIV", "serp", "slm", "speedlm",
     "speedglm", "splmm", "spml", "stanmvreg", "stanreg", "summary.lm",
     "survfit", "survreg", "survPresmooth", "svychisq", "svyglm", "svy_vglm",
-    "svyolr", "svytable", "systemfit", "svy2lme", "seqanova.svyglm",
+    "svyolr", "svytable", "systemfit", "svy2lme", "svycoxph", "seqanova.svyglm",
+    "sdmTMB", "stanfit", "semLME", "svysurvreg",
 
     # t --------------------
     "t1way", "t2way", "t3way", "test_mediation", "tobit", "trendPMCMR",
@@ -166,20 +172,21 @@ is_regression_model <- function(x) {
   )
 
   if (isTRUE(regression_only)) {
+    # fmt: skip
     out <- setdiff(out, c(
       "emmGrid", "emm_list", "htest", "pairwise.htest", "summary.lm",
-      "marginaleffects", "marginaleffects.summary", "ggcomparisons"
+      "marginaleffects", "marginaleffects.summary", "ggcomparisons",
+      "estimate_means", "estimate_slopes", "estimate_contrasts"
     ))
   }
 
   out
 }
 
-
+# fmt: skip
 .get_gam_classes <- function() {
   out <- c(
-    "bamlss", "bamlss.frame", "brmsfit",
-    "cgam", "cgamm",
+    "bamlss", "bamlss.frame", "brmsfit", "cgam", "cgamm",
     "gam", "Gam", "GAMBoost", "gamlr", "gamlss", "gamm", "gamm4",
     "stanmvreg", "stanreg"
   )
