@@ -3,6 +3,11 @@
 #'
 #' @description Retrieve information from model objects.
 #'
+#' @param response If `x` is a multivariate response model, `model_info()`
+#' returns a list of information for each response variable. Set `response` to
+#' the number of a specific response variable, or provide the name of the
+#' response variable in `response`, to return the information for only one
+#' response.
 #' @param verbose Toggle off warnings.
 #' @inheritParams find_predictors
 #' @inheritParams link_inverse
@@ -14,50 +19,72 @@
 #' @details `model_info()` returns a list with information about the
 #' model for many different model objects. Following information
 #' is returned, where all values starting with `is_` are logicals.
-#' * `is_binomial`: family is binomial (but not negative binomial)
+#'
+#' **Common families and distributions:**
+#'
 #' * `is_bernoulli`: special case of binomial models: family is Bernoulli
-#' * `is_poisson`: family is poisson
-#' * `is_negbin`: family is negative binomial
-#' * `is_count`: model is a count model (i.e. family is either poisson or negative binomial)
 #' * `is_beta`: family is beta
 #' * `is_betabinomial`: family is beta-binomial
-#' * `is_orderedbeta`: family is ordered beta
-#' * `is_dirichlet`: family is dirichlet
-#' * `is_exponential`: family is exponential (e.g. Gamma or Weibull)
-#' * `is_logit`: model has logit link
-#' * `is_probit`: model has probit link
-#' * `is_linear`: family is gaussian
-#' * `is_tweedie`: family is tweedie
-#' * `is_ordinal`: family is ordinal or cumulative link
-#' * `is_cumulative`: family is ordinal or cumulative link
-#' * `is_multinomial`: family is multinomial or categorical link
+#' * `is_binomial`: family is binomial (but not negative binomial)
 #' * `is_categorical`: family is categorical link
 #' * `is_censored`: model is a censored model (has a censored response, including survival models)
-#' * `is_truncated`: model is a truncated model (has a truncated response)
-#' * `is_survival`: model is a survival model
-#' * `is_zero_inflated`: model has zero-inflation component
-#' * `is_hurdle`: model has zero-inflation component and is a hurdle-model (truncated family distribution)
-#' * `is_dispersion`: model has dispersion component (not only dispersion _parameter_)
-#' * `is_mixed`: model is a mixed effects model (with random effects)
-#' * `is_multivariate`: model is a multivariate response model (currently only works for _brmsfit_ and _vglm/vgam_ objects)
-#' * `is_trial`: model response contains additional information about the trials
-#' * `is_bayesian`: model is a Bayesian model
-#' * `is_gam`: model is a generalized additive model
+#' * `is_count`: model is a count model (i.e. family is either poisson or negative binomial)
+#' * `is_cumulative`: family is ordinal or cumulative link
+#' * `is_dirichlet`: family is dirichlet
+#' * `is_exponential`: family is exponential (e.g. Gamma or Weibull)
+#' * `is_linear`: family is gaussian
+#' * `is_logit`: model has logit link
+#' * `is_multinomial`: family is multinomial or categorical link
+#' * `is_negbin`: family is negative binomial
+#' * `is_orderedbeta`: family is ordered beta
+#' * `is_ordinal`: family is ordinal or cumulative link
+#' * `is_poisson`: family is poisson
+#' * `is_probit`: model has probit link
+#' * `is_tweedie`: family is tweedie
+#'
+#' **Special model types**:
+#'
 #' * `is_anova`: model is an Anova object
-#' * `is_ttest`: model is an an object of class `htest`, returned by `t.test()`
+#' * `is_bayesian`: model is a Bayesian model
+#' * `is_dispersion`: model has dispersion component (not only dispersion _parameter_)
+#' * `is_gam`: model is a generalized additive model
+#' * `is_meta`: model is a meta-analysis object
+#' * `is_mixed`: model is a mixed effects model (with random effects)
+#' * `is_mixture`: model is a finite mixture model (currently only recognized for
+#'   package *brms*).
+#' * `is_multivariate`: model is a multivariate response model (currently only works for _brmsfit_ and _vglm/vgam_ objects)
+#' * `is_hurdle`: model has zero-inflation component and is a hurdle-model (truncated family distribution)
+#' * `is_rtchoice`: model is a *brms* decision-making (sequential sampling) model,
+#'   which models outcomes that consists of two components (reaction times and
+#'   choice).
+#' * `is_survival`: model is a survival model
+#' * `is_trial`: model response contains additional information about the trials
+#' * `is_truncated`: model is a truncated model (has a truncated response)
+#' * `is_wiener`: model is a *brms* decision-making (sequential sampling) model
+#'   with Wiener process (also called drift diffusion model)
+#' * `is_zero_inflated`: model has zero-inflation component
+#'
+#' **Hypotheses tests:**
+#'
+#' * `is_binomtest`: model is an an object of class `htest`, returned by `binom.test()`
+#' * `is_chi2test`: model is an an object of class `htest`, returned by `chisq.test()`
 #' * `is_correlation`: model is an an object of class `htest`, returned by `cor.test()`
-#' * `is_ranktest`: model is an an object of class `htest`, returned by `cor.test()`
-#'   (if Spearman's rank correlation), `wilcox.text()` or `kruskal.test()`.
-#' * `is_variancetest`: model is an an object of class `htest`, returned by
-#'   `bartlett.test()`, `shapiro.test()` or `car::leveneTest()`.
+#' * `is_ftest`: model is an an object of class `htest`, and test-statistic
+#'   is an F-statistic.
 #' * `is_levenetest`: model is an an object of class `anova`, returned by `car::leveneTest()`.
 #' * `is_onewaytest`: model is an an object of class `htest`, returned by `oneway.test()`
 #' * `is_proptest`: model is an an object of class `htest`, returned by `prop.test()`
-#' * `is_binomtest`: model is an an object of class `htest`, returned by `binom.test()`
-#' * `is_chi2test`: model is an an object of class `htest`, returned by `chisq.test()`
+#' * `is_ranktest`: model is an an object of class `htest`, returned by `cor.test()`
+#'   (if Spearman's rank correlation), `wilcox.text()` or `kruskal.test()`.
+#' * `is_ttest`: model is an an object of class `htest`, returned by `t.test()`
+#' * `is_variancetest`: model is an an object of class `htest`, returned by
+#'   `bartlett.test()`, `shapiro.test()` or `car::leveneTest()`.
 #' * `is_xtab`: model is an an object of class `htest` or `BFBayesFactor`, and
 #'   test-statistic stems from a contingency table (i.e. `chisq.test()` or
 #'   `BayesFactor::contingencyTableBF()`).
+#'
+#' **Other model information:**
+#'
 #' * `link_function`: the link-function
 #' * `family`: name of the distributional family of the model. For some
 #'   exceptions (like some `htest` objects), can also be the name of the test.
@@ -114,7 +141,7 @@ model_info.default <- function(x, verbose = TRUE, ...) {
     }
     NULL
   } else {
-    .make_family(
+    .retrieve_model_info(
       x = x,
       fitfam = faminfo$family,
       logit.link = faminfo$link == "logit",
@@ -134,11 +161,13 @@ model_info.model_fit <- function(x, verbose = TRUE, ...) {
 
 # Models with general handling, Gaussian ----------------------------------
 
-
 #' @export
 model_info.anova <- function(x, verbose = TRUE, ...) {
-  if (!is.null(attributes(x)$heading) && grepl("Levene's Test", attributes(x)$heading, fixed = TRUE)) {
-    .make_family(x, verbose = verbose, ...)
+  if (
+    !is.null(attributes(x)$heading) &&
+      grepl("Levene's Test", attributes(x)$heading, fixed = TRUE)
+  ) {
+    .retrieve_model_info(x, verbose = verbose, ...)
   } else {
     NULL
   }
@@ -147,13 +176,13 @@ model_info.anova <- function(x, verbose = TRUE, ...) {
 
 #' @export
 model_info.asym <- function(x, verbose = TRUE, ...) {
-  .make_family(x, verbose = verbose, ...)
+  .retrieve_model_info(x, verbose = verbose, ...)
 }
 
 
 #' @export
 model_info.mclogit <- function(x, verbose = TRUE, ...) {
-  .make_family(
+  .retrieve_model_info(
     x,
     fitfam = "categorical",
     logit.link = TRUE,
@@ -177,9 +206,9 @@ model_info.logitr <- model_info.mclogit
 model_info.maxLik <- function(x, verbose = TRUE, ...) {
   fitfam <- .safe(eval(get_call(x)$family))
   if (is.null(fitfam)) {
-    .make_family(x, verbose = verbose, ...)
+    .retrieve_model_info(x, verbose = verbose, ...)
   } else {
-    .make_family(
+    .retrieve_model_info(
       x,
       fitfam = fitfam$family,
       logit.link = fitfam$link == "logit",
@@ -313,27 +342,26 @@ model_info.metaplus <- model_info.maxLik
 
 #' @export
 model_info.mlm <- function(x, ...) {
-  .make_family(x, multi.var = TRUE, ...)
+  .retrieve_model_info(x, multi.var = TRUE, ...)
 }
 
 
 #' @export
 model_info.afex_aov <- function(x, verbose = TRUE, ...) {
   if (is.null(x$aov)) {
-    .make_family(x$lm, verbose = verbose, ...)
+    .retrieve_model_info(x$lm, verbose = verbose, ...)
   } else {
-    .make_family(x$aov, verbose = verbose, ...)
+    .retrieve_model_info(x$aov, verbose = verbose, ...)
   }
 }
 
 
 # Models with logit-link --------------------------------
 
-
 #' @export
 model_info.logistf <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::binomial(link = "logit")
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -369,7 +397,7 @@ model_info.gmnl <- model_info.logistf
 
 #' @export
 model_info.phylolm <- function(x, verbose = TRUE, ...) {
-  .make_family(x, verbose = verbose, ...)
+  .retrieve_model_info(x, verbose = verbose, ...)
 }
 
 
@@ -380,7 +408,7 @@ model_info.phyloglm <- function(x, verbose = TRUE, ...) {
   } else {
     faminfo <- stats::poisson()
   }
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -393,11 +421,10 @@ model_info.phyloglm <- function(x, verbose = TRUE, ...) {
 
 # Models with ordinal family ------------------------------------
 
-
 #' @export
 model_info.clm <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::binomial(link = .get_ordinal_link(x))
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -422,7 +449,7 @@ model_info.mixor <- model_info.clm
 #' @export
 model_info.ordinal_weightit <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::binomial(link = .get_ordinal_link(x$family))
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -439,7 +466,7 @@ model_info.multinom_weightit <- model_info.ordinal_weightit
 model_info.mvord <- function(x, verbose = verbose, ...) {
   link_name <- x$rho$link$name
   faminfo <- stats::binomial(link = ifelse(link_name == "mvprobit", "probit", "logit"))
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -453,11 +480,10 @@ model_info.mvord <- function(x, verbose = verbose, ...) {
 
 # Models with family-function  ----------------------------------
 
-
 #' @export
 model_info.bamlss <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::family(x)
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$links[1] == "logit",
@@ -471,7 +497,7 @@ model_info.bamlss <- function(x, verbose = TRUE, ...) {
 #' @export
 model_info.speedglm <- function(x, verbose = TRUE, ...) {
   faminfo <- stats::family(x)
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -487,13 +513,12 @@ model_info.brmultinom <- model_info.speedglm
 
 # Models with tobit family ----------------------------------
 
-
 #' @export
 model_info.flexsurvreg <- function(x, verbose = TRUE, ...) {
   distribution <- parse(text = safe_deparse(x$call))[[1]]$dist
   faminfo <- .make_tobit_family(x, distribution)
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -507,7 +532,7 @@ model_info.flexsurvreg <- function(x, verbose = TRUE, ...) {
 model_info.tobit <- function(x, verbose = TRUE, ...) {
   faminfo <- .make_tobit_family(x)
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -526,11 +551,10 @@ model_info.survreg <- model_info.tobit
 
 # Models with family in object ----------------------------------
 
-
 #' @export
 model_info.MixMod <- function(x, verbose = TRUE, ...) {
   faminfo <- x$family
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     zero.inf = !is.null(stats::formula(x, type = "zi_fixed")),
@@ -548,10 +572,35 @@ model_info.glmmPQL <- model_info.MixMod
 model_info.bife <- model_info.MixMod
 
 
+#' @export
+model_info.sdmTMB <- function(x, verbose = TRUE, ...) {
+  faminfo <- x$family
+
+  # check if we have delta component
+  if (length(faminfo$family) > 1) {
+    faminfo <- list(
+      family = faminfo$family[2],
+      link = faminfo$link[2],
+      linkfun = faminfo[[2]]$linkfun,
+      linkinv = faminfo[[2]]$linkinv
+    )
+  }
+
+  .retrieve_model_info(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    verbose = verbose,
+    ...
+  )
+}
+
+
 #' @export
 model_info.glmx <- function(x, verbose = TRUE, ...) {
   faminfo <- x$family$glm
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -568,10 +617,10 @@ model_info.fixest <- function(x, verbose = TRUE, ...) {
 
   if (is.null(faminfo)) {
     if (!is.null(x$method) && x$method == "feols") {
-      .make_family(x, ...)
+      .retrieve_model_info(x, ...)
     }
   } else if (inherits(faminfo, "family")) {
-    .make_family(
+    .retrieve_model_info(
       x = x,
       fitfam = faminfo$family,
       logit.link = faminfo$link == "logit",
@@ -580,20 +629,17 @@ model_info.fixest <- function(x, verbose = TRUE, ...) {
       ...
     )
   } else {
-    fitfam <- switch(faminfo,
-      negbin = "negative binomial",
-      logit = "binomial",
-      faminfo
-    )
+    fitfam <- switch(faminfo, negbin = "negative binomial", logit = "binomial", faminfo)
 
-    link <- switch(faminfo,
+    link <- switch(
+      faminfo,
       poisson = ,
       negbin = "log",
       logit = "logit",
       gaussian = "identity"
     )
 
-    .make_family(
+    .retrieve_model_info(
       x = x,
       fitfam = fitfam,
       logit.link = link == "logit",
@@ -612,7 +658,7 @@ model_info.feglm <- model_info.fixest
 
 #' @export
 model_info.coxph <- function(x, verbose = TRUE, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = "survival",
     logit.link = TRUE,
@@ -650,12 +696,13 @@ model_info.zeroinfl <- function(x, ...) {
   } else {
     distribution <- x$dist
   }
-  fitfam <- switch(distribution,
+  fitfam <- switch(
+    distribution,
     poisson = "poisson",
     negbin = "negative binomial",
     "poisson"
   )
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fitfam,
     zero.inf = TRUE,
@@ -675,12 +722,13 @@ model_info.hurdle <- function(x, ...) {
   } else {
     distribution <- x$dist
   }
-  fitfam <- switch(distribution,
+  fitfam <- switch(
+    distribution,
     poisson = "poisson",
     negbin = "negative binomial",
     "poisson"
   )
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fitfam,
     zero.inf = TRUE,
@@ -693,7 +741,7 @@ model_info.hurdle <- function(x, ...) {
 
 #' @export
 model_info.mhurdle <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     zero.inf = TRUE,
     hurdle = TRUE,
@@ -704,7 +752,6 @@ model_info.mhurdle <- function(x, ...) {
 
 # Bayesian Models ---------------------------
 
-
 #' @export
 model_info.stanreg <- function(x, ...) {
   if (inherits(x, "polr")) {
@@ -715,15 +762,16 @@ model_info.stanreg <- function(x, ...) {
 }
 
 
+#' @rdname model_info
 #' @export
-model_info.brmsfit <- function(x, ...) {
+model_info.brmsfit <- function(x, response = NULL, ...) {
   faminfo <- stats::family(x)
   if (is_multivariate(x)) {
-    lapply(faminfo, function(.x) {
+    out <- lapply(faminfo, function(.x) {
       ## TODO: check for multivariate, if we need "x" or ".x"
       form <- find_formula(x, verbose = FALSE)
       is_dispersion <- !is_empty_object(form$sigma) || !is_empty_object(form$kappa)
-      .make_family(
+      .retrieve_model_info(
         x = x,
         fitfam = .x$family,
         zero.inf = FALSE,
@@ -731,19 +779,26 @@ model_info.brmsfit <- function(x, ...) {
         multi.var = TRUE,
         link.fun = .x$link,
         dispersion = is_dispersion,
+        brms_custom_name = faminfo$name,
         ...
       )
     })
+    if (is.null(response)) {
+      out
+    } else {
+      out[[response]]
+    }
   } else {
     form <- find_formula(x, verbose = FALSE)
     is_dispersion <- !is_empty_object(form$sigma) || !is_empty_object(form$kappa)
-    .make_family(
+    .retrieve_model_info(
       x = x,
       fitfam = faminfo$family,
       logit.link = faminfo$link == "logit",
       multi.var = FALSE,
       link.fun = faminfo$link,
       dispersion = is_dispersion,
+      brms_custom_name = faminfo$name,
       ...
     )
   }
@@ -751,10 +806,10 @@ model_info.brmsfit <- function(x, ...) {
 
 
 #' @export
-model_info.stanmvreg <- function(x, ...) {
+model_info.stanmvreg <- function(x, response = NULL, ...) {
   faminfo <- stats::family(x)
-  lapply(faminfo, function(.x) {
-    .make_family(
+  out <- lapply(faminfo, function(.x) {
+    .retrieve_model_info(
       x = x,
       fitfam = .x$family,
       zero.inf = FALSE,
@@ -764,12 +819,18 @@ model_info.stanmvreg <- function(x, ...) {
       ...
     )
   })
+  if (is.null(response)) {
+    out
+  } else {
+    out[[response]]
+  }
 }
 
 
 #' @export
 model_info.oohbchoice <- function(x, ...) {
-  link <- switch(x$distribution,
+  link <- switch(
+    x$distribution,
     normal = ,
     "log-normal" = stats::gaussian()$link,
     logistic = ,
@@ -777,7 +838,8 @@ model_info.oohbchoice <- function(x, ...) {
     "log"
   )
 
-  fam <- switch(x$distribution,
+  fam <- switch(
+    x$distribution,
     normal = ,
     "log-normal" = "gaussian",
     logistic = ,
@@ -785,7 +847,7 @@ model_info.oohbchoice <- function(x, ...) {
     "weibull"
   )
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fam,
     zero.inf = FALSE,
@@ -798,18 +860,11 @@ model_info.oohbchoice <- function(x, ...) {
 
 #' @export
 model_info.BGGM <- function(x, ...) {
-  link <- switch(x$type,
-    continuous = stats::gaussian(),
-    stats::binomial()
-  )
+  link <- switch(x$type, continuous = stats::gaussian(), stats::binomial())
 
-  fam <- switch(x$type,
-    continuous = "gaussian",
-    binary = "binomial",
-    "ordinal"
-  )
+  fam <- switch(x$type, continuous = "gaussian", binary = "binomial", "ordinal")
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fam,
     zero.inf = FALSE,
@@ -824,7 +879,7 @@ model_info.BGGM <- function(x, ...) {
 
 #' @export
 model_info.garch <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     ...
   )
@@ -833,7 +888,7 @@ model_info.garch <- function(x, ...) {
 
 #' @export
 model_info.Rchoice <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = x$family,
     logit.link = x$link == "logit",
@@ -845,7 +900,7 @@ model_info.Rchoice <- function(x, ...) {
 
 #' @export
 model_info.ivprobit <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = "binomial",
     logit.link = FALSE,
@@ -869,13 +924,14 @@ model_info.coeftest <- function(x, ...) {
 
 #' @export
 model_info.glmm <- function(x, ...) {
-  f <- switch(tolower(x$family.glmm$family.glmm),
+  f <- switch(
+    tolower(x$family.glmm$family.glmm),
     bernoulli.glmm = ,
     binomial.glmm = stats::binomial("logit"),
     poisson.glmm = stats::poisson("log"),
     stats::gaussian("identity")
   )
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = f$family,
     logit.link = f$link == "logit",
@@ -888,7 +944,8 @@ model_info.glmm <- function(x, ...) {
 
 #' @export
 model_info.robmixglm <- function(x, ...) {
-  f <- switch(tolower(x$family),
+  f <- switch(
+    tolower(x$family),
     gaussian = stats::gaussian("identity"),
     binomial = stats::binomial("logit"),
     poisson = stats::poisson("log"),
@@ -896,7 +953,7 @@ model_info.robmixglm <- function(x, ...) {
     truncpoisson = stats::poisson("log"),
     stats::gaussian("identity")
   )
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = f$family,
     logit.link = f$link == "logit",
@@ -911,7 +968,7 @@ model_info.robmixglm <- function(x, ...) {
 
 #' @export
 model_info.Arima <- function(x, ...) {
-  .make_family(x, ...)
+  .retrieve_model_info(x, ...)
 }
 
 
@@ -922,7 +979,9 @@ model_info.summary.lm <- model_info.Arima
 #' @export
 model_info.averaging <- function(x, ...) {
   if (is.null(attributes(x)$modelList)) {
-    format_warning("Can't access model information. Please use 'fit = TRUE' in 'model.avg()'.")
+    format_warning(
+      "Can't access model information. Please use 'fit = TRUE' in 'model.avg()'."
+    )
     return(NULL)
   }
   model_info(x = attributes(x)$modelList[[1]])
@@ -941,11 +1000,11 @@ model_info.cglm <- function(x, ...) {
   method <- parse(text = safe_deparse(x$call))[[1]]$method
 
   if (!is.null(method) && method == "clm") {
-    .make_family(x, ...)
+    .retrieve_model_info(x, ...)
   } else if (is.null(link)) {
-    .make_family(x, ...)
+    .retrieve_model_info(x, ...)
   } else {
-    .make_family(
+    .retrieve_model_info(
       x,
       logit.link = link == "logit",
       link.fun = link,
@@ -958,7 +1017,7 @@ model_info.cglm <- function(x, ...) {
 #' @export
 model_info.cgam <- function(x, ...) {
   faminfo <- x$family
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -996,7 +1055,7 @@ model_info.LORgee <- function(x, ...) {
     fam <- "multinomial"
   }
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fam,
     logit.link = link == "logit",
@@ -1008,7 +1067,7 @@ model_info.LORgee <- function(x, ...) {
 
 #' @export
 model_info.BBreg <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = "betabinomial",
     logit.link = TRUE,
@@ -1025,7 +1084,7 @@ model_info.BBmm <- model_info.BBreg
 
 #' @export
 model_info.mmrm <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     ...
   )
@@ -1040,7 +1099,7 @@ model_info.mmrm_tmb <- model_info.mmrm
 
 #' @export
 model_info.glmmadmb <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = x$family,
     logit.link = x$link == "logit",
@@ -1055,7 +1114,7 @@ model_info.glmmadmb <- function(x, ...) {
 #' @export
 model_info.glmgee <- function(x, ...) {
   faminfo <- x$family
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -1068,9 +1127,13 @@ model_info.glmgee <- function(x, ...) {
 #' @export
 model_info.cpglmm <- function(x, ...) {
   link <- parse(text = safe_deparse(x@call))[[1]]$link
-  if (is.null(link)) link <- "log"
-  if (is.numeric(link)) link <- "tweedie"
-  .make_family(
+  if (is.null(link)) {
+    link <- "log"
+  }
+  if (is.numeric(link)) {
+    link <- "tweedie"
+  }
+  .retrieve_model_info(
     x = x,
     fitfam = "poisson",
     logit.link = FALSE,
@@ -1084,9 +1147,13 @@ model_info.cpglmm <- function(x, ...) {
 #' @export
 model_info.zcpglm <- function(x, ...) {
   link <- parse(text = safe_deparse(x@call))[[1]]$link
-  if (is.null(link)) link <- "log"
-  if (is.numeric(link)) link <- "tweedie"
-  .make_family(
+  if (is.null(link)) {
+    link <- "log"
+  }
+  if (is.numeric(link)) {
+    link <- "tweedie"
+  }
+  .retrieve_model_info(
     x = x,
     fitfam = "poisson",
     logit.link = FALSE,
@@ -1106,11 +1173,8 @@ model_info.bcplm <- model_info.cpglmm
 
 #' @export
 model_info.glimML <- function(x, ...) {
-  fitfam <- switch(x@method,
-    BB = "betabinomial",
-    NB = "negative binomial"
-  )
-  .make_family(
+  fitfam <- switch(x@method, BB = "betabinomial", NB = "negative binomial")
+  .retrieve_model_info(
     x = x,
     fitfam = fitfam,
     logit.link = x@link == "logit",
@@ -1136,7 +1200,7 @@ model_info.gam <- function(x, ...) {
     link <- "identity"
   }
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = !is.null(link) && (link == "logit" || faminfo$family == "multinom"),
@@ -1154,7 +1218,7 @@ model_info.vgam <- function(x, ...) {
   if (grepl("^(l|L)ogit", link.fun)) {
     link.fun <- "logit"
   }
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo@vfamily[1],
     logit.link = any(.string_contains("logit", faminfo@blurb)),
@@ -1176,7 +1240,7 @@ model_info.svy_vglm <- function(x, verbose = TRUE, ...) {
 
 #' @export
 model_info.svy2lme <- function(x, verbose = TRUE, ...) {
-  .make_family(x = x, verbose = verbose, ...)
+  .retrieve_model_info(x = x, verbose = verbose, ...)
 }
 
 
@@ -1185,9 +1249,10 @@ model_info.glmmTMB <- function(x, ...) {
   check_if_installed("lme4")
 
   faminfo <- stats::family(x)
-  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi) || startsWith(faminfo$family, "truncated")
+  zero_inflated <- !is_empty_object(lme4::fixef(x)$zi) ||
+    startsWith(faminfo$family, "truncated")
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     zero.inf = zero_inflated,
@@ -1203,19 +1268,33 @@ model_info.glmmTMB <- function(x, ...) {
 
 #' @export
 model_info.betareg <- function(x, ...) {
-  .make_family(
+  element_name <- .betareg_mean_element(x)
+
+  .retrieve_model_info(
     x = x,
     fitfam = "beta",
-    logit.link = x$link$mean$name == "logit",
-    link.fun = x$link$mean$name,
+    logit.link = x$link[[element_name]]$name == "logit",
+    link.fun = x$link[[element_name]]$name,
     ...
   )
 }
 
+.betareg_mean_element <- function(x) {
+  if (!is.null(x$link$mean)) {
+    "mean"
+  } else if (!is.null(x$link$mu)) {
+    "mu"
+  } else {
+    format_error(
+      "Could not find link information for the mean model in the betareg-object."
+    )
+  }
+}
+
 
 #' @export
 model_info.DirichletRegModel <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = "dirichlet",
     logit.link = TRUE,
@@ -1227,7 +1306,8 @@ model_info.DirichletRegModel <- function(x, ...) {
 
 #' @export
 model_info.gbm <- function(x, ...) {
-  faminfo <- switch(x$distribution$name,
+  faminfo <- switch(
+    x$distribution$name,
     laplace = ,
     tdist = ,
     gaussian = list(name = "gaussian", logit = FALSE, link = NULL),
@@ -1238,7 +1318,7 @@ model_info.gbm <- function(x, ...) {
     bernoulli = list(name = "binomial", logit = TRUE, link = "logit"),
   )
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$name,
     logit.link = faminfo$logit,
@@ -1250,7 +1330,7 @@ model_info.gbm <- function(x, ...) {
 
 #' @export
 model_info.MCMCglmm <- function(x, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = x$Residual$family,
     logit.link = FALSE,
@@ -1263,9 +1343,11 @@ model_info.MCMCglmm <- function(x, ...) {
 #' @export
 model_info.polr <- function(x, ...) {
   link <- x$method
-  if (link == "logistic") link <- "logit"
+  if (link == "logistic") {
+    link <- "logit"
+  }
   faminfo <- stats::binomial(link = link)
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -1278,7 +1360,7 @@ model_info.polr <- function(x, ...) {
 #' @export
 model_info.nestedLogit <- function(x, ...) {
   faminfo <- stats::binomial(link = "logit")
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = TRUE,
@@ -1299,7 +1381,7 @@ model_info.hglm <- function(x, ...) {
     return(NULL)
   }
 
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -1312,7 +1394,7 @@ model_info.hglm <- function(x, ...) {
 #' @export
 model_info.orm <- function(x, ...) {
   faminfo <- stats::binomial(link = "logit")
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -1324,12 +1406,9 @@ model_info.orm <- function(x, ...) {
 
 #' @export
 model_info.svyolr <- function(x, ...) {
-  l <- switch(x$method,
-    logistic = "logit",
-    x$method
-  )
+  l <- switch(x$method, logistic = "logit", x$method)
   faminfo <- stats::binomial(link = l)
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = faminfo$family,
     logit.link = faminfo$link == "logit",
@@ -1350,7 +1429,7 @@ model_info.gamlss <- function(x, ...) {
       fitfam <- "unknown"
     }
   }
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = fitfam,
     logit.link = faminfo$mu.link == "logit",
@@ -1411,7 +1490,7 @@ model_info.negbinirr <- model_info.logitmfx
 
 #' @export
 model_info.bfsl <- function(x, verbose = TRUE, ...) {
-  .make_family(
+  .retrieve_model_info(
     x = x,
     fitfam = "gaussian",
     logit.link = FALSE,
@@ -1425,7 +1504,8 @@ model_info.bfsl <- function(x, verbose = TRUE, ...) {
 
 #' @export
 model_info.marginaleffects <- function(x, ...) {
-  model_info(attributes(x)$model)
+  check_if_installed("marginaleffects", minimum_version = "0.29.0")
+  model_info(marginaleffects::components(x, "model"))
 }
 
 
@@ -1445,3 +1525,30 @@ model_info.deltaMethod <- function(x, ...) {
 model_info.ggcomparisons <- function(x, ...) {
   NULL
 }
+
+#' @export
+model_info.lcmm <- function(x, verbose = TRUE, ...) {
+  .retrieve_model_info(
+    x = x,
+    fitfam = "gaussian",
+    logit.link = FALSE,
+    link.fun = "identity",
+    verbose = verbose,
+    ...
+  )
+}
+
+#' @export
+model_info.externX <- function(x, verbose = TRUE, ...) {
+  .retrieve_model_info(
+    x = x,
+    fitfam = "multinomial",
+    logit.link = TRUE,
+    link.fun = "logit",
+    verbose = verbose,
+    ...
+  )
+}
+
+#' @export
+model_info.externVar <- model_info.externX
