@@ -4,12 +4,13 @@
 #' @description Collection of small helper functions. `trim_ws()` is an
 #' efficient function to trim leading and trailing whitespaces from character
 #' vectors or strings. `n_unique()` returns the number of unique values in a
-#' vector. `has_single_value()` is equivalent to `n_unique() == 1` but is faster.
-#' `safe_deparse()` is comparable to `deparse1()`, i.e. it can safely
-#' deparse very long expressions into a single string. `safe_deparse_symbol()`
-#' only deparses a substituted expressions when possible, which can be much faster
-#' than `deparse(substitute())` for those cases where `substitute()` returns no
-#' valid object name.
+#' vector. `has_single_value()` is equivalent to `n_unique() == 1` but is faster
+#' (note the different default for the `remove_na` argument). `safe_deparse()`
+#' is comparable to `deparse1()`, i.e. it can safely deparse very long
+#' expressions into a single string. `safe_deparse_symbol()` only deparses a
+#' substituted expressions when possible, which can be much faster than
+#' `deparse(substitute())` for those cases where `substitute()` returns no valid
+#' object name.
 #'
 #' @param x A (character) vector, or for some functions may also be a data frame.
 #' @param remove_na Logical, if missing values should be removed from the input.
@@ -91,7 +92,9 @@ n_unique.default <- function(x, remove_na = TRUE, ...) {
   if (is.null(x)) {
     return(0)
   }
-  if (isTRUE(remove_na)) x <- x[!is.na(x)]
+  if (isTRUE(remove_na)) {
+    x <- x[!is.na(x)]
+  }
   length(unique(x))
 }
 
@@ -137,6 +140,8 @@ safe_deparse_symbol <- function(x) {
 #' @rdname trim_ws
 #' @export
 has_single_value <- function(x, remove_na = FALSE, ...) {
-  if (remove_na) x <- x[!is.na(x)]
+  if (remove_na) {
+    x <- x[!is.na(x)]
+  }
   !is.null(x) && length(x) > 0L && isTRUE(all(x == x[1]))
 }
