@@ -1,6 +1,8 @@
 skip_on_cran()
 skip_on_os("mac")
 skip_if_not_installed("brms")
+skip_if_not_installed("BH")
+skip_if_not_installed("RcppEigen")
 skip_if_not_installed("withr")
 
 withr::with_environment(
@@ -20,7 +22,10 @@ withr::with_environment(
       ),
       ignore_attr = TRUE
     )
-    expect_identical(find_predictors(m, "all"), list(conditional = "Trt", random = "patient"))
+    expect_identical(
+      find_predictors(m, "all"),
+      list(conditional = "Trt", random = "patient")
+    )
     expect_identical(find_random(m), list(random = "patient"))
     d <- get_data(m)
     expect_named(d, c("count", "Trt", "patient"))
