@@ -1,11 +1,12 @@
 skip_on_cran()
-skip_if_not_installed("marginaleffects")
+skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 skip_if_not_installed("emmeans")
 
 test_that("marginaleffects", {
   m <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
 
-  x <- marginaleffects::slopes(m,
+  x <- marginaleffects::slopes(
+    m,
     variables = "Petal.Length",
     newdata = insight::get_datagrid(m, by = "Species")
   )
@@ -28,15 +29,28 @@ test_that("marginaleffects", {
   expect_identical(insight::find_statistic(x), "z-statistic")
 
   # standardize names - "s.value" becomes "S"
-  skip_if_not_installed("parameters", minimum_version = "0.24.0")
-  skip_if_not_installed("marginaleffects", minimum_version = "0.24.0.6")
+  skip_if_not_installed("parameters", minimum_version = "0.28.0.13")
+  skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 
   expect_named(
     parameters::model_parameters(x),
     c(
-      "rowid", "Parameter", "Comparison", "Coefficient", "SE", "Statistic", "p",
-      "S", "CI", "CI_low", "CI_high", "Predicted", "Species",
-      "Petal.Length", "Sepal.Width"
+      "rowid",
+      "Parameter",
+      "Comparison",
+      "Coefficient",
+      "SE",
+      "Statistic",
+      "p",
+      "S",
+      "CI",
+      "CI_low",
+      "CI_high",
+      "Species",
+      "Petal.Length",
+      "Predicted"
     )
   )
+
+  expect_equal(n_obs(x), 150) # nrow(iris)
 })
